@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2014, OFFIS e.V.
+ *  Copyright (C) 2003-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -300,9 +300,8 @@ static OFCondition putElementContent(xmlNodePtr current,
         } else {
             OFString dicomVal;
             /* convert character set from UTF-8 (for specific VRs only) */
-            if (((dcmEVR == EVR_PN) || (dcmEVR == EVR_SH) || (dcmEVR == EVR_LO) ||
-                 (dcmEVR == EVR_ST) || (dcmEVR == EVR_LT) || (dcmEVR == EVR_UT)) &&
-                (xmlStrlen(elemVal) > 0) && convertUtf8ToCharset(elemVal, dicomVal))
+            if (element->isAffectedBySpecificCharacterSet() &&
+               (xmlStrlen(elemVal) > 0) && convertUtf8ToCharset(elemVal, dicomVal))
             {
                 result = element->putOFStringArray(dicomVal);
             } else {
@@ -434,7 +433,7 @@ static OFCondition parsePixelSequence(DcmPixelSequence *sequence,
             if (xmlStrcmp(current->name, OFreinterpret_cast(const xmlChar *, "pixel-item")) == 0)
             {
                 /* create new pixel item */
-                DcmPixelItem *newItem = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+                DcmPixelItem *newItem = new DcmPixelItem(DCM_PixelItemTag);
                 if (newItem != NULL)
                 {
                     sequence->insert(newItem);
@@ -504,7 +503,7 @@ static OFCondition parseDataSet(DcmItem *dataset,
                     if (newElem->getTag() == DCM_PixelData)
                     {
                         /* create new pixel sequence */
-                        DcmPixelSequence *sequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
+                        DcmPixelSequence *sequence = new DcmPixelSequence(DCM_PixelSequenceTag);
                         if (sequence != NULL)
                         {
                             /* ... insert it into the dataset and proceed with the pixel items */
