@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -30,6 +30,12 @@
 #include "dcmtk/ofstd/ofstring.h"
 
 
+// include this file in doxygen documentation
+
+/** @file dcbytstr.h
+ *  @brief base class for all DICOM value representations storing a character string
+ */
+
 /** This flag defines whether the VR checker is actually used by the various
  *  checkStringValue() methods.  Since this checker is currently limited to
  *  ASCII and Latin-1, and the detection of the character set might fail for
@@ -71,6 +77,25 @@ class DCMTK_DCMDATA_EXPORT DcmByteString: public DcmElement
      */
     DcmByteString& operator=(const DcmByteString& obj);
 
+    /** comparison operator that compares the normalized value of this object
+     *  with a given object of the same type. The tag of the element is also
+     *  considered as the first component that is compared, followed by the
+     *  object types (VR, i.e. DCMTK'S EVR) and the comparison of all value
+     *  components of the object, preferably in the order declared in the
+     *  object (if applicable).
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *          -1 if either the value of the  first component that does not match
+     *          is lower in this object than in rhs, or all compared components match
+     *          but this object has fewer components than rhs. Also returned if rhs
+     *          cannot be casted to this object type.
+     *          1 if either the value of the first component that does not match
+     *          is greater in this object than in rhs object, or all compared
+     *          components match but the this component is longer.
+     */
+    virtual int compare(const DcmElement& rhs) const;
+
+
     /** clone method
      *  @return deep copy of this object
      */
@@ -233,7 +258,8 @@ class DCMTK_DCMDATA_EXPORT DcmByteString: public DcmElement
      *  codes below 128 are considered to be ASCII codes and all others are considered to
      *  be non-ASCII.
      *  @param checkAllStrings if true, also check elements with string values not affected
-     *    by SpecificCharacterSet (0008,0005), default: only check PN, LO, LT, SH, ST, UT
+     *    by SpecificCharacterSet (0008,0005). By default, only check PN, LO, LT, SH, ST,
+     *    UC and UT, i.e. none of the derived VR classes.
      *  @return true if element contains non-ASCII characters, false otherwise
      */
     virtual OFBool containsExtendedCharacters(const OFBool checkAllStrings = OFFalse);
@@ -329,6 +355,19 @@ class DCMTK_DCMDATA_EXPORT DcmByteString: public DcmElement
 
     /* --- static helper functions --- */
 
+    /** check if a given character string contains non-ASCII characters.
+     *  Please note that this check is pretty simple and only works for single-byte character
+     *  sets that do include the 7-bit ASCII codes, e.g. for the ISO 8859 family. In other
+     *  words: All character codes below 128 are considered to be ASCII codes and all others
+     *  are considered to be non-ASCII.
+     *  @param stringVal character string to be checked
+     *  @param stringLen length of the string (number of characters without the trailing
+     *    NULL byte)
+     * @return true if character string contains non-ASCII characters, false otherwise
+     */
+    static OFBool containsExtendedCharacters(const char *stringVal,
+                                             const size_t stringLen);
+
     /** check whether given string value conforms to a certain VR and VM.
      *  @param value string value to be checked (possibly multi-valued)
      *  @param vm value multiplicity (according to the data dictionary) to be checked for.
@@ -338,6 +377,8 @@ class DCMTK_DCMDATA_EXPORT DcmByteString: public DcmElement
      *  @param maxLen maximum number of characters allowed for a single value (0 = no check)
      *  @param charset character set (according to the value of the SpecificCharacterSet
      *    element) to be used for checking the string value. The default is ASCII (7-bit).
+     *    Currently, the VR checker only supports ASCII (ISO_IR 6) and Latin-1 (ISO_IR 100).
+     *    All other values disable the check of the value representation, e.g. "UNKNOWN".
      *  @return status of the check, EC_Normal if value is correct, an error code otherwise
      */
     static OFCondition checkStringValue(const OFString &value,
