@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -66,6 +66,11 @@ const unsigned short OFM_dcmstscp = 25;
 const unsigned short OFM_dcmqrdbx = 26;
 const unsigned short OFM_dcmkosel = 27;
 const unsigned short OFM_dcmenc   = 28;
+const unsigned short OFM_dcmiod   = 29;
+const unsigned short OFM_dcmseg   = 30;
+const unsigned short OFM_dcmfg    = 31;
+const unsigned short OFM_dcmtract = 32;
+
 
 // condition constants
 
@@ -140,6 +145,22 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_PrematureSequDelimitationI
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidDICOMDIR;
 /// Unknown VR, e.g. tag not found in data dictionary
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownVR;
+/// Invalid value, e.g. element value has been provided that does not match the VR
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidValue;
+/// An expected Item was not found
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_ItemNotFound;
+/// Given transfer syntax is unknown
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownTransferSyntax;
+/// Cannot check
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotCheck;
+/// Missing value, e.g. element must contain a value but is empty
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_MissingValue;
+/// Missing attribute
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_MissingAttribute;
+/// Internal error
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InternalError;
+/// Invalid character, e.g. non-ASCII character used but no Specific Character Set defined
+extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidCharacter;
 //@}
 
 // status code constants
@@ -148,9 +169,10 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownVR;
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotSelectCharacterSet;
 /// error, cannot convert specific character set
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertCharacterSet;
-
 /// error, cannot convert to XML
-extern const unsigned short EC_CODE_CannotConvertToXML;
+extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertToXML;
+/// error, cannot determine start fragment (of compressed pixel data)
+extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotDetermineStartFragment;
 
 
 #endif /* !DCERROR_H */
