@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,25 +26,54 @@
 #include "dcmtk/ofstd/ofglobal.h"
 #include "dcmtk/dcmdata/dcdefine.h"
 
+// include this file in doxygen documentation
+
+/** @file dcvr.h
+ *  @brief definition and handling of value representations (VR)
+ */
+
 /** Global flag to enable/disable the generation of VR=UN, which has been
  *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=OB is used instead.
  */
 extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableUnknownVRGeneration; /* default OFTrue */
 
 /** Global flag to enable/disable the generation of VR=UT, which has been
  *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UN (if enabled) or alternatively VR=OB is used.
  */
 extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableUnlimitedTextVRGeneration; /* default OFTrue */
 
 /** Global flag to enable/disable the generation of VR=OF, which has been
  *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UN (if enabled) or alternatively VR=OB is used.
  */
-extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherFloatStringVRGeneration; /* default OFTrue */
+extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherFloatVRGeneration; /* default OFTrue */
 
 /** Global flag to enable/disable the generation of VR=OD, which has been
  *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UN (if enabled) or alternatively VR=OB is used.
  */
-extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherDoubleStringVRGeneration; /* default OFTrue */
+extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherDoubleVRGeneration; /* default OFTrue */
+
+/** Global flag to enable/disable the generation of VR=OL, which has been
+ *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UN (if enabled) or alternatively VR=OB is used.
+ */
+extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherLongVRGeneration; /* default OFTrue */
+
+/** Global flag to enable/disable the generation of VR=UR, which has been
+ *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UT (if enabled), VR=UN (if enabled) or alternatively
+ *  VR=OB is used.
+ */
+extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableUniversalResourceIdentifierOrLocatorVRGeneration; /* default OFTrue */
+
+/** Global flag to enable/disable the generation of VR=UC, which has been
+ *  introduced after the first edition of the DICOM standard (1993).
+ *  If disabled, the VR=UN (if enabled) or alternatively VR=OB is used.
+ */
+extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableUnlimitedCharactersVRGeneration; /* default OFTrue */
 
 /** Global flag to enable/disable the automatic re-conversion of defined
  *  length UN elements read in an explicit VR transfer syntax, if the real
@@ -52,6 +81,20 @@ extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableOtherDoubleStringVRGenerat
  */
 extern DCMTK_DCMDATA_EXPORT OFGlobal<OFBool> dcmEnableUnknownVRConversion; /* default OFFalse */
 
+
+/** Global function that enables the generation of "new" value representations,
+ *  i.e. the ones that have been introduced after the first edition of the DICOM
+ *  standard (1993). See above dcmEnableXXXVRGeneration() flags for details.
+ */
+DCMTK_DCMDATA_EXPORT void dcmEnableGenerationOfNewVRs();
+
+/** Global function that disables the generation of "new" value representations,
+ *  i.e. the ones that have been introduced after the first edition of the DICOM
+ *  standard (1993). See above dcmEnableXXXVRGeneration() flags for details.
+ */
+DCMTK_DCMDATA_EXPORT void dcmDisableGenerationOfNewVRs();
+
+
 /*
 ** VR Enumerations.
 ** NB: The order of entries has to conform to the order in DcmVRDict (see dcmvr.cc)!
@@ -95,16 +138,19 @@ enum DcmEVR
     /// long text
     EVR_LT,
 
-    /// other byte string
+    /// other byte
     EVR_OB,
 
-    /// other double string
+    /// other double
     EVR_OD,
 
-    /// other float string
+    /// other float
     EVR_OF,
 
-    /// other word string
+    /// other long
+    EVR_OL,
+
+    /// other word
     EVR_OW,
 
     /// person name
@@ -128,12 +174,18 @@ enum DcmEVR
     /// time string
     EVR_TM,
 
+    /// unlimited characters
+    EVR_UC,
+
     /// unique identifier
     EVR_UI,
 
     /// unsigned long
     EVR_UL,
 
+    /// universal resource identifier or universal resource locator (URI/URL)
+    EVR_UR,
+
     /// unsigned short
     EVR_US,
 
