@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2007-2013, OFFIS e.V.
+ *  Copyright (C) 2007-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -688,7 +688,7 @@ OFString I2DJpegSource::jpegMarkerToString(const E_JPGMARKER& marker)
 /* Read one byte, testing for EOF */
 int I2DJpegSource::read1Byte(Uint8& result)
 {
-  register int c;
+  int c;
   c = jpegFile.fgetc();
   if (c == EOF)
     return EOF;
