@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -127,6 +127,61 @@ DcmByteString &DcmByteString::operator=(const DcmByteString &obj)
 }
 
 
+int DcmByteString::compare(const DcmElement& rhs) const
+{
+    int result = DcmElement::compare(rhs);
+    if (result != 0)
+    {
+        return result;
+    }
+
+    /* cast away constness (dcmdata is not const correct...) */
+    DcmByteString* myThis = NULL;
+    DcmByteString* myRhs = NULL;
+    myThis = OFconst_cast(DcmByteString*, this);
+    myRhs = OFstatic_cast(DcmByteString*, OFconst_cast(DcmElement*, &rhs));
+
+    /* iterate over all components and test equality */
+    unsigned long thisVM = myThis->getVM();
+    for (unsigned long count = 0; count < thisVM; count++)
+    {
+        OFString val;
+        if (myThis->getOFString(val, count).good())
+        {
+            OFString rhsVal;
+            if (myRhs->getOFString(rhsVal, count).good())
+            {
+                result = val.compare(rhsVal);
+                if (result != 0)
+                {
+                    return result;
+                }
+            }
+            else
+            {
+                break; // values equal until this point (rhs shorter)
+            }
+        }
+    }
+
+    /* we get here if all values are equal. Now look at the number of components. */
+    unsigned long rhsVM = myRhs->getVM();
+    if (thisVM < rhsVM)
+    {
+        return -1;
+    }
+    else if (thisVM > rhsVM)
+    {
+        return 1;
+    }
+
+    /* all values as well as VM equal: objects are equal */
+    return 0;
+}
+
+
+
+
 OFCondition DcmByteString::copyFrom(const DcmObject& rhs)
 {
     if (this != &rhs)
@@ -498,7 +553,15 @@ Uint8 *DcmByteString::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField + 2];
 #else
-        value = new Uint8[lengthField + 2];
+        /* make sure that the pointer is set to NULL in case of error */
+        try
+        {
+            value = new Uint8[lengthField + 2];
+        }
+        catch (STD_NAMESPACE bad_alloc const &)
+        {
+            value = NULL;
+        }
 #endif
 
         /* terminate string after real length */
@@ -519,7 +582,15 @@ Uint8 *DcmByteString::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField + 1];
 #else
-        value = new Uint8[lengthField + 1];
+        /* make sure that the pointer is set to NULL in case of error */
+        try
+        {
+            value = new Uint8[lengthField + 1];
+        }
+        catch (STD_NAMESPACE bad_alloc const &)
+        {
+            value = NULL;
+        }
 #endif
     }
     /* make sure that the string is properly terminated by a 0 byte */
@@ -619,6 +690,7 @@ OFCondition DcmByteString::verify(const OFBool autocorrect)
 
 OFBool DcmByteString::containsExtendedCharacters(const OFBool checkAllStrings)
 {
+    OFBool result = OFFalse;
     /* only check if parameter is true since derived VRs are not affected
        by the attribute SpecificCharacterSet (0008,0005) */
     if (checkAllStrings)
@@ -626,18 +698,10 @@ OFBool DcmByteString::containsExtendedCharacters(const OFBool checkAllStrings)
         char *str = NULL;
         Uint32 len = 0;
         /* determine length in order to support possibly embedded NULL bytes */
-        if (getString(str, len).good() && (str != NULL))
-        {
-            const char *p = str;
-            for (Uint32 i = 0; i < len; i++)
-            {
-                /* check for 8 bit characters */
-                if (OFstatic_cast(unsigned char, *p++) > 127)
-                    return OFTrue;
-            }
-        }
+        if (getString(str, len).good())
+            result = containsExtendedCharacters(str, len);
     }
-    return OFFalse;
+    return result;
 }
 
 
@@ -730,6 +794,25 @@ void normalizeString(OFString &string,
 // ********************************
 
 
+OFBool DcmByteString::containsExtendedCharacters(const char *stringVal,
+                                                 const size_t stringLen)
+{
+    if (stringVal != NULL)
+    {
+        for (size_t i = stringLen; i != 0; --i)
+        {
+            /* check for 8 bit characters */
+            if (OFstatic_cast(unsigned char, *stringVal++) > 127)
+                return OFTrue;
+        }
+    }
+    return OFFalse;
+}
+
+
+// ********************************
+
+
 OFCondition DcmByteString::checkStringValue(const OFString &value,
                                             const OFString &vm,
                                             const OFString &vr,
@@ -749,12 +832,21 @@ OFCondition DcmByteString::checkStringValue(const OFString &value,
                 result = EC_MaximumLengthViolated;
             else if (dcmEnableVRCheckerForStringValues.get())
             {
-                /* currently, the VR checker only supports ASCII and Latin-1 */
-                if (charset.empty() || (charset == "ISO_IR 6") || (charset == "ISO_IR 100"))
+                /* check for non-ASCII characters (if default character set used) */
+                if (charset.empty() || (charset == "ISO_IR 6"))
                 {
-                    /* check value representation */
-                    if (DcmElement::scanValue(value, vr) != vrID)
-                        result = EC_ValueRepresentationViolated;
+                    if (containsExtendedCharacters(value.c_str(), value.length()))
+                        result = EC_InvalidCharacter;
+                }
+                if (result.good())
+                {
+                    /* currently, the VR checker only supports ASCII and Latin-1 */
+                    if (charset.empty() || (charset == "ISO_IR 6") || (charset == "ISO_IR 100"))
+                    {
+                        /* check value representation (VR) */
+                        if (DcmElement::scanValue(value, vr) != vrID)
+                            result = EC_ValueRepresentationViolated;
+                    }
                 }
             }
         } else {
@@ -775,10 +867,19 @@ OFCondition DcmByteString::checkStringValue(const OFString &value,
                 }
                 else if (dcmEnableVRCheckerForStringValues.get())
                 {
+                    /* check for non-ASCII characters (if default character set used) */
+                    if (charset.empty() || (charset == "ISO_IR 6"))
+                    {
+                        if (containsExtendedCharacters(value.c_str() + posStart, length))
+                        {
+                            result = EC_InvalidCharacter;
+                            break;
+                        }
+                    }
                     /* currently, the VR checker only supports ASCII and Latin-1 */
                     if (charset.empty() || (charset == "ISO_IR 6") || (charset == "ISO_IR 100"))
                     {
-                        /* check value representation */
+                        /* check value representation (VR) */
                         if (DcmElement::scanValue(value, vr, posStart, length) != vrID)
                         {
                             result = EC_ValueRepresentationViolated;
@@ -790,7 +891,7 @@ OFCondition DcmByteString::checkStringValue(const OFString &value,
             }
             if (result.good())
             {
-                /* check value multiplicity */
+                /* check value multiplicity (VM) */
                 result = DcmElement::checkVM(vmNum, vm);
             }
         }
