@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -34,8 +34,8 @@
 //
 // If the extension for > 8 bit character sets will be implemented this class
 // must be derived directly from DcmElement. This class is designed to support
-// the value representations (LO, LT, PN, SH, ST, UT). They are a problem because
-// their value width (1, 2, .. Bytes) is specified by the element
+// the value representations (LO, LT, PN, SH, ST, UC and UT). They are a problem
+// because their value width (1, 2, ... bytes) is specified by the element
 // SpecificCharacterSet (0008, 0005) and an implementation must support
 // different value widths that cannot be derived from the value representation.
 //
@@ -121,7 +121,7 @@ OFCondition DcmCharString::verify(const OFBool autocorrect)
                     errorFlag = EC_MaximumLengthViolated;
                     if (autocorrect)
                     {
-                        /*  We are currently not removing any charaters since we do not know
+                        /*  We are currently not removing any characters since we do not know
                          *  whether a character consists of one or more bytes.  This will be
                          *  fixed in a future version.
                          */
@@ -147,20 +147,13 @@ OFCondition DcmCharString::verify(const OFBool autocorrect)
 
 OFBool DcmCharString::containsExtendedCharacters(const OFBool /*checkAllStrings*/)
 {
+    OFBool result = OFFalse;
     char *str = NULL;
     Uint32 len = 0;
     /* determine length in order to support possibly embedded NULL bytes */
-    if (getString(str, len).good() && (str != NULL))
-    {
-        const char *p = str;
-        for (Uint32 i = 0; i < len; i++)
-        {
-            /* check for 8 bit characters */
-            if (OFstatic_cast(unsigned char, *p++) > 127)
-                return OFTrue;
-        }
-    }
-    return OFFalse;
+    if (getString(str, len).good())
+        result = DcmByteString::containsExtendedCharacters(str, len);
+    return result;
 }
 
 
