@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -101,7 +101,9 @@ static const char *DRTypeNames[] =
     "IMPLANT GROUP",
     "IMPLANT ASSY",
     "PLAN",
-    "SURFACE SCAN"
+    "SURFACE SCAN",
+    "TRACT",
+    "ASSESSMENT"
 };
 
 static const short DIM_OF_DRTypeNames = OFstatic_cast(short, (sizeof(DRTypeNames) / sizeof(DRTypeNames[0])));
@@ -111,7 +113,7 @@ static const short DIM_OF_DRTypeNames = OFstatic_cast(short, (sizeof(DRTypeNames
 
 
 DcmDirectoryRecord::DcmDirectoryRecord()
-  : DcmItem(ItemTag),
+  : DcmItem(DCM_ItemTag),
     recordsOriginFile(),
     lowerLevelList(new DcmSequenceOfItems(DCM_DirectoryRecordSequence)),
     DirRecordType(ERT_Private),
@@ -145,7 +147,7 @@ DcmDirectoryRecord::DcmDirectoryRecord(const E_DirRecType recordType,
                                        const char *referencedFileID,
                                        const OFFilename &sourceFilename,
                                        DcmFileFormat *fileFormat)
-  : DcmItem(ItemTag),
+  : DcmItem(DCM_ItemTag),
     recordsOriginFile(),
     lowerLevelList(new DcmSequenceOfItems(DCM_DirectoryRecordSequence)),
     DirRecordType(recordType),
@@ -167,7 +169,7 @@ DcmDirectoryRecord::DcmDirectoryRecord(const char *recordTypeName,
                                        const char *referencedFileID,
                                        const OFFilename &sourceFilename,
                                        DcmFileFormat *fileFormat)
-  : DcmItem(ItemTag),
+  : DcmItem(DCM_ItemTag),
     recordsOriginFile(),
     lowerLevelList(new DcmSequenceOfItems(DCM_DirectoryRecordSequence)),
     DirRecordType(ERT_Private),
@@ -341,7 +343,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_FilmBox:
+        case ERT_FilmBox:  // retired
             switch (lowerRecord)
             {
                 case ERT_ImageBox:
@@ -353,7 +355,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_FilmSession:
+        case ERT_FilmSession:  // retired
             switch (lowerRecord)
             {
                 case ERT_FilmBox:
@@ -378,7 +380,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_PrintQueue:
+        case ERT_PrintQueue:  // retired
             switch (lowerRecord)
             {
                 case ERT_FilmSession:
@@ -390,7 +392,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_Results:
+        case ERT_Results:  // retired
             switch (lowerRecord)
             {
                 case ERT_Interpretation:
@@ -430,6 +432,8 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                 case ERT_Measurement:
                 case ERT_Plan:
                 case ERT_SurfaceScan:
+                case ERT_Tract:
+                case ERT_Assessment:
                 case ERT_Private:
                     l_error = EC_Normal;
                     break;
@@ -454,7 +458,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_Topic:
+        case ERT_Topic:  // retired
             switch (lowerRecord)
             {
                 case ERT_Curve:
@@ -486,7 +490,7 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
                     break;
             }
             break;
-        case ERT_Mrdr:
+        case ERT_Mrdr:  // retired
             l_error = EC_IllegalCall;
             break;
         case ERT_Curve:
@@ -524,6 +528,8 @@ OFCondition DcmDirectoryRecord::checkHierarchy(const E_DirRecType upperRecord,
         case ERT_ImplantAssy:
         case ERT_Plan:
         case ERT_SurfaceScan:
+        case ERT_Tract:
+        case ERT_Assessment:
         case ERT_Private:
             switch (lowerRecord)
             {
@@ -593,7 +599,7 @@ E_DirRecType DcmDirectoryRecord::lookForRecordType()
 static void hostToDicomFilename(char *fname)
 {
     /*
-    ** Massage filename into dicom format.
+    ** Massage filename into DICOM format.
     ** Eliminate any invalid characters.
     ** Most commonly there is a '.' at the end of a filename.
     */
@@ -1239,7 +1245,7 @@ void DcmDirectoryRecord::print(STD_NAMESPACE ostream&out,
         if (lowerLevelList->card() > 0)
             lowerLevelList->print(out, flags, level + 1);
         /* print record end line */
-        DcmTag delimItemTag(DCM_ItemDelimitationItem);
+        DcmTag delimItemTag(DCM_ItemDelimitationItemTag);
         if (getLengthField() == DCM_UndefinedLength)
             printInfoLine(out, flags, level, "\"ItemDelimitationItem\"", &delimItemTag);
         else
@@ -1254,10 +1260,11 @@ void DcmDirectoryRecord::print(STD_NAMESPACE ostream&out,
 OFCondition DcmDirectoryRecord::writeXML(STD_NAMESPACE ostream &out,
                                          const size_t flags)
 {
+    OFCondition l_error = EC_Normal;
     if (flags & DCMTypes::XF_useNativeModel)
     {
         /* in Native DICOM Model, there is no concept of a DICOMDIR */
-        return makeOFCondition(OFM_dcmdata, EC_CODE_CannotConvertToXML, OF_error,
+        l_error = makeOFCondition(OFM_dcmdata, EC_CODE_CannotConvertToXML, OF_error,
             "Cannot convert Directory Record to Native DICOM Model");
     } else {
         /* XML start tag for "item" */
@@ -1278,16 +1285,18 @@ OFCondition DcmDirectoryRecord::writeXML(STD_NAMESPACE ostream &out,
             elementList->seek(ELP_first);
             do {
                 dO = elementList->get();
-                dO->writeXML(out, flags);
-            } while (elementList->seek(ELP_next));
+                l_error = dO->writeXML(out, flags);
+            } while (l_error.good() && elementList->seek(ELP_next));
+        }
+        if (l_error.good())
+        {
+            if (lowerLevelList->card() > 0)
+                lowerLevelList->writeXML(out, flags);
+            /* XML end tag for "item" */
+            out << "</item>" << OFendl;
         }
-        if (lowerLevelList->card() > 0)
-            lowerLevelList->writeXML(out, flags);
-        /* XML end tag for "item" */
-        out << "</item>" << OFendl;
-        /* always report success */
-        return EC_Normal;
     }
+    return l_error;
 }
 
 
