@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -203,7 +203,7 @@ int DcmSequenceOfItems::compare(const DcmElement& rhs) const
             DcmItem* rhsVal = myRhs->getItem(count);
             if (rhsVal)
             {
-                int result = val->compare(*rhsVal);
+                result = val->compare(*rhsVal);
                 if (result != 0)
                 {
                     return result;
@@ -290,7 +290,7 @@ void DcmSequenceOfItems::print(STD_NAMESPACE ostream&out,
             } while (itemList->seek(ELP_next));
         }
         /* print sequence end line */
-        DcmTag delimItemTag(DCM_SequenceDelimitationItem);
+        DcmTag delimItemTag(DCM_SequenceDelimitationItemTag);
         if (getLengthField() == DCM_UndefinedLength)
             printInfoLine(out, flags, level, "(SequenceDelimitationItem)", &delimItemTag);
         else
@@ -305,6 +305,7 @@ void DcmSequenceOfItems::print(STD_NAMESPACE ostream&out,
 OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
                                          const size_t flags)
 {
+    OFCondition l_error = EC_Normal;
     if (flags & DCMTypes::XF_useNativeModel)
     {
         /* use common method from DcmElement to write start tag */
@@ -320,12 +321,17 @@ OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
             {
                 out << "<Item number=\"" << (itemNo++) << "\">" << OFendl;
                 dO = itemList->get();
-                dO->writeXML(out, flags);
+                l_error = dO->writeXML(out, flags);
+                /* exit loop in case of error */
+                if (l_error.bad()) break;
                 out << "</Item>" << OFendl;
             } while (itemList->seek(ELP_next));
         }
-        /* use common method from DcmElement to write end tag */
-        DcmElement::writeXMLEndTag(out, flags);
+        if (l_error.good())
+        {
+            /* use common method from DcmElement to write end tag */
+            DcmElement::writeXMLEndTag(out, flags);
+        }
     } else {
         OFString xmlString;
         DcmVR vr(getTag().getVR());
@@ -357,14 +363,16 @@ OFCondition DcmSequenceOfItems::writeXML(STD_NAMESPACE ostream&out,
             do
             {
                 dO = itemList->get();
-                dO->writeXML(out, flags);
-            } while (itemList->seek(ELP_next));
+                l_error = dO->writeXML(out, flags);
+            } while (l_error.good() && itemList->seek(ELP_next));
+        }
+        if (l_error.good())
+        {
+            /* XML end tag for "sequence" */
+            out << "</sequence>" << OFendl;
         }
-        /* XML end tag for "sequence" */
-        out << "</sequence>" << OFendl;
     }
-    /* always report success */
-    return EC_Normal;
+    return l_error;
 }
 
 
@@ -546,7 +554,7 @@ OFCondition DcmSequenceOfItems::readTagAndLength(DcmInputStream &inStream,
         inStream.read(&elementTag, 2);
         swapIfNecessary(gLocalByteOrder, iByteOrder, &groupTag, 2, 2);
         swapIfNecessary(gLocalByteOrder, iByteOrder, &elementTag, 2, 2);
-        // tag has ben read
+        // tag has been read
 
         DcmTag newTag(groupTag, elementTag);
 
@@ -787,13 +795,13 @@ OFCondition DcmSequenceOfItems::write(DcmOutputStream &outStream,
                         if (outStream.avail() >= 8)
                         {
                             // write sequence delimitation item
-                            DcmTag delim(DCM_SequenceDelimitationItem);
+                            const DcmTag delim(DCM_SequenceDelimitationItemTag);
                             errorFlag = writeTag(outStream, delim, oxfer);
                             Uint32 delimLen = 0L;
                             outStream.write(&delimLen, 4); // 4 bytes length
                         } else {
                             // the complete sequence is written but it
-                            // is not possible to write the delimination item into the buffer.
+                            // is not possible to write the delimitation item into the buffer.
                             errorFlag = EC_StreamNotifyClient;
                             setTransferState(ERW_inWork);
                         }
@@ -907,11 +915,11 @@ OFCondition DcmSequenceOfItems::writeSignatureFormat(DcmOutputStream &outStream,
                     if (outStream.avail() >= 4)
                     {
                         // write sequence delimitation item
-                        DcmTag delim(DCM_SequenceDelimitationItem);
+                        const DcmTag delim(DCM_SequenceDelimitationItemTag);
                         errorFlag = writeTag(outStream, delim, oxfer);
                     } else {
                         // Every subelement of the item was written but it
-                        // is not possible to write the delimination item
+                        // is not possible to write the delimitation item
                         // into the buffer.
                         setTransferState(ERW_inWork);
                         errorFlag = EC_StreamNotifyClient;
