@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -126,6 +126,9 @@ static const UIDNameMap uidNameMap[] = {
     { UID_MPEG2MainProfileAtHighLevelTransferSyntax,           "MPEG2MainProfile@HighLevel" },
     { UID_MPEG4HighProfileLevel4_1TransferSyntax,              "MPEG4HighProfile/Level4.1" },
     { UID_MPEG4BDcompatibleHighProfileLevel4_1TransferSyntax,  "MPEG4BDcompatibleHighProfile/Level4.1" },
+    { UID_MPEG4HighProfileLevel4_2_For2DVideoTransferSyntax,   "MPEG4HighProfile/Level4.2For2DVideo" },
+    { UID_MPEG4HighProfileLevel4_2_For3DVideoTransferSyntax,   "MPEG4HighProfile/Level4.2For3DVideo" },
+    { UID_MPEG4StereoHighProfileLevel4_2TransferSyntax,        "MPEG4StereoHighProfile/Level4.2" },
     { UID_JPEG2000Part2MulticomponentImageCompressionLosslessOnlyTransferSyntax, "JPEG2000MulticomponentLosslessOnly" },
     { UID_JPEG2000Part2MulticomponentImageCompressionTransferSyntax,             "JPEG2000Multicomponent" },
     { UID_JPIPReferencedTransferSyntax,                        "JPIPReferenced" },
@@ -133,7 +136,8 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RFC2557MIMEEncapsulationTransferSyntax,              "RFC2557MIMEEncapsulation" },
     { UID_XMLEncodingTransferSyntax,                           "XMLEncoding" },
 
-    // Storage
+    // Storage (DICOM)
+    { UID_AcquisitionContextSRStorage,                         "AcquisitionContextSRStorage" },
     { UID_AmbulatoryECGWaveformStorage,                        "AmbulatoryECGWaveformStorage" },
     { UID_ArterialPulseWaveformStorage,                        "ArterialPulseWaveformStorage" },
     { UID_AutorefractionMeasurementsStorage,                   "AutorefractionMeasurementsStorage" },
@@ -148,9 +152,11 @@ static const UIDNameMap uidNameMap[] = {
     { UID_ChestCADSRStorage,                                   "ChestCADSRStorage" },
     { UID_ColonCADSRStorage,                                   "ColonCADSRStorage" },
     { UID_ColorSoftcopyPresentationStateStorage,               "ColorSoftcopyPresentationStateStorage" },
+    { UID_CompositingPlanarMPRVolumetricPresentationStateStorage, "CompositingPlanarMPRVolumetricPresentationStateStorage" },
     { UID_Comprehensive3DSRStorage,                            "Comprehensive3DSRStorage" },
     { UID_ComprehensiveSRStorage,                              "ComprehensiveSRStorage" },
     { UID_ComputedRadiographyImageStorage,                     "ComputedRadiographyImageStorage" },
+    { UID_ContentAssessmentResultsStorage,                     "ContentAssessmentResultsStorage" },
     { UID_CornealTopographyMapStorage,                         "CornealTopographyMapStorage" },
     { UID_CTImageStorage,                                      "CTImageStorage" },
     { UID_DeformableSpatialRegistrationStorage,                "DeformableSpatialRegistrationStorage" },
@@ -170,9 +176,11 @@ static const UIDNameMap uidNameMap[] = {
     { UID_EnhancedUSVolumeStorage,                             "EnhancedUSVolumeStorage" },
     { UID_EnhancedXAImageStorage,                              "EnhancedXAImageStorage" },
     { UID_EnhancedXRFImageStorage,                             "EnhancedXRFImageStorage" },
+    { UID_ExtensibleSRStorage,                                 "ExtensibleSRStorage" },
     { UID_GeneralAudioWaveformStorage,                         "GeneralAudioWaveformStorage" },
     { UID_GeneralECGWaveformStorage,                           "GeneralECGWaveformStorage" },
     { UID_GenericImplantTemplateStorage,                       "GenericImplantTemplateStorage" },
+    { UID_GrayscalePlanarMPRVolumetricPresentationStateStorage, "GrayscalePlanarMPRVolumetricPresentationStateStorage" },
     { UID_GrayscaleSoftcopyPresentationStateStorage,           "GrayscaleSoftcopyPresentationStateStorage" },
     { UID_HangingProtocolStorage,                              "HangingProtocolStorage" },
     { UID_HemodynamicWaveformStorage,                          "HemodynamicWaveformStorage" },
@@ -212,7 +220,9 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RawDataStorage,                                      "RawDataStorage" },
     { UID_RealWorldValueMappingStorage,                        "RealWorldValueMappingStorage" },
     { UID_RespiratoryWaveformStorage,                          "RespiratoryWaveformStorage" },
+    { UID_RTBeamsDeliveryInstructionStorage,                   "RTBeamsDeliveryInstructionStorage" },
     { UID_RTBeamsTreatmentRecordStorage,                       "RTBeamsTreatmentRecordStorage" },
+    { UID_RTBrachyApplicationSetupDeliveryInstructionStorage,  "RTBrachyApplicationSetupDeliveryInstructionStorage" },
     { UID_RTBrachyTreatmentRecordStorage,                      "RTBrachyTreatmentRecordStorage" },
     { UID_RTDoseStorage,                                       "RTDoseStorage" },
     { UID_RTImageStorage,                                      "RTImageStorage" },
@@ -231,6 +241,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_SurfaceScanMeshStorage,                              "SurfaceScanMeshStorage" },
     { UID_SurfaceScanPointCloudStorage,                        "SurfaceScanPointCloudStorage" },
     { UID_SurfaceSegmentationStorage,                          "SurfaceSegmentationStorage" },
+    { UID_TractographyResultsStorage,                          "TractographyResultsStorage" },
     { UID_TwelveLeadECGWaveformStorage,                        "TwelveLeadECGWaveformStorage" },
     { UID_UltrasoundImageStorage,                              "UltrasoundImageStorage" },
     { UID_UltrasoundMultiframeImageStorage,                    "UltrasoundMultiframeImageStorage" },
@@ -271,6 +282,9 @@ static const UIDNameMap uidNameMap[] = {
     { UID_DICOS_DigitalXRayImageStorageForPresentation,        "DICOS_DigitalXRayImageStorageForPresentation" },
     { UID_DICOS_DigitalXRayImageStorageForProcessing,          "DICOS_DigitalXRayImageStorageForProcessing" },
     { UID_DICOS_ThreatDetectionReportStorage,                  "DICOS_ThreatDetectionReportStorage" },
+    { UID_DICOS_2DAITStorage,                                  "DICOS_2DAITStorage" },
+    { UID_DICOS_3DAITStorage,                                  "DICOS_3DAITStorage" },
+    { UID_DICOS_QuadrupoleResonanceStorage,                    "DICOS_QuadrupoleResonanceStorage" },
     // Storage (DICONDE)
     { UID_DICONDE_EddyCurrentImageStorage,                     "DICONDE_EddyCurrentImageStorage" },
     { UID_DICONDE_EddyCurrentMultiframeImageStorage,           "DICONDE_EddyCurrentMultiframeImageStorage" },
@@ -289,7 +303,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_MOVECompositeInstanceRootRetrieve,                         "MOVECompositeInstanceRootRetrieve" },
     { UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel, "RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel" },
 
-    // Worklist
+    // Modality Worklist
     { UID_FINDModalityWorklistInformationModel,                "FINDModalityWorklistInformationModel" },
 
     // General Purpose Worklist
@@ -303,8 +317,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_ModalityPerformedProcedureStepRetrieveSOPClass,      "ModalityPerformedProcedureStepRetrieveSOPClass" },
     { UID_ModalityPerformedProcedureStepSOPClass,              "ModalityPerformedProcedureStepSOPClass" },
 
-    // Radiotherapy Treatment Delivery
-    { UID_RTBeamsDeliveryInstructionStorage,                   "RTBeamsDeliveryInstructionStorage" },
+    // Radiotherapy
     { UID_RTConventionalMachineVerification,                   "RTConventionalMachineVerification" },
     { UID_RTIonMachineVerification,                            "RTIonMachineVerification" },
 
@@ -527,6 +540,7 @@ static const int uidNameMap_size = OFstatic_cast(int, sizeof(uidNameMap) / sizeo
  */
 
 const char* dcmAllStorageSOPClassUIDs[] = {
+    UID_AcquisitionContextSRStorage,
     UID_AmbulatoryECGWaveformStorage,
     UID_ArterialPulseWaveformStorage,
     UID_AutorefractionMeasurementsStorage,
@@ -541,9 +555,11 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_ChestCADSRStorage,
     UID_ColonCADSRStorage,
     UID_ColorSoftcopyPresentationStateStorage,
+    UID_CompositingPlanarMPRVolumetricPresentationStateStorage,
     UID_Comprehensive3DSRStorage,
     UID_ComprehensiveSRStorage,
     UID_ComputedRadiographyImageStorage,
+    UID_ContentAssessmentResultsStorage,
     UID_CornealTopographyMapStorage,
     UID_CTImageStorage,
     UID_DeformableSpatialRegistrationStorage,
@@ -563,9 +579,11 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_EnhancedUSVolumeStorage,
     UID_EnhancedXAImageStorage,
     UID_EnhancedXRFImageStorage,
+    UID_ExtensibleSRStorage,
     UID_GeneralAudioWaveformStorage,
     UID_GeneralECGWaveformStorage,
     UID_GenericImplantTemplateStorage,
+    UID_GrayscalePlanarMPRVolumetricPresentationStateStorage,
     UID_GrayscaleSoftcopyPresentationStateStorage,
     UID_HemodynamicWaveformStorage,
     UID_ImplantAssemblyTemplateStorage,
@@ -605,6 +623,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_RespiratoryWaveformStorage,
     UID_RTBeamsDeliveryInstructionStorage,
     UID_RTBeamsTreatmentRecordStorage,
+    UID_RTBrachyApplicationSetupDeliveryInstructionStorage,
     UID_RTBrachyTreatmentRecordStorage,
     UID_RTDoseStorage,
     UID_RTImageStorage,
@@ -623,6 +642,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_SurfaceScanMeshStorage,
     UID_SurfaceScanPointCloudStorage,
     UID_SurfaceSegmentationStorage,
+    UID_TractographyResultsStorage,
     UID_TwelveLeadECGWaveformStorage,
     UID_UltrasoundImageStorage,
     UID_UltrasoundMultiframeImageStorage,
@@ -670,6 +690,9 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_DICOS_DigitalXRayImageStorageForPresentation,
     UID_DICOS_DigitalXRayImageStorageForProcessing,
     UID_DICOS_ThreatDetectionReportStorage,
+    UID_DICOS_2DAITStorage,
+    UID_DICOS_3DAITStorage,
+    UID_DICOS_QuadrupoleResonanceStorage,
     // DICONDE
     UID_DICONDE_EddyCurrentImageStorage,
     UID_DICONDE_EddyCurrentMultiframeImageStorage,
@@ -794,14 +817,21 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
     UID_XRayRadiationDoseSRStorage,
     UID_XRayRadiofluoroscopicImageStorage,
     // recently approved
+//  UID_AcquisitionContextSRStorage,
 //  UID_BreastProjectionXRayImageStorageForPresentation,
 //  UID_BreastProjectionXRayImageStorageForProcessing,
+//  UID_CompositingPlanarMPRVolumetricPresentationStateStorage,
+//  UID_ContentAssessmentResultsStorage,
 //  UID_CornealTopographyMapStorage,
+//  UID_ExtensibleSRStorage,
+//  UID_GrayscalePlanarMPRVolumetricPresentationStateStorage
 //  UID_LegacyConvertedEnhancedCTImageStorage,
 //  UID_LegacyConvertedEnhancedMRImageStorage,
 //  UID_LegacyConvertedEnhancedPETImageStorage,
 //  UID_ParametricMapStorage,
 //  UID_RadiopharmaceuticalRadiationDoseSRStorage,
+//  UID_RTBrachyApplicationSetupDeliveryInstructionStorage,
+//  UID_TractographyResultsStorage,
 //  UID_WideFieldOphthalmicPhotographyStereographicProjectionImageStorage,
 //  UID_WideFieldOphthalmicPhotography3DCoordinatesImageStorage,
     // retired
@@ -831,6 +861,9 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
 //  UID_DICOS_DigitalXRayImageStorageForPresentation,
 //  UID_DICOS_DigitalXRayImageStorageForProcessing,
 //  UID_DICOS_ThreatDetectionReportStorage,
+//  UID_DICOS_2DAITStorage,
+//  UID_DICOS_3DAITStorage,
+//  UID_DICOS_QuadrupoleResonanceStorage,
     // DICONDE
 //  UID_DICONDE_EddyCurrentImageStorage,
 //  UID_DICONDE_EddyCurrentMultiframeImageStorage,
@@ -1031,6 +1064,7 @@ typedef struct {
 ** the size of an image being transmitted).
 */
 static const DcmModalityTable modalities[] = {
+    { UID_AcquisitionContextSRStorage,                             "SRa", 4096 },
     { UID_AmbulatoryECGWaveformStorage,                            "ECA", 4096 },
     { UID_ArterialPulseWaveformStorage,                            "WVa", 4096 },
     { UID_AutorefractionMeasurementsStorage,                       "OPa", 4096 },
@@ -1045,9 +1079,11 @@ static const DcmModalityTable modalities[] = {
     { UID_ChestCADSRStorage,                                       "SRh", 4096 },
     { UID_ColonCADSRStorage,                                       "SRo", 4096 },
     { UID_ColorSoftcopyPresentationStateStorage,                   "PSc", 4096 },
+    { UID_CompositingPlanarMPRVolumetricPresentationStateStorage,  "VPc", 4096 },
     { UID_Comprehensive3DSRStorage,                                "SR3", 4096 },
     { UID_ComprehensiveSRStorage,                                  "SRc", 4096 },
     { UID_ComputedRadiographyImageStorage,                         "CR",  2048 * 2048 * 2 },
+    { UID_ContentAssessmentResultsStorage,                         "AS",  4096 },
     { UID_CornealTopographyMapStorage,                             "CM",  512 * 512 },
     { UID_CTImageStorage,                                          "CT",  512 * 512 * 2 },
     { UID_DeformableSpatialRegistrationStorage,                    "RGd", 4096 },
@@ -1067,9 +1103,11 @@ static const DcmModalityTable modalities[] = {
     { UID_EnhancedUSVolumeStorage,                                 "USe", 512 * 512 },
     { UID_EnhancedXAImageStorage,                                  "XAe", 256 * 512 * 512 },
     { UID_EnhancedXRFImageStorage,                                 "RFe", 256 * 512 * 512 },
+    { UID_ExtensibleSRStorage,                                     "SRx", 4096 },
     { UID_GeneralAudioWaveformStorage,                             "AUG", 4096 },
     { UID_GeneralECGWaveformStorage,                               "ECG", 4096 },
     { UID_GenericImplantTemplateStorage,                           "IT",  4096 },
+    { UID_GrayscalePlanarMPRVolumetricPresentationStateStorage,    "VPg", 4096 },
     { UID_GrayscaleSoftcopyPresentationStateStorage,               "PSg", 4096 },
     { UID_HemodynamicWaveformStorage,                              "WVh", 4096 },
     { UID_ImplantAssemblyTemplateStorage,                          "ITa", 4096 },
@@ -1109,6 +1147,7 @@ static const DcmModalityTable modalities[] = {
     { UID_RespiratoryWaveformStorage,                              "WVr", 4096 },
     { UID_RTBeamsDeliveryInstructionStorage,                       "RTd", 4096 },
     { UID_RTBeamsTreatmentRecordStorage,                           "RTb", 4096 },
+    { UID_RTBrachyApplicationSetupDeliveryInstructionStorage,      "RTa", 4096 },
     { UID_RTBrachyTreatmentRecordStorage,                          "RTr", 4096 },
     { UID_RTDoseStorage,                                           "RD",  4096 },
     { UID_RTImageStorage,                                          "RI",  4096 },
@@ -1127,6 +1166,7 @@ static const DcmModalityTable modalities[] = {
     { UID_SurfaceScanMeshStorage,                                  "SSm", 4096 },
     { UID_SurfaceScanPointCloudStorage,                            "SSp", 4096 },
     { UID_SurfaceSegmentationStorage,                              "SGs", 4096 },
+    { UID_TractographyResultsStorage,                              "TR",  4096 },
     { UID_TwelveLeadECGWaveformStorage,                            "TLE", 4096 },
     { UID_UltrasoundImageStorage,                                  "US",  512 * 512 },
     { UID_UltrasoundMultiframeImageStorage,                        "USm", 512 * 512 },
@@ -1164,16 +1204,19 @@ static const DcmModalityTable modalities[] = {
     { UID_RETIRED_XRayAngiographicBiPlaneImageStorage,             "XB",  512 * 512 * 2 },
     // draft
     { UID_DRAFT_RTBeamsDeliveryInstructionStorage,                 "RBd", 4096 },
-    { UID_DRAFT_SRAudioStorage,                                    "SRw", 4096 },
-    { UID_DRAFT_SRComprehensiveStorage,                            "SRx", 4096 },
-    { UID_DRAFT_SRDetailStorage,                                   "SRy", 4096 },
-    { UID_DRAFT_SRTextStorage,                                     "SRz", 4096 },
+    { UID_DRAFT_SRAudioStorage,                                    "SR_", 4096 },  /* was "SRw" */
+    { UID_DRAFT_SRComprehensiveStorage,                            "SR_", 4096 },  /* was "SRx" */
+    { UID_DRAFT_SRDetailStorage,                                   "SR_", 4096 },  /* was "SRy" */
+    { UID_DRAFT_SRTextStorage,                                     "SR_", 4096 },  /* was "SRz" */
     { UID_DRAFT_WaveformStorage,                                   "WVd", 4096 },
     // DICOS
     { UID_DICOS_CTImageStorage,                                    "CTs", 512 * 512 * 2 },
     { UID_DICOS_DigitalXRayImageStorageForPresentation,            "DXs", 2048 * 2048 * 2 },
     { UID_DICOS_DigitalXRayImageStorageForProcessing,              "DPs", 2048 * 2048 * 2 },
     { UID_DICOS_ThreatDetectionReportStorage,                      "TDR", 4096 },
+    { UID_DICOS_2DAITStorage,                                      "AI2", 4096 },
+    { UID_DICOS_3DAITStorage,                                      "AI3", 4096 },
+    { UID_DICOS_QuadrupoleResonanceStorage,                        "QR",  4096 },
     // DICONDE
     { UID_DICONDE_EddyCurrentImageStorage,                         "EC",  512 * 512 },
     { UID_DICONDE_EddyCurrentMultiframeImageStorage,               "ECm", 512 * 512 }
@@ -1357,22 +1400,12 @@ typedef bool(WINAPI *pSnmpExtensionInit) (
         OUT HANDLE *hPollForTrapEvent,
         OUT AsnObjectIdentifier *supportedView);
 
-typedef bool(WINAPI *pSnmpExtensionTrap) (
-        OUT AsnObjectIdentifier *enterprise,
-        OUT AsnInteger32 *genericTrap,
-        OUT AsnInteger32 *specificTrap,
-        OUT AsnTimeticks *timeStamp,
-        OUT SnmpVarBindList *variableBindings);
-
 typedef bool(WINAPI *pSnmpExtensionQuery) (
         IN BYTE requestType,
         IN OUT SnmpVarBindList *variableBindings,
         OUT AsnInteger32 *errorStatus,
         OUT AsnInteger32 *errorIndex);
 
-typedef bool(WINAPI *pSnmpExtensionInitEx) (
-        OUT AsnObjectIdentifier *supportedView);
-
 typedef struct _ASTAT_
 {
     ADAPTER_STATUS adapt;
@@ -1439,7 +1472,6 @@ static unsigned char *getMACAddress(unsigned char buffer[6])
                 UINT OID_ipMACEntAddr[] = {1, 3, 6, 1, 2, 1, 2, 2, 1, 6};
                 AsnObjectIdentifier MIB_ifMACEntAddr = {sizeof(OID_ipMACEntAddr) / sizeof(UINT), OID_ipMACEntAddr};
                 AsnObjectIdentifier MIB_ifEntryType = {sizeof(OID_ifEntryType) / sizeof(UINT), OID_ifEntryType};
-                AsnObjectIdentifier MIB_ifEntryNum = {sizeof(OID_ifEntryNum) / sizeof(UINT), OID_ifEntryNum};
                 SnmpVarBindList varBindList;
                 SnmpVarBind varBind[2];
                 AsnInteger32 errorStatus;
@@ -1449,18 +1481,12 @@ static unsigned char *getMACAddress(unsigned char buffer[6])
                 int dtmp;
                 int j = 0;
                 pSnmpExtensionInit m_Init = (pSnmpExtensionInit)GetProcAddress(m_hInst2, "SnmpExtensionInit");
-                /* pSnmpExtensionInitEx m_InitEx = (pSnmpExtensionInitEx)GetProcAddress(m_hInst2, "SnmpExtensionInitEx"); */
                 pSnmpExtensionQuery m_Query = (pSnmpExtensionQuery)GetProcAddress(m_hInst2, "SnmpExtensionQuery");
-                /* pSnmpExtensionTrap m_Trap = (pSnmpExtensionTrap)GetProcAddress(m_hInst2, "SnmpExtensionTrap"); */
                 m_Init(GetTickCount(), &PollForTrapEvent, &SupportedView);
                 /* initialize the variable list to be retrieved by m_Query */
                 varBindList.list = varBind;
                 varBind[0].name = MIB_NULL;
                 varBind[1].name = MIB_NULL;
-                /* copy in the OID to find the number of entries in the interface table */
-                varBindList.len = 1;        /* only retrieving one item */
-                m_Copy(&varBind[0].name, &MIB_ifEntryNum);
-                ret = m_Query(SNMP_PDU_GETNEXT, &varBindList, &errorStatus, &errorIndex);
                 varBindList.len = 2;
                 /* copy in the OID of ifType, the type of interface */
                 m_Copy(&varBind[0].name, &MIB_ifEntryType);
