@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2016, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -112,7 +112,16 @@ OFCondition FGUSImageDescription::setFrameType(const DcmFGTypes::E_FGUSFrameType
   value += "\\";
   value += derivedPixelContrast;
 
-  return m_FrameType.putOFStringArray(value);
+  OFCondition result;
+  if (checkValue)
+  {
+    result = DcmCodeString::checkStringValue(value, "4");
+  }
+  if (result.good())
+  {
+    result = m_FrameType.putOFStringArray(value);
+  }
+  return result;
 }
 
 
@@ -160,7 +169,7 @@ OFCondition FGUSImageDescription::read(DcmItem& item)
   DcmIODUtil::getAndCheckElementFromDataset(*seqItem, m_FrameType, "4", "1", "USImageDescriptionMacro");
   DcmIODUtil::getAndCheckElementFromDataset(*seqItem, m_VolumetricProperties, "1", "1", "USImageDescriptionMacro");
   DcmIODUtil::getAndCheckElementFromDataset(*seqItem, m_VolumeBasedCalculationTechnique, "1", "1", "USImageDescriptionMacro");
-  return result;;
+  return result;
 }
 
 
