@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2014, OFFIS e.V.
+ *  Copyright (C) 2002-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -85,7 +85,7 @@ unsigned long DcmQuantColorHashTable::addToHashTable(
   DcmQuantScaleTable scaletable;
   scaletable.createTable(maxval, newmaxval);
 
-  register DcmQuantComponent r, g, b;
+  DcmQuantComponent r, g, b;
 
   for (unsigned long ff=0; ff<frames; ff++)
   {
