@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2013, OFFIS e.V.
+ *  Copyright (C) 1996-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -196,7 +196,7 @@ class DiMonoOutputPixelTemplate
     {
         if (Data != NULL)
         {
-            register unsigned long i;
+            unsigned long i;
             for (i = 0; i < FrameSize; ++i)
                 stream << OFstatic_cast(unsigned long, Data[i]) << " ";    // typecast to resolve problems with 'char'
             return 1;
@@ -216,7 +216,7 @@ class DiMonoOutputPixelTemplate
     {
         if (Data != NULL)
         {
-            register unsigned long i;
+            unsigned long i;
             for (i = 0; i < FrameSize; ++i)
                 fprintf(stream, "%lu ", OFstatic_cast(unsigned long, Data[i]));
             return 1;
@@ -239,9 +239,9 @@ class DiMonoOutputPixelTemplate
             if (UsedValues != NULL)
             {
                 OFBitmanipTemplate<Uint8>::zeroMem(UsedValues, MaxValue + 1); // initialize array
-                register const T3 *p = Data;
-                register Uint8 *q = UsedValues;
-                register unsigned long i;
+                const T3 *p = Data;
+                Uint8 *q = UsedValues;
+                unsigned long i;
                 for (i = Count; i != 0; --i)
                     *(q + *(p++)) = 1;                                        // mark used entries
             }
@@ -336,7 +336,7 @@ class DiMonoOutputPixelTemplate
                 const DiDisplayLUT *dlut = NULL;
                 const double minvalue = vlut->getMinValue();
                 const double outrange = OFstatic_cast(double, high) - OFstatic_cast(double, low) + 1;
-                register unsigned long i;
+                unsigned long i;
                 if (minvalue == vlut->getMaxValue())                                    // LUT has only one entry or all entries are equal
                 {
                     T3 value;
@@ -372,19 +372,19 @@ class DiMonoOutputPixelTemplate
                     }
                     OFBitmanipTemplate<T3>::setMem(Data, value, Count);                 // set output pixels to LUT value
                 } else {
-                    register T2 value = 0;
+                    T2 value = 0;
                     const T2 absmin = OFstatic_cast(T2, inter->getAbsMinimum());
                     const T2 firstentry = vlut->getFirstEntry(value);                   // choose signed/unsigned method
                     const T2 lastentry = vlut->getLastEntry(value);
                     const unsigned long ocnt = OFstatic_cast(unsigned long, inter->getAbsMaxRange());  // number of LUT entries
-                    register const T1 *p = pixel + start;
-                    register T3 *q = Data;
+                    const T1 *p = pixel + start;
+                    T3 *q = Data;
                     T3 *lut = NULL;
                     if ((plut != NULL) && (plut->isValid()))                            // has presentation LUT
                     {
                         DCMIMGLE_DEBUG("applying presentation LUT transformation");
                         createDisplayLUT(dlut, disp, plut->getBits());
-                        register Uint32 value2;                                         // presentation LUT is always unsigned
+                        Uint32 value2;                                                  // presentation LUT is always unsigned
                         const Uint32 pcnt = plut->getCount();
                         const double gradient1 = OFstatic_cast(double, pcnt) / OFstatic_cast(double, vlut->getAbsMaxRange());
                         const Uint32 firstvalue = OFstatic_cast(Uint32, OFstatic_cast(double, vlut->getFirstValue()) * gradient1);
@@ -624,15 +624,15 @@ class DiMonoOutputPixelTemplate
                 const double outrange = OFstatic_cast(double, high) - OFstatic_cast(double, low) + 1;
                 const unsigned long ocnt = OFstatic_cast(unsigned long, inter->getAbsMaxRange());  // number of LUT entries
                 DCMIMGLE_TRACE("intermediate pixel data - absmin: " << absmin << ", absmax: " << absmax);
-                register const T1 *p = pixel + start;
-                register T3 *q = Data;
-                register unsigned long i;
+                const T1 *p = pixel + start;
+                T3 *q = Data;
+                unsigned long i;
                 T3 *lut = NULL;
                 if ((plut != NULL) && (plut->isValid()))                              // has presentation LUT
                 {
                     DCMIMGLE_DEBUG("applying presentation LUT transformation");
                     createDisplayLUT(dlut, disp, plut->getBits());
-                    register Uint32 value;                                            // presentation LUT is always unsigned
+                    Uint32 value;                                                     // presentation LUT is always unsigned
                     const double gradient1 = OFstatic_cast(double, plut->getCount()) / inter->getAbsMaxRange();
                     const double gradient2 = outrange / OFstatic_cast(double, plut->getAbsMaxRange());
                     if (initOptimizationLUT(lut, ocnt))
@@ -700,7 +700,7 @@ class DiMonoOutputPixelTemplate
                     }
                 } else {                                                              // has no presentation LUT
                     createDisplayLUT(dlut, disp, inter->getBits());
-                    register const double gradient = outrange / (inter->getAbsMaxRange());
+                    const double gradient = outrange / (inter->getAbsMaxRange());
                     if (initOptimizationLUT(lut, ocnt))
                     {                                                                 // use LUT for optimization
                         q = lut;
@@ -785,16 +785,16 @@ class DiMonoOutputPixelTemplate
                 const double absmin = inter->getAbsMinimum();
                 const double outrange = OFstatic_cast(double, high) - OFstatic_cast(double, low);  // output range
                 const unsigned long ocnt = OFstatic_cast(unsigned long, inter->getAbsMaxRange());  // number of LUT entries
-                register const T1 *p = pixel + start;
-                register T3 *q = Data;
-                register unsigned long i;
-                register double value;
+                const T1 *p = pixel + start;
+                T3 *q = Data;
+                unsigned long i;
+                double value;
                 T3 *lut = NULL;
                 if ((plut != NULL) && (plut->isValid()))                              // has presentation LUT
                 {
                     DCMIMGLE_DEBUG("applying presentation LUT transformation");
                     createDisplayLUT(dlut, disp, plut->getBits());
-                    register Uint32 value2;                                           // presentation LUT is always unsigned
+                    Uint32 value2;                                                    // presentation LUT is always unsigned
                     const double plutcnt_1 = OFstatic_cast(double, plut->getCount() - 1);
                     const double plutmax_1 = OFstatic_cast(double, plut->getAbsMaxRange() - 1);
                     if (initOptimizationLUT(lut, ocnt))
@@ -947,16 +947,16 @@ class DiMonoOutputPixelTemplate
                 const double rightBorder = center - 0.5 + width_1 / 2;
                 const double outrange = OFstatic_cast(double, high) - OFstatic_cast(double, low);  // output range
                 const unsigned long ocnt = OFstatic_cast(unsigned long, inter->getAbsMaxRange());  // number of LUT entries
-                register const T1 *p = pixel + start;
-                register T3 *q = Data;
-                register unsigned long i;
-                register double value;
+                const T1 *p = pixel + start;
+                T3 *q = Data;
+                unsigned long i;
+                double value;
                 T3 *lut = NULL;
                 if ((plut != NULL) && (plut->isValid()))                              // has presentation LUT
                 {
                     DCMIMGLE_DEBUG("applying presentation LUT transformation");
                     createDisplayLUT(dlut, disp, plut->getBits());
-                    register Uint32 value2;                                           // presentation LUT is always unsigned
+                    Uint32 value2;                                                    // presentation LUT is always unsigned
                     const Uint32 pcnt = plut->getCount();
                     const double plutmax_1 = OFstatic_cast(double, plut->getAbsMaxRange()) - 1;
                     const double gradient1 = (width_1 == 0) ? 0 : OFstatic_cast(double, pcnt - 1) / width_1;
@@ -1142,15 +1142,15 @@ class DiMonoOutputPixelTemplate
                         DCMIMGLE_DEBUG("applying " << ((j == 0) ? "built-in" : "additional") << " overlay planes");
                     const signed long left_pos = overlays[j]->getLeft();
                     const signed long top_pos = overlays[j]->getTop();
-                    register DiOverlayPlane *plane;
+                    DiOverlayPlane *plane;
                     for (unsigned int i = 0; i < overlays[j]->getCount(); ++i)
                     {
                         plane = overlays[j]->getPlane(i);
                         if ((plane != NULL) && plane->isVisible() && plane->reset(frame))
                         {
-                            register T3 *q;
-                            register Uint16 x;
-                            register Uint16 y;
+                            T3 *q;
+                            Uint16 x;
+                            Uint16 y;
                             const Uint16 xmin = (plane->getLeft(left_pos) > 0) ? plane->getLeft(left_pos) : 0;
                             const Uint16 ymin = (plane->getTop(top_pos) > 0) ? plane->getTop(top_pos) : 0;
                             const Uint16 xmax = (plane->getRight(left_pos) < columns) ? plane->getRight(left_pos) : columns;
@@ -1242,7 +1242,7 @@ class DiMonoOutputPixelTemplate
                                 case EMO_BitmapShutter:
                                 {
                                     DCMIMGLE_DEBUG("applying overlay plane " << (i + 1) << " with 'bitmap shutter' mode");
-                                    register T3 fore = OFstatic_cast(T3, OFstatic_cast(double, maxvalue) * OFstatic_cast(double, plane->getPValue()) / OFstatic_cast(double, DicomImageClass::maxval(WIDTH_OF_PVALUES)));
+                                    T3 fore = OFstatic_cast(T3, OFstatic_cast(double, maxvalue) * OFstatic_cast(double, plane->getPValue()) / OFstatic_cast(double, DicomImageClass::maxval(WIDTH_OF_PVALUES)));
                                     if ((disp != NULL) && (disp->isValid()))
                                     {
                                         const DiDisplayLUT *dlut = disp->getLookupTable(WIDTH_OF_PVALUES);
