@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2016, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -36,7 +36,6 @@
 #include "dcmtk/dcmdata/dcitem.h"
 
 
-
 // --- static helpers ---
 
 OFCondition DcmIODUtil::getAndCheckElementFromDataset(DcmItem &dataset,
@@ -166,33 +165,38 @@ OFCondition DcmIODUtil::addElementToDataset(OFCondition &result,
         {
           delem = newDicomElement(rule->getTagKey());
           if (delem == NULL)
-            return EC_MemoryExhausted;
+          {
+            result = EC_MemoryExhausted;
+            return result;
+          };
         } else if (type != "1")
         {
-          // Not type 1 or type 2 means the is type 1C,2C or 3. For those it is
+          // Not type 1 or type 2 means the is type 1C, 2C or 3. For those it is
           // fine to not insert anything
           return EC_Normal;
         }
         else
         {
           // type 1 is missing
-          DCMIOD_WARN(DcmTag(rule->getTagKey()).getTagName() << " " << rule->getTagKey() << " absent in " << rule->getModule() << " (type " << rule->getType() << ")");
-          return IOD_EC_MissingAttribute;
+          DCMIOD_ERROR(DcmTag(rule->getTagKey()).getTagName() << " " << rule->getTagKey() << " absent in " << rule->getModule() << " (type " << rule->getType() << ")");
+          result = IOD_EC_MissingAttribute;
+          return result;
         }
       }
-
-      // We have an element at this position, check its value
+      // At this point, we certainly have an element. Check its value (empty ok for type 2)
       if ((type == "2") || !delem->isEmpty())
       {
-        /* insert non-empty element or empty "type 2" element */
-        result = dataset.insert(delem, OFTrue /*replaceOld*/);
-        checkElementValue(*delem, rule->getVM(), type, result, rule->getModule().c_str());
+        result = checkElementValue(*delem, rule->getVM(), type, result, rule->getModule().c_str());
+        // Insert non-empty element or empty "type 2" element
         if (result.good())
-          insertionOK = OFTrue;
+        {
+          result = dataset.insert(delem, OFTrue /*replaceOld*/);
+          if (result.good()) insertionOK = OFTrue;
+        }
       }
       else if (type == "1")
       {
-        /* empty element value not allowed for "type 1" */
+        // Empty element value not allowed for "type 1"
         result = EC_InvalidValue;
         checkElementValue(*delem, rule->getVM(), type, result, rule->getModule().c_str());
       }
@@ -249,7 +253,7 @@ OFCondition DcmIODUtil::checkElementValue(const DcmElement *delem,
     DCMIOD_WARN(tagName << " " << tagKey << " absent in " << module << " (type " << type << ")");
     result = IOD_EC_MissingAttribute;
   }
-  else if ((delem == NULL) || OFconst_cast(DcmElement*, delem)->isEmpty(OFTrue /*normalize*/))   // cast away constness of delem; value modification can happpen (eg. to remove padding)
+  else if ((delem == NULL) || OFconst_cast(DcmElement*, delem)->isEmpty(OFTrue /*normalize*/))   // cast away constness of delem; value modification can happen (eg. to remove padding)
   {
     /* however, type 1C should never be present with empty value */
     if (((type == "1") || (type == "1C")) && searchCond.good())
@@ -258,8 +262,12 @@ OFCondition DcmIODUtil::checkElementValue(const DcmElement *delem,
       result = EC_MissingValue;
     }
   } else {
-    result = OFconst_cast(DcmElement*, delem)->checkValue(vm, OFTrue /*oldFormat*/);   // cast away constness of delem; value modification can happpen (eg. to remove padding)
-    if (result == EC_ValueRepresentationViolated)
+    result = OFconst_cast(DcmElement*, delem)->checkValue(vm, OFTrue /*oldFormat*/);   // cast away constness of delem; value modification can happen (eg. to remove padding)
+    if (result == EC_InvalidCharacter)
+    {
+      DCMIOD_WARN(tagName << " " << tagKey << " contains invalid character(s) in " << module);
+    }
+    else if (result == EC_ValueRepresentationViolated)
     {
       DCMIOD_WARN(tagName << " " << tagKey << " violates VR definition in " << module);
     }
@@ -298,7 +306,7 @@ OFCondition DcmIODUtil::getStringValueFromElement(const DcmElement &delem,
                                                   const signed long pos)
 {
   OFCondition result = EC_Normal;
-  // cast away constness of delem; value modification can happpen (eg. to remove padding)
+  // cast away constness of delem; value modification can happen (eg. to remove padding)
   if (pos < 0)
     result = OFconst_cast(DcmElement &, delem).getOFStringArray(stringValue);
   else
@@ -473,7 +481,7 @@ OFCondition DcmIODUtil::getAndCheckSingleItem(DcmSequenceOfItems& seq,
   item = seq.getItem(0);
   if (item == NULL)
   {
-    DCMIOD_ERROR("Cannot read item from " << tagName << ": No item found (internal errror)");
+    DCMIOD_ERROR("Cannot read item from " << tagName << ": No item found (internal error)");
     return EC_CorruptedData;
   }
   return EC_Normal;
@@ -546,7 +554,7 @@ OFCondition DcmIODUtil::decompress(DcmDataset& dset)
   {
     if (EC_Normal != dset.chooseRepresentation(EXS_LittleEndianExplicit, NULL))
     {
-      DCMIOD_ERROR("No conversion uncompressed transfer syntax possible!");
+      DCMIOD_ERROR("No conversion to uncompressed transfer syntax possible!");
       return IOD_EC_CannotDecompress;
     }
   }
@@ -566,4 +574,4 @@ OFString DcmIODUtil::createUID(const Uint8 level)
     default: dcmGenerateUniqueIdentifier(uid, SITE_STUDY_UID_ROOT);
   }
   return uid;
-}
\ No newline at end of file
+}
