@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2016, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -65,39 +65,39 @@ OFString IODEnhUSImageModule::getName() const
 void IODEnhUSImageModule::resetRules()
 {
   // parameters are tag, VM, type. Overwrite old rules if any.
-  m_Rules->addRule(new IODRule(DCM_ImageType, "4","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_SamplesPerPixel, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "1"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_PhotometricInterpretation, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "MONOCHROME2"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_Rows, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_Columns, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_BitsAllocated, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_BitsStored, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_HighBit, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_PixelRepresentation, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "0"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_DimensionOrganizationType, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_AcquisitionDateTime, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_AcquisitionDuration, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_PixelSpacing, "2","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_PositionMeasuringDeviceUsed, "1","1C" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_LossyImageCompression, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_LossyImageCompressionRatio, "1-n","1C" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_LossyImageCompressionMethod, "1-n","1C" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_PresentationLUTShape, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "IDENTITY"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_RescaleSlope, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "1"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_RescaleIntercept, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "0"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_BurnedInAnnotation, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "NO"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_RecognizableVisualFeatures, "1","3" ,m_ModuleName, DcmIODTypes::IE_IMAGE, "NO"), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_TransducerScanPatternCodeSequence, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_TransducerGeometryCodeSequence, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_TransducerBeamSteeringCodeSequence, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_TransducerApplicationCodeSequence, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_ProcessingFunction, "1","3" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_MechanicalIndex, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_BoneThermalIndex, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_CranialThermalIndex, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_SoftTissueThermalIndex, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_DepthsOfFocus, "1-n","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
-  m_Rules->addRule(new IODRule(DCM_DepthOfScanField, "1","1" ,m_ModuleName, DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_ImageType, "4","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_SamplesPerPixel, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "1"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_PhotometricInterpretation, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "MONOCHROME2"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_Rows, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_Columns, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_BitsAllocated, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_BitsStored, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_HighBit, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_PixelRepresentation, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "0"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_DimensionOrganizationType, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_AcquisitionDateTime, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_AcquisitionDuration, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_PixelSpacing, "2","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_PositionMeasuringDeviceUsed, "1","1C" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_LossyImageCompression, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_LossyImageCompressionRatio, "1-n","1C" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_LossyImageCompressionMethod, "1-n","1C" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_PresentationLUTShape, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "IDENTITY"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_RescaleSlope, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "1"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_RescaleIntercept, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "0"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_BurnedInAnnotation, "1","1" ,getName(), DcmIODTypes::IE_IMAGE, "NO"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_RecognizableVisualFeatures, "1","3" ,getName(), DcmIODTypes::IE_IMAGE, "NO"), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_TransducerScanPatternCodeSequence, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_TransducerGeometryCodeSequence, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_TransducerBeamSteeringCodeSequence, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_TransducerApplicationCodeSequence, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_ProcessingFunction, "1","3" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_MechanicalIndex, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_BoneThermalIndex, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_CranialThermalIndex, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_SoftTissueThermalIndex, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_DepthsOfFocus, "1-n","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
+  m_Rules->addRule(new IODRule(DCM_DepthOfScanField, "1","1" ,getName(), DcmIODTypes::IE_IMAGE), OFTrue);
 }
 
 
@@ -405,7 +405,16 @@ OFCondition IODEnhUSImageModule::setImageType(const DcmIODTypes::IOD_ENHUSIMAGET
   value += "\\";
   value += derivedPixelContrast;
 
-  return m_Item->putAndInsertOFStringArray(DCM_ImageType, value);
+  OFCondition result;
+  if (checkValue)
+  {
+    result = DcmCodeString::checkStringValue(value, "2");
+  }
+  if (result.good())
+  {
+    result = m_Item->putAndInsertOFStringArray(DCM_ImageType, value);
+  }
+  return result;
 }
 
 
@@ -534,7 +543,6 @@ OFCondition IODEnhUSImageModule::setLossyImageCompression(const OFString& value,
 
 
 OFCondition IODEnhUSImageModule::setLossyImageCompressionMethod(const OFString& value,
-                                                                const unsigned long pos,
                                                                 const OFBool checkValue)
 {
   OFCondition result = (checkValue) ? DcmCodeString::checkStringValue(value, "1-n") : EC_Normal;
@@ -596,7 +604,8 @@ OFCondition IODEnhUSImageModule::setBoneThermalIndex(const OFString& value,
 }
 
 
-OFCondition IODEnhUSImageModule::setCranialThermalIndex(const OFString& value, const bool checkValue)
+OFCondition IODEnhUSImageModule::setCranialThermalIndex(const OFString& value,
+                                                        const bool checkValue)
 {
   OFCondition result = (checkValue) ? DcmDecimalString::checkStringValue(value, "1") : EC_Normal;
   if (result.good())
@@ -605,7 +614,8 @@ OFCondition IODEnhUSImageModule::setCranialThermalIndex(const OFString& value, c
 }
 
 
-OFCondition IODEnhUSImageModule::setSoftTissueThermalIndex(const OFString& value, const bool checkValue)
+OFCondition IODEnhUSImageModule::setSoftTissueThermalIndex(const OFString& value,
+                                                           const bool checkValue)
 {
   OFCondition result = (checkValue) ? DcmDecimalString::checkStringValue(value, "1") : EC_Normal;
   if (result.good())
@@ -614,14 +624,19 @@ OFCondition IODEnhUSImageModule::setSoftTissueThermalIndex(const OFString& value
 }
 
 
-OFCondition IODEnhUSImageModule::setDepthsOfFocus(const Float64 value, const long unsigned int pos, const bool checkValue)
+OFCondition IODEnhUSImageModule::setDepthsOfFocus(const Float64 value,
+                                                  const long unsigned int pos,
+                                                  const bool checkValue)
 {
+  (void)checkValue;
   return m_Item->putAndInsertFloat64(DCM_DepthsOfFocus, value, pos);
 }
 
 
-OFCondition IODEnhUSImageModule::setDepthsOfFocus(const OFVector< Float64 >& values, const bool checkValue)
+OFCondition IODEnhUSImageModule::setDepthsOfFocus(const OFVector< Float64 >& values,
+                                                  const bool checkValue)
 {
+  (void)checkValue;
   DcmElement* elem = newDicomElement(DCM_DepthsOfFocus);
   if (!elem)
     return EC_MemoryExhausted;
@@ -645,7 +660,8 @@ OFCondition IODEnhUSImageModule::setDepthsOfFocus(const OFVector< Float64 >& val
 }
 
 
-OFCondition IODEnhUSImageModule::setDepthsOfScanField(const OFString& value, const bool checkValue)
+OFCondition IODEnhUSImageModule::setDepthsOfScanField(const OFString& value,
+                                                      const bool checkValue)
 {
   OFCondition result = (checkValue) ? DcmIntegerString::checkStringValue(value, "1") : EC_Normal;
   if (result.good())
