@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2014, OFFIS e.V.
+ *  Copyright (C) 2001-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -727,6 +727,9 @@ Uint8 DJCodecDecoder::scanJpegDataForBitDepth(
       case 0xfffe: // COM
         offset += readUint16(data+offset+2)+2;
         break;
+      case 0xffff: // fill byte 0xff (skip one byte only)
+        offset += 1;
+        break;
       case 0xff01: // TEM
         break;
       default:
@@ -734,7 +737,15 @@ Uint8 DJCodecDecoder::scanJpegDataForBitDepth(
         {
           offset += 2;
         }
-        else return 0; // syntax error, stop parsing
+        else
+        {
+          DCMJPEG_ERROR("found invalid marker in JPEG stream while scanning for bit depth: 0x"
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0')
+            << STD_NAMESPACE setw(2) << OFstatic_cast(int, data[offset])
+            << STD_NAMESPACE setw(2) << OFstatic_cast(int, data[offset+1])
+            << STD_NAMESPACE dec << STD_NAMESPACE setfill(' '));
+          return 0; // syntax error, stop parsing
+        }
         break;
     }
   } // while
@@ -756,11 +767,11 @@ OFCondition DJCodecDecoder::createPlanarConfigurationByte(
   if (buf)
   {
     memcpy(buf, imageFrame, 3*numPixels);
-    register Uint8 *s = buf;                        // source
-    register Uint8 *r = imageFrame;                 // red plane
-    register Uint8 *g = imageFrame + numPixels;     // green plane
-    register Uint8 *b = imageFrame + (2*numPixels); // blue plane
-    for (register size_t i=numPixels; i; i--)
+    Uint8 *s = buf;                        // source
+    Uint8 *r = imageFrame;                 // red plane
+    Uint8 *g = imageFrame + numPixels;     // green plane
+    Uint8 *b = imageFrame + (2*numPixels); // blue plane
+    for (size_t i=numPixels; i; i--)
     {
       *r++ = *s++;
       *g++ = *s++;
@@ -785,11 +796,11 @@ OFCondition DJCodecDecoder::createPlanarConfigurationWord(
   if (buf)
   {
     memcpy(buf, imageFrame, 3*numPixels*sizeof(Uint16));
-    register Uint16 *s = buf;                        // source
-    register Uint16 *r = imageFrame;                 // red plane
-    register Uint16 *g = imageFrame + numPixels;     // green plane
-    register Uint16 *b = imageFrame + (2*numPixels); // blue plane
-    for (register size_t i=numPixels; i; i--)
+    Uint16 *s = buf;                        // source
+    Uint16 *r = imageFrame;                 // red plane
+    Uint16 *g = imageFrame + numPixels;     // green plane
+    Uint16 *b = imageFrame + (2*numPixels); // blue plane
+    for (size_t i=numPixels; i; i--)
     {
       *r++ = *s++;
       *g++ = *s++;
