@@ -1,6 +1,6 @@
-//
-// (C) Jan de Vaan 2007-2010, all rights reserved. See the accompanying "License.txt" for licensed use.
-//
+// 
+// (C) Jan de Vaan 2007-2010, all rights reserved. See the accompanying "License.txt" for licensed use. 
+// 
 
 
 #ifndef CHARLS_HEADER
@@ -24,13 +24,21 @@
 #define JPEG_APP8 0xE8 // colorXForm
 
 
+
+// Default bin sizes for JPEG-LS statistical modeling. Can be overridden at compression time, however this is rarely done.
+const int BASIC_T1		= 3;
+const int BASIC_T2		= 7;
+const int BASIC_T3		= 21;
+
+const LONG BASIC_RESET	= 64;
+
 class JLSOutputStream;
 
 
 template<class STRATEGY>
-class JlsCodecFactory
+class JlsCodecFactory 
 {
-public:
+public:	
 	OFauto_ptr<STRATEGY> GetCodec(const JlsParameters& info, const JlsCustomParameters&);
 private:
 	STRATEGY* GetCodecImpl(const JlsParameters& info);
@@ -38,6 +46,7 @@ private:
 
 JLS_ERROR CheckParameterCoherent(const JlsParameters* pparams);
 
+JlsCustomParameters ComputeDefault(LONG MAXVAL, LONG NEAR);
 
 //
 // JpegSegment
