@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -71,7 +71,7 @@
 **      This file contains the routines which provide association management
 **      for DICOM V.3 applications.  It maintains structures which describe
 **      active associations and provides access to association specific
-**      informtion.  Also provided are routines for performing association
+**      information.  Also provided are routines for performing association
 **      negotiation (presentation contexts, abstract syntaxes, transfer
 **      syntaxes, maximum PDU length, and other extended negotiation).
 **
@@ -211,7 +211,7 @@ typedef struct {
 */
 
 /*
- * Network creation/distroy wrappers.
+ * Network creation/destroy wrappers.
  * The T_ASC_Network structure will be allocated/freed by
  * these routines.
  */
@@ -582,8 +582,8 @@ ascRole2dulRole(T_ASC_SC_ROLE role)
     return dr;
 }
 
-static const char*
-ascRole2String(T_ASC_SC_ROLE role)
+const char*
+ASC_role2String(T_ASC_SC_ROLE role)
 {
     const char* s = NULL;
     switch (role) {
@@ -664,7 +664,6 @@ ASC_addPresentationContext(
     /* we cannot simply use DUL_MakePresentationCtx() because
     ** it takes variable arguments (for transfer syntax).
     */
-
     pc = (DUL_PRESENTATIONCONTEXT *) calloc(1, sizeof(DUL_PRESENTATIONCONTEXT));
     if (pc == NULL) return EC_MemoryExhausted;
     lst = LST_Create();
@@ -680,10 +679,13 @@ ASC_addPresentationContext(
     pc->acceptedSCRole = ascRole2dulRole(ASC_SC_ROLE_DEFAULT);
 
     /* there must be at least one transfer syntax */
-    if (transferSyntaxListCount < 1 ) return ASC_MISSINGTRANSFERSYNTAX;
+    if (transferSyntaxListCount < 1)
+    {
+      free(pc);
+      return ASC_MISSINGTRANSFERSYNTAX;
+    }
 
     /* add the transfer syntaxes */
-    OFCondition cond = EC_Normal;
     for (i=0; i<transferSyntaxListCount; i++)
     {
         transfer = (DUL_TRANSFERSYNTAX*)malloc(sizeof(DUL_TRANSFERSYNTAX));
@@ -694,7 +696,6 @@ ASC_addPresentationContext(
     pc->proposedTransferSyntax = lst;
 
     /* add to presentation context list */
-
     lst = params->DULparams.requestedPresentationContext;
     if (lst == NULL) {
         lst = LST_Create();
@@ -858,7 +859,7 @@ ASC_acceptPresentationContext(
     if (proposedContext == NULL) return ASC_BADPRESENTATIONCONTEXTID;
     strcpy(proposedContext->acceptedTransferSyntax, transferSyntax);
 
-    /* we want to mark this proposed context as beeing ok */
+    /* we want to mark this proposed context as being ok */
     proposedContext->result = ASC_P_ACCEPTANCE;
     proposedContext->acceptedSCRole = ascRole2dulRole(acceptedRole);
 
@@ -873,8 +874,8 @@ ASC_acceptPresentationContext(
             {
                 proposedContext->result = ASC_P_NOREASON;
                 DCMNET_ERROR("ASSOC: SCP/SCU role selection failed, proposed ("
-                    << ascRole2String(dulRole2ascRole(proposedContext->proposedSCRole))
-                    << ") and accepted role (" << ascRole2String(acceptedRole) << ") are incompatible");
+                    << ASC_role2String(dulRole2ascRole(proposedContext->proposedSCRole))
+                    << ") and accepted role (" << ASC_role2String(acceptedRole) << ") are incompatible");
                 return ASC_SCPSCUROLESELECTIONFAILED;
             }
         }
@@ -1460,11 +1461,11 @@ ASC_dumpPresentationContext(T_ASC_PresentationContext * p)
     }
 
     outstream << "    Proposed SCP/SCU Role: "
-        << ascRole2String(p->proposedRole) << OFendl;
+        << ASC_role2String(p->proposedRole) << OFendl;
 
     if (p->resultReason != ASC_P_NOTYETNEGOTIATED) {
         outstream << "    Accepted SCP/SCU Role: "
-            << ascRole2String(p->acceptedRole) << OFendl;
+            << ASC_role2String(p->acceptedRole) << OFendl;
     }
 
     if (p->resultReason == ASC_P_ACCEPTANCE) {
@@ -1684,6 +1685,10 @@ ASC_associationWaiting(T_ASC_Network * network, int timeout)
 #else
     nfound = select(s + 1, &fdset, NULL, NULL, &t);
 #endif
+    if (DCM_dcmnetLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
+    {
+      DU_logSelectResult(nfound);
+    }
     return nfound > 0;
 }
 
@@ -1971,7 +1976,7 @@ ASC_requestAssociation(T_ASC_Network * network,
         strcpy(params->theirImplementationVersionName,
            params->DULparams.calledImplementationVersionName);
 
-        /* make sure accepted PCs are marked as such in the requsted PC list */
+        /* make sure accepted PCs are marked as such in the requested PC list */
         cond = updateRequestedPCListFromAcceptedPCList(&params->DULparams);
     }
     return cond;
