@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -115,7 +115,7 @@
 #include "dcmtk/dcmdata/dcvrobow.h"    /* for class DcmOtherByteOtherWord */
 #include "dcmtk/dcmdata/dcvrsh.h"      /* for class DcmShortString */
 #include "dcmtk/dcmdata/dcvrae.h"      /* for class DcmApplicationEntity */
-#include "dcmtk/dcmdata/dcdicent.h"    /* for DcmDictEntry, needed for MSVC5 */
+#include "dcmtk/dcmdata/dcdicent.h"    /* for class DcmDictEntry, needed for MSVC5 */
 #include "dcmtk/dcmdata/dcwcache.h"    /* for class DcmWriteCache */
 #include "dcmtk/dcmdata/dcvrui.h"      /* for class DcmUniqueIdentifier */
 
@@ -358,6 +358,9 @@ getTransferSyntax(
         case EXS_MPEG2MainProfileAtHighLevel:
         case EXS_MPEG4HighProfileLevel4_1:
         case EXS_MPEG4BDcompatibleHighProfileLevel4_1:
+        case EXS_MPEG4HighProfileLevel4_2_For2DVideo:
+        case EXS_MPEG4HighProfileLevel4_2_For3DVideo:
+        case EXS_MPEG4StereoHighProfileLevel4_2:
         case EXS_JPEG2000MulticomponentLosslessOnly:
         case EXS_JPEG2000Multicomponent:
 #ifdef WITH_ZLIB
