@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2011-2014, OFFIS e.V.
+ *  Copyright (C) 2011-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,6 +25,7 @@
 #include "dcmtk/ofstd/ofdatime.h"
 #include "dcmtk/dcmdata/dccodec.h"
 #include "dcmtk/dcmdata/dcfilefo.h"
+#include "dcmtk/dcmdata/dcdatutl.h"
 #include "dcmtk/dcmnet/dstorscu.h"
 #include "dcmtk/dcmnet/diutil.h"
 
@@ -60,7 +61,7 @@ static const OFString &dicomToHostFilename(const OFString &dicomFilename,
 
 // implementation of the internal class/struct for a single transfer entry
 
-DcmStorageSCU::TransferEntry::TransferEntry(const OFString &filename,
+DcmStorageSCU::TransferEntry::TransferEntry(const OFFilename &filename,
                                             const E_FileReadMode readMode,
                                             const OFString &sopClassUID,
                                             const OFString &sopInstanceUID,
@@ -74,6 +75,7 @@ DcmStorageSCU::TransferEntry::TransferEntry(const OFString &filename,
     TransferSyntaxUID(transferSyntaxUID),
     NetworkTransferSyntax(EXS_Unknown),
     Uncompressed(OFFalse),
+    DatasetSize(0),
     AssociationNumber(0),
     PresentationContextID(0),
     RequestSent(OFFalse),
@@ -97,6 +99,7 @@ DcmStorageSCU::TransferEntry::TransferEntry(DcmDataset *dataset,
     TransferSyntaxUID(transferSyntaxUID),
     NetworkTransferSyntax(EXS_Unknown),
     Uncompressed(OFFalse),
+    DatasetSize(0),
     AssociationNumber(0),
     PresentationContextID(0),
     RequestSent(OFFalse),
@@ -357,20 +360,20 @@ OFCondition DcmStorageSCU::removeSOPInstance(const OFString &sopClassUID,
 }
 
 
-OFCondition DcmStorageSCU::addDicomFile(const OFString &filename,
+OFCondition DcmStorageSCU::addDicomFile(const OFFilename &filename,
                                         const E_FileReadMode readMode,
                                         const OFBool checkValues)
 {
     OFCondition status = EC_IllegalParameter;
     // check for non-empty filename
-    if (!filename.empty())
+    if (!filename.isEmpty())
     {
         DCMNET_DEBUG("adding DICOM file '" << filename << "'");
         const size_t numInstances = TransferList.size();
         OFBool isDICOMDIR = OFFalse;
         // get relevant information from the DICOM file
         OFString sopClassUID, sopInstanceUID, transferSyntaxUID;
-        status = getSOPInstanceFromFile(filename, sopClassUID, sopInstanceUID, transferSyntaxUID, readMode);
+        status = DcmDataUtil::getSOPInstanceFromFile(filename, sopClassUID, sopInstanceUID, transferSyntaxUID, readMode);
         if (status.good())
         {
             // check whether it is a DICOMDIR and should be treated in a special manner
@@ -432,7 +435,7 @@ OFCondition DcmStorageSCU::addDataset(DcmDataset *dataset,
         DCMNET_DEBUG("adding DICOM dataset");
         // get relevant information from the DICOM dataset
         OFString sopClassUID, sopInstanceUID, transferSyntaxUID;
-        status = getSOPInstanceFromDataset(dataset, datasetXfer, sopClassUID, sopInstanceUID, transferSyntaxUID);
+        status = DcmDataUtil::getSOPInstanceFromDataset(dataset, datasetXfer, sopClassUID, sopInstanceUID, transferSyntaxUID);
         if (status.good())
         {
             // check the SOP instance before adding it
@@ -463,20 +466,20 @@ OFCondition DcmStorageSCU::addDataset(DcmDataset *dataset,
 }
 
 
-OFCondition DcmStorageSCU::addDicomFilesFromDICOMDIR(const OFString &filename,
+OFCondition DcmStorageSCU::addDicomFilesFromDICOMDIR(const OFFilename &filename,
                                                      const E_FileReadMode readMode,
                                                      const OFBool checkValues)
 {
     DCMNET_DEBUG("adding DICOM files referenced from '" << filename << "'");
     // read the DICOMDIR file (always require meta-header to be present)
     DcmFileFormat fileformat;
-    OFCondition status = fileformat.loadFile(filename.c_str(), EXS_Unknown, EGL_noChange, DCM_MaxReadLength, ERM_fileOnly);
+    OFCondition status = fileformat.loadFile(filename, EXS_Unknown, EGL_noChange, DCM_MaxReadLength, ERM_fileOnly);
     if (status.good())
     {
         DcmStack stack;
         // do not use the DcmDirectoryRecord class, but access the data elements directly
         DcmDataset *dataset = fileformat.getDataset();
-        OFString dirName;
+        OFFilename dirName;
         OFStandard::getDirNameFromPath(dirName, filename, OFFalse /* assumeDirName */);
         // iterate over all items (directory records) where ReferencedFileID is present
         while (dataset->search(DCM_ReferencedFileID, stack, ESM_afterStackTop, OFTrue).good())
@@ -484,7 +487,8 @@ OFCondition DcmStorageSCU::addDicomFilesFromDICOMDIR(const OFString &filename,
             // make sure that the dataset and element pointer are there
             if (stack.card() > 1)
             {
-                OFString pathName, fileID, sopClassUID, sopInstanceUID, transferSyntaxUID;
+                OFFilename pathName;
+                OFString fileID, sopClassUID, sopInstanceUID, transferSyntaxUID;
                 // first, get the name of the referenced DICOM file
                 DcmElement *element = OFstatic_cast(DcmElement *, stack.top());
                 if (element != NULL)
@@ -507,9 +511,9 @@ OFCondition DcmStorageSCU::addDicomFilesFromDICOMDIR(const OFString &filename,
                     if (status.good())
                     {
                         OFString tmpString;
+                        const OFFilename tmpFilename(dicomToHostFilename(fileID, tmpString), pathName.usesWideChars() /*convert*/);
                         // consider that the value of ReferencedFileID is relative to the DICOMDIR
-                        OFStandard::combineDirAndFilename(pathName, dirName, dicomToHostFilename(fileID, tmpString),
-                            OFTrue /* allowEmptyDirName */);
+                        OFStandard::combineDirAndFilename(pathName, dirName, tmpFilename, OFTrue /* allowEmptyDirName */);
                         // create a new entry ...
                         TransferEntry *entry = new TransferEntry(pathName, readMode, sopClassUID, sopInstanceUID, transferSyntaxUID);
                         if (entry != NULL)
@@ -527,7 +531,7 @@ OFCondition DcmStorageSCU::addDicomFilesFromDICOMDIR(const OFString &filename,
                         DCMNET_DEBUG("successfully added SOP instance " << sopInstanceUID << " to the transfer list");
                     } else {
                         DCMNET_ERROR("cannot add DICOM file from DICOMDIR to the transfer list: "
-                            << (pathName.empty() ? fileID : pathName) << ": " << status.text());
+                            << (pathName.isEmpty() ? fileID : pathName) << ": " << status.text());
                     }
                 } else {
                     DCMNET_ERROR("cannot add DICOM file from DICOMDIR with empty filename");
@@ -805,7 +809,7 @@ OFCondition DcmStorageSCU::sendSOPInstances()
                     break;
                 }
                 // output debug information on the SOP instance to be sent
-                if ((*CurrentTransferEntry)->Filename.empty())
+                if ((*CurrentTransferEntry)->Filename.isEmpty())
                 {
                     if ((*CurrentTransferEntry)->Dataset != NULL)
                     {
@@ -824,11 +828,17 @@ OFCondition DcmStorageSCU::sendSOPInstances()
                 } else {
                     DCMNET_DEBUG("sending SOP instance from file: " << (*CurrentTransferEntry)->Filename);
                     // load SOP instance from DICOM file
-                    status = fileformat.loadFile((*CurrentTransferEntry)->Filename.c_str(), EXS_Unknown, EGL_noChange,
+                    status = fileformat.loadFile((*CurrentTransferEntry)->Filename, EXS_Unknown, EGL_noChange,
                         DCM_MaxReadLength, (*CurrentTransferEntry)->FileReadMode);
-                    // do not store the dataset pointer in the transfer entry, because this pointer
-                    // will become invalid for the next iteration of this while-loop.
-                    dataset = fileformat.getDataset();
+                    if (status.good())
+                    {
+                        // do not store the dataset pointer in the transfer entry, because this pointer
+                        // will become invalid for the next iteration of this while-loop.
+                        dataset = fileformat.getDataset();
+                    } else {
+                        DCMNET_ERROR("cannot send SOP instance from file: " << (*CurrentTransferEntry)->Filename
+                            << ": " << status.text());
+                    }
                 }
                 // send SOP instance to the peer using a C-STORE request message
                 if (status.good())
@@ -838,7 +848,7 @@ OFCondition DcmStorageSCU::sendSOPInstances()
                     {
                         DCMNET_DEBUG("checking whether SOP Class UID and SOP Instance UID in dataset are consistent with transfer list");
                         OFString sopClassUID, sopInstanceUID, transferSyntaxUID;
-                        if (getSOPInstanceFromDataset(dataset, dataset->getOriginalXfer(), sopClassUID, sopInstanceUID, transferSyntaxUID).good())
+                        if (DcmDataUtil::getSOPInstanceFromDataset(dataset, dataset->getOriginalXfer(), sopClassUID, sopInstanceUID, transferSyntaxUID).good())
                         {
                             // differences are usually a result of inconsistent values in meta-header and dataset
                             if ((*CurrentTransferEntry)->SOPClassUID != sopClassUID)
@@ -855,6 +865,10 @@ OFCondition DcmStorageSCU::sendSOPInstances()
                             }
                         }
                     }
+                    // determine size of the dataset (in bytes) based on the original transfer syntax
+                    (*CurrentTransferEntry)->DatasetSize = dataset->calcElementLength(dataset->getOriginalXfer(), g_dimse_send_sequenceType_encoding);
+                    // notify user of this class that the current SOP instance is to be sent
+                    notifySOPInstanceToBeSent(**CurrentTransferEntry);
                     // call the inherited method from the base class doing the real work
                     status = sendSTORERequest((*CurrentTransferEntry)->PresentationContextID, "" /* filename */,
                         dataset, (*CurrentTransferEntry)->ResponseStatusCode,
@@ -869,7 +883,7 @@ OFCondition DcmStorageSCU::sendSOPInstances()
                     // ... remember that this SOP instance has already been sent
                     (*CurrentTransferEntry)->RequestSent = OFTrue;
                     // check whether we need to compact or delete the dataset
-                    if ((*CurrentTransferEntry)->Filename.empty() && ((*CurrentTransferEntry)->Dataset != NULL))
+                    if ((*CurrentTransferEntry)->Filename.isEmpty() && ((*CurrentTransferEntry)->Dataset != NULL))
                     {
                         if ((*CurrentTransferEntry)->DatasetHandlingMode == HM_compactAfterSend)
                         {
@@ -913,7 +927,13 @@ OFCondition DcmStorageSCU::sendSOPInstances()
 }
 
 
-void DcmStorageSCU::notifySOPInstanceSent(const TransferEntry &transferEntry)
+void DcmStorageSCU::notifySOPInstanceToBeSent(const TransferEntry &transferEntry)
+{
+    // do nothing in the default implementation
+}
+
+
+void DcmStorageSCU::notifySOPInstanceSent(const TransferEntry & /*transferEntry*/)
 {
     // do nothing in the default implementation
 }
@@ -1039,12 +1059,13 @@ OFCondition DcmStorageSCU::createReportFile(const OFString &filename) const
             {
                 DcmXfer orgXfer((*transferEntry)->TransferSyntaxUID.c_str());
                 stream << "Number        : " << (++counter) << OFendl;
-                if (!(*transferEntry)->Filename.empty())
+                if (!(*transferEntry)->Filename.isEmpty())
                     stream << "Filename      : " << (*transferEntry)->Filename << OFendl;
                 stream << "SOP Instance  : " << (*transferEntry)->SOPInstanceUID << OFendl;
                 stream << "SOP Class     : " << (*transferEntry)->SOPClassUID << " = "
                     << dcmFindNameOfUID((*transferEntry)->SOPClassUID.c_str(), "unknown") << OFendl;
                 stream << "Original Xfer : " << (*transferEntry)->TransferSyntaxUID << " = " << orgXfer.getXferName() << OFendl;
+                stream << "Dataset Size  : " << (*transferEntry)->DatasetSize << " bytes" << OFendl;
                 stream << "Association   : " << (*transferEntry)->AssociationNumber << OFendl;
                 stream << "Pres. Context : " << OFstatic_cast(unsigned int, (*transferEntry)->PresentationContextID) << OFendl;
                 stream << "Network Xfer  : ";
@@ -1089,112 +1110,6 @@ OFCondition DcmStorageSCU::createReportFile(const OFString &filename) const
 }
 
 
-OFCondition DcmStorageSCU::getSOPInstanceFromFile(const OFString &filename,
-                                                  OFString &sopClassUID,
-                                                  OFString &sopInstanceUID,
-                                                  OFString &transferSyntaxUID,
-                                                  const E_FileReadMode readMode)
-{
-    OFCondition status = EC_IllegalParameter;
-    if (!filename.empty())
-    {
-        DCMNET_DEBUG("getting SOP Class UID, SOP Instance UID and Transfer Syntax UID from DICOM file");
-        sopClassUID.clear();
-        sopInstanceUID.clear();
-        transferSyntaxUID.clear();
-        // prefer to load file meta information header only (since this is more efficient)
-        if (readMode != ERM_dataset)
-        {
-            DcmMetaInfo metaInfo;
-            status = metaInfo.loadFile(filename.c_str());
-            if (status.good())
-            {
-                // try to get the UIDs from the meta-header
-                DCMNET_DEBUG("trying to get SOP Class UID, SOP Instance UID and Transfer Syntax UID from meta-header");
-                metaInfo.findAndGetOFStringArray(DCM_MediaStorageSOPClassUID, sopClassUID);
-                metaInfo.findAndGetOFStringArray(DCM_MediaStorageSOPInstanceUID, sopInstanceUID);
-                metaInfo.findAndGetOFStringArray(DCM_TransferSyntaxUID, transferSyntaxUID);
-            }
-        }
-        // alternatively, get UIDs from the dataset (if required and desired)
-        if ((readMode != ERM_fileOnly) && (readMode != ERM_metaOnly))
-        {
-            if (sopClassUID.empty() || sopInstanceUID.empty())
-                DCMNET_DEBUG("no SOP Class UID and/or SOP Instance UID found in meta-header, checking dataset instead");
-            if (status.bad() || sopClassUID.empty() || sopInstanceUID.empty() || transferSyntaxUID.empty())
-            {
-                DcmFileFormat fileformat;
-                status = fileformat.loadFile(filename.c_str(), EXS_Unknown, EGL_noChange, 256 /* maxReadLength */, readMode);
-                if (status.good())
-                {
-                    DcmDataset *dataset = fileformat.getDataset();
-                    if (dataset != NULL)
-                    {
-                        if (sopClassUID.empty())
-                            dataset->findAndGetOFStringArray(DCM_SOPClassUID, sopClassUID);
-                        if (sopInstanceUID.empty())
-                            dataset->findAndGetOFStringArray(DCM_SOPInstanceUID, sopInstanceUID);
-                        if (transferSyntaxUID.empty())
-                        {
-                            DCMNET_DEBUG("no Transfer Syntax UID found in meta-header, trying to determine from dataset instead");
-                            // empty string in case of unknown/unsupported transfer syntax
-                            transferSyntaxUID = DcmXfer(dataset->getOriginalXfer()).getXferID();
-                        }
-                    }
-                }
-            }
-        }
-    }
-    return status;
-}
-
-
-OFCondition DcmStorageSCU::getSOPInstanceFromDataset(DcmDataset *dataset,
-                                                     const E_TransferSyntax datasetXfer,
-                                                     OFString &sopClassUID,
-                                                     OFString &sopInstanceUID,
-                                                     OFString &transferSyntaxUID)
-{
-    OFCondition status = EC_IllegalParameter;
-    // check for invalid dataset pointer
-    if (dataset != NULL)
-    {
-        DCMNET_DEBUG("getting SOP Class UID, SOP Instance UID and Transfer Syntax UID from DICOM dataset");
-        sopClassUID.clear();
-        sopInstanceUID.clear();
-        transferSyntaxUID.clear();
-        // check for correct class type
-        if (dataset->ident() == EVR_dataset)
-        {
-            // try to determine the transfer syntax of the dataset
-            E_TransferSyntax xfer = datasetXfer;
-            if (xfer == EXS_Unknown)
-                xfer = dataset->getOriginalXfer();
-            if (xfer == EXS_Unknown)
-            {
-                // update the internally stored transfer syntax based on the pixel data (if any)
-                dataset->updateOriginalXfer();
-                xfer = dataset->getOriginalXfer();
-            }
-            if (xfer != EXS_Unknown)
-            {
-                status = EC_Normal;
-                // store UID of the transfers syntax in result variable
-                transferSyntaxUID = DcmXfer(xfer).getXferID();
-                // get other UIDs directly from the dataset
-                dataset->findAndGetOFStringArray(DCM_SOPClassUID, sopClassUID);
-                dataset->findAndGetOFStringArray(DCM_SOPInstanceUID, sopInstanceUID);
-            } else {
-                DCMNET_DEBUG("unable to determine transfer syntax from dataset");
-                status = NET_EC_UnknownTransferSyntax;
-            }
-        } else
-            status = EC_CorruptedData;
-    }
-    return status;
-}
-
-
 OFCondition DcmStorageSCU::checkSOPInstance(const OFString &sopClassUID,
                                             const OFString &sopInstanceUID,
                                             const OFString &transferSyntaxUID,
