@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2012, OFFIS e.V.
+ *  Copyright (C) 1994-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were partly developed by
@@ -380,7 +380,7 @@ DUL_InitializeNetwork(const char *mode,
 **
 **
 ** Algorithm:
-**      Close the socket and free the memeory occupied by the network key
+**      Close the socket and free the memory occupied by the network key
 */
 OFCondition
 DUL_DropNetwork(DUL_NETWORKKEY ** callerNetworkKey)
@@ -1409,58 +1409,6 @@ DUL_ClearServiceParameters(DUL_ASSOCIATESERVICEPARAMETERS * params)
 }
 
 
-/* DUL_DefaultServiceParameters
-**
-** Purpose:
-**      DUL_DefaultServiceParameters is used to set a number of default
-**      parameters in a DUL_ASSOCIATESERVICEPARAMETERS structure.  These
-**      parameters are the default MIR parameters (which should be
-**      adequate for most Unix installations).
-**
-** Parameter Dictionary:
-**      params  Pointer to a DUL_ASSOCIATESERVICEPARAMETERS structure
-**              to be set.
-**
-** Return Values:
-**      none
-** Notes:
-**
-** Algorithm:
-*/
-void
-DUL_DefaultServiceParameters(DUL_ASSOCIATESERVICEPARAMETERS * params)
-{
-    static DUL_ASSOCIATESERVICEPARAMETERS p = {
-        DICOM_STDAPPLICATIONCONTEXT,    /* Application Ctx Name */
-        "Calling AP Title",     /* Calling AP Title */
-        "Called AP Title",      /* Called AP Title */
-        "",                     /* Responding AP Title */
-        16384,                  /* Max PDU */
-        0,                      /* result */
-        0,                      /* result source */
-        0,                      /* diagnostic */
-        "localhost",            /* Calling presentation addr */
-        "localhost:104",        /* Called presentation addr */
-        NULL,                   /* Requested presentation ctx list */
-        NULL,                   /* Accepted presentation ctx list */
-        0,                      /* Maximum operations invoked */
-        0,                      /* Maximum operations performed */
-        DICOM_NET_IMPLEMENTATIONCLASSUID, /* Calling implementation class UID */
-        DICOM_NET_IMPLEMENTATIONVERSIONNAME, /* Calling implementation vers name */
-        "",                     /* Called implementation class UID */
-        "",                     /* Called implementation vers name */
-        0,                      /* peer max pdu */
-        NULL,                   /* Requested Extended Negotation List */
-        NULL,                   /* Accepted Extended Negotation List */
-        NULL,                   /* Requested User Identify Negotiation */
-        NULL,                   /* Accepted User Identify Negotiation */
-        OFFalse                 /* don't use Secure Transport Layer */
-    };
-
-    *params = p;
-}
-
-
 /*  ========================================================================
  *  Private functions not meant for users of the package are included below.
  */
@@ -1591,6 +1539,10 @@ receiveTransportConnectionTCP(PRIVATE_NETWORKKEY ** network,
             nfound = select((*network)->networkSpecific.TCP.listenSocket + 1,
                             &fdset, NULL, NULL, &timeout_val);
 #endif
+            if (DCM_dcmnetLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
+            {
+                DU_logSelectResult(nfound);
+            }
             if (nfound > 0) {
                 if (FD_ISSET((*network)->networkSpecific.TCP.listenSocket, &fdset))
                     connected++;
@@ -1618,6 +1570,10 @@ receiveTransportConnectionTCP(PRIVATE_NETWORKKEY ** network,
                 nfound = select((*network)->networkSpecific.TCP.listenSocket + 1,
                                 &fdset, NULL, NULL, &timeout_val);
 #endif
+                if (DCM_dcmnetLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
+                {
+                    DU_logSelectResult(nfound);
+                }
                 if (nfound > 0) {
                     if (FD_ISSET((*network)->networkSpecific.TCP.listenSocket,
                                  &fdset))
@@ -2072,7 +2028,7 @@ initializeNetworkTCP(PRIVATE_NETWORKKEY ** key, void *parameter)
       int sock;
       struct sockaddr_in server;
 
-      /* Create socket for internet type communication */
+      /* Create socket for Internet type communication */
       (*key)->networkSpecific.TCP.port = *(int *) parameter;
       (*key)->networkSpecific.TCP.listenSocket = socket(AF_INET, SOCK_STREAM, 0);
       sock = (*key)->networkSpecific.TCP.listenSocket;
@@ -2127,7 +2083,14 @@ initializeNetworkTCP(PRIVATE_NETWORKKEY ** key, void *parameter)
         return makeDcmnetCondition(DULC_TCPINITERROR, OF_error, msg.c_str());
       }
 #endif
-      listen(sock, PRV_LISTENBACKLOG);
+      /* Listen on the socket */
+      if (listen(sock, PRV_LISTENBACKLOG) < 0)
+      {
+        char buf[256];
+        OFString msg = "TCP Initialization Error: ";
+        msg += OFStandard::strerror(errno, buf, sizeof(buf));
+        return makeDcmnetCondition(DULC_TCPINITERROR, OF_error, msg.c_str());
+      }
     }
 
     (*key)->networkSpecific.TCP.tLayer = new DcmTransportLayer((*key)->applicationFunction);
@@ -2306,15 +2269,15 @@ setTCPBufferLength(int sock)
     int bufLen;
 
     /*
-     * Use a 32K default socket buffer length.
-     * This value has provided optimal throughput during performance testing.
-     * Test environment: Windows NT 4 (SP4), 100Mbit/s Fast Ethernet.
-     * Other environments, particularly slower networks may require different values for optimal performance.
+     * Use a 64K default socket buffer length, fitting the MTU size of the loopback device implementation
+     * in recent Linux kernel versions.
+     * Different environments, particularly slower networks may require different values for optimal
+     * performance.
      */
 #ifdef HAVE_GUSI_H
     /* GUSI always returns an error for setsockopt(...) */
 #else
-    bufLen = 32768; // a socket buffer size of 32K gives best throughput for image transmission
+    bufLen = 65536; // a socket buffer size of 64K gives best throughput for image transmission
     if ((TCPBufferLength = getenv("TCP_BUFFER_LENGTH")) != NULL) {
         if (sscanf(TCPBufferLength, "%d", &bufLen) != 1) {
             DCMNET_WARN("DUL: cannot parse environment variable TCP_BUFFER_LENGTH=" << TCPBufferLength);
@@ -2411,7 +2374,7 @@ static SC_MAP scMap[] = {
 **      Display the contents of the presentation context list
 **
 ** Parameter Dictionary:
-**      l  Head of the list of various presentation conmtexts.
+**      l  Head of the list of various presentation contexts.
 **
 ** Return Values:
 **
@@ -2650,7 +2613,7 @@ clearRequestorsParams(DUL_ASSOCIATESERVICEPARAMETERS * params)
 /* clearPresentationContext
 **
 ** Purpose:
-**      Free the memory oocupied by the given presentation context.
+**      Free the memory occupied by the given presentation context.
 **
 ** Parameter Dictionary:
 **      l  Head of list of the presentation contexts to be freed.
