@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2015, Open Connections GmbH
+ *  Copyright (C) 2015-2016, Open Connections GmbH
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation are maintained by
@@ -61,6 +61,12 @@ const Uint32 DCM_SEG_MAX_SEGMENTS = 65536;
 extern DCMTK_DCMSEG_EXPORT   const OFConditionConst     SG_EC_MaxSegmentsReached;
 /// error: specified segment does not exist
 extern DCMTK_DCMSEG_EXPORT   const OFConditionConst     SG_EC_NoSuchSegment;
+/// error: unknown segmentation type
+extern DCMTK_DCMSEG_EXPORT   const OFConditionConst     SG_EC_UnknownSegmentationType;
+/// error: invalid value
+extern DCMTK_DCMSEG_EXPORT   const OFConditionConst     SG_EC_InvalidValue;
+/// error: not enough data
+extern DCMTK_DCMSEG_EXPORT   const OFConditionConst     SG_EC_NotEnoughData;
 
 /** General purpose class hiding global functions, constants and types in the
  *  segmentation context from the global namespace.
@@ -105,7 +111,7 @@ class DCMTK_DCMSEG_EXPORT DcmSegTypes
     {
       /// Unknown (e.g.\ not initialized)
       SFT_UNKNOWN,
-      /// For fractional segmentations, a value defines probablity that pixel belongs to segment
+      /// For fractional segmentations, a value defines probability that pixel belongs to segment
       SFT_PROBABILITY,
       /// For fractional segmentations, a value defines how much of the pixel is covered by the segment
       SFT_OCCUPANCY
@@ -134,6 +140,12 @@ class DCMTK_DCMSEG_EXPORT DcmSegTypes
      */
     static DcmSegTypes::E_SegmentationType OFString2Segtype( const OFString& value );
 
+    /** Return string representation from segmentation enum type
+     *  @param  value The segmentation type as enum value
+     *  @return The segmentation type as a string
+     */
+    static OFString segtype2OFString( const DcmSegTypes::E_SegmentationType& value );
+
     /** Return enum representation of fractional type string as found in
      *  segmentation objects
      *  @param  value The fractional type as a string
@@ -174,7 +186,7 @@ public:
 
   /** Read data from given item
    *  @param  item The item to read from
-   *  @param  clearOldData If OFtrue, old data is cleared before reading
+   *  @param  clearOldData If OFTrue, old data is cleared before reading
    *  @return EC_Normal if reading was successful, error otherwise
    */
   virtual OFCondition read(DcmItem& item,
@@ -288,8 +300,8 @@ public:
 
   /** Set Segment Description
    *  @param  value Value to be set (single value only) or "" for no value
-   *  @param  checkValue Check 'value' for conformance with VR (ST) and VM (1)
-   *          if enabled
+   *  @param  checkValue Check 'value'. Not evaluated (here for consistency
+   *          with other setter functions).
    *  @return EC_Normal if successful, an error code otherwise
    */
   virtual OFCondition setSegmentDescription(const OFString& value,
