@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -23,11 +23,12 @@
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmsr/dsrdoc.h"
-#include "dcmtk/dcmdata/cmdlnarg.h"
+#include "dcmtk/dcmsr/dsrdoc.h"       /* for main interface class DSRDocument */
+
+#include "dcmtk/dcmdata/dctk.h"       /* for typical set of "dcmdata" headers */
+
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofconapp.h"
-#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>                     /* for zlibVersion() */
@@ -95,6 +96,9 @@ static OFCondition dumpFile(STD_NAMESPACE ostream &out,
             }
         }
     }
+#else
+    // avoid compiler warning on unused variable
+    (void)convertToUTF8;
 #endif
     if (result.good())
     {
@@ -191,6 +195,9 @@ int main(int argc, char *argv[])
         cmd.addOption("--print-invalid-codes",  "+Pi",  "print invalid codes (for debugging purposes)");
         cmd.addOption("--no-invalid-codes",     "-Pi",  "print text \"invalid code\" instead (default)");
         cmd.addOption("--print-template-id",    "+Pt",  "print template identification information");
+      cmd.addSubGroup("enhanced encoding mode:");
+        cmd.addOption("--indicate-enhanced",    "+Pe",  "indicate that enhanced mode is used for codes");
+        cmd.addOption("--no-enhanced-mode",     "-Pe",  "do not indicate enhanced mode (default)");
 #ifdef ANSI_ESCAPE_CODES_AVAILABLE
       cmd.addSubGroup("color:");
         cmd.addOption("--print-color",          "+C",   "use ANSI escape codes for colored output");
@@ -322,6 +329,13 @@ int main(int argc, char *argv[])
         if (cmd.findOption("--print-template-id"))
             opt_printFlags |= DSRTypes::PF_printTemplateIdentification;
 
+        cmd.beginOptionBlock();
+        if (cmd.findOption("--indicate-enhanced"))
+            opt_printFlags |= DSRTypes::PF_indicateEnhancedEncodingMode;
+        if (cmd.findOption("--no-enhanced-mode"))
+            opt_printFlags &= ~DSRTypes::PF_indicateEnhancedEncodingMode;
+        cmd.endOptionBlock();
+
 #ifdef ANSI_ESCAPE_CODES_AVAILABLE
         cmd.beginOptionBlock();
         if (cmd.findOption("--print-color"))
