@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2013, OFFIS e.V.
+ *  Copyright (C) 2003-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,24 +11,25 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
- *  Purpose: Convert the contents of an XML document to a DICOM structured
- *            reporting file
+ *  Purpose:
+ *    convert the contents of an XML document to a DICOM structured reporting file
  *
  */
 
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmsr/dsrdoc.h"
-#include "dcmtk/dcmdata/cmdlnarg.h"
+#include "dcmtk/dcmsr/dsrdoc.h"       /* for main interface class DSRDocument */
+
+#include "dcmtk/dcmdata/dctk.h"       /* for typical set of "dcmdata" headers */
+#include "dcmtk/dcmdata/dcostrmz.h"   /* for dcmZlibCompressionLevel */
+
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofconapp.h"
-#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
-#include "dcmtk/dcmdata/dcostrmz.h"   /* for dcmZlibCompressionLevel */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>                     /* for zlibVersion() */
@@ -206,19 +207,9 @@ int main(int argc, char *argv[])
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--enable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFTrue);
-            dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-            dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
-            dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
-        }
+            dcmEnableGenerationOfNewVRs();
         if (cmd.findOption("--disable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFFalse);
-            dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-            dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
-            dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
-        }
+            dcmDisableGenerationOfNewVRs();
         cmd.endOptionBlock();
 
         cmd.beginOptionBlock();
