@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -28,7 +28,6 @@
 
 #include "dcmtk/dcmsr/dsrtypes.h"
 
-#include "dcmtk/ofstd/ofstring.h"
 #include "dcmtk/ofstd/ofexbl.h"
 
 
@@ -198,7 +197,7 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
      */
     DSRCodedEntryValue &operator=(const DSRCodedEntryValue &codedEntryValue);
 
-    /** comparison operator.
+    /** comparison operator "equal".
      *  Two codes are equal if the code value, coding scheme designator and the (optional)
      *  coding scheme version are equal.  The code meaning is not relevant for this check.
      ** @param  codedEntryValue  code which should be compared to the current one
@@ -206,6 +205,32 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
      */
     OFBool operator==(const DSRCodedEntryValue &codedEntryValue) const;
 
+    /** comparison operator "not equal".
+     *  Two codes are not equal if either the code value or the coding scheme designator
+     *  or the (optional) coding scheme version are not equal.  The code meaning is not
+     *  relevant for this check.
+     ** @param  codedEntryValue  code which should be compared to the current one
+     ** @return OFTrue if both codes are not equal, OFFalse otherwise
+     */
+    OFBool operator!=(const DSRCodedEntryValue &codedEntryValue) const;
+
+    /** comparison operator "equal".
+     *  Two codes are equal if the code value, coding scheme designator and the (optional)
+     *  coding scheme version are equal.  The code meaning is not relevant for this check.
+     ** @param  basicCodedEntry  code which should be compared to the current one
+     ** @return OFTrue if both codes are equal, OFFalse otherwise
+     */
+    OFBool operator==(const DSRBasicCodedEntry &basicCodedEntry) const;
+
+    /** comparison operator "not equal".
+     *  Two codes are not equal if either the code value or the coding scheme designator
+     *  or the (optional) coding scheme version are not equal.  The code meaning is not
+     *  relevant for this check.
+     ** @param  basicCodedEntry  code which should be compared to the current one
+     ** @return OFTrue if both codes are not equal, OFFalse otherwise
+     */
+    OFBool operator!=(const DSRBasicCodedEntry &basicCodedEntry) const;
+
     /** clear all internal variables.
      *  Since an empty code is invalid the code becomes invalid afterwards.
      */
@@ -223,6 +248,14 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
      */
     virtual OFBool isEmpty() const;
 
+    /** check whether the current code is complete, i.e.\ whether the three mandatory
+     *  components of the code are non-empty.  This is just a basic check that might be useful
+     *  for "validating" input data.  See isValid() for a more sophisticated way of checking
+     *  the current code.
+     ** @return OFTrue if code is complete, OFFalse otherwise
+     */
+    virtual OFBool isComplete() const;
+
     /** print code.
      *  The output of a typical code triple looks like this: (1234,99_OFFIS_DCMTK,"Code
      *  Meaning").  The optional coding scheme version is printed in square brackets directly
@@ -230,20 +263,20 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
      *  Please note that only the "Basic Coded Entry Attributes" are supported by this method.
      ** @param  stream          output stream to which the code should be printed
      *  @param  printCodeValue  flag indicating whether the code value and coding scheme
-     *                          designator should be printed (default) or not.  If OFFalse the
-     *                          output looks like this: (,,"Code Meaning")
-     *  @param  printInvalid    flag indicating whether the text "invalid code" should be
-     *                          printed for invalid codes (default) or the actual code triple
+     *                          designator should be printed (default) or not.  If OFFalse,
+     *                          the output looks like this: (,,"Code Meaning")
+     *  @param  flags           flag used to customize the output (see DSRTypes::PF_xxx)
      */
     void print(STD_NAMESPACE ostream &stream,
                const OFBool printCodeValue = OFTrue,
-               const OFBool printInvalid = OFFalse) const;
+               const size_t flags = 0) const;
 
     /** read code sequence from dataset.
      *  The number of items within the code sequence is checked.  If error/warning output are
-     *  enabled, a warning message is printed if the sequence is empty or contains more than
-     *  one item.  The latter is a limitation of the current implementation, knowing that
-     *  there are code sequences for which more than one item is allowed.
+     *  enabled, a warning message is printed if the sequence is empty or contains more items
+     *  than specified in the 'vm ' parameter (1 by default, which applies to most use cases).
+     *  However, this method always reads the first item from the given sequence.  If another
+     *  item should be read (e.g. a modifier), the method readSequenceItem() should be used.
      ** @param  dataset  DICOM dataset from which the code sequence should be read
      *  @param  tagKey   DICOM tag specifying the attribute (= sequence) which should be read
      *  @param  type     value type of the sequence (valid value: "1", "2", something else).
@@ -251,12 +284,25 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
      *                   reported.
      *  @param  flags    optional flag used to customize the reading process (see
      *                   DSRTypes::RF_xxx)
+     *  @param  vm       value multiplicity to be checked, interpreted as cardinality (number
+     *                   of items).  See DcmElement::checkVM() for a list of valid values.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readSequence(DcmItem &dataset,
                              const DcmTagKey &tagKey,
                              const OFString &type,
-                             const size_t flags = 0);
+                             const size_t flags = 0,
+                             const OFString &vm = "1");
+
+    /** read code from sequence item
+     ** @param  item    DICOM sequence item from which the code should be read
+     *  @param  tagKey  DICOM tag specifying the sequence in which this item is contained
+     *  @param  flags   flag used to customize the reading process (see DSRTypes::RF_xxx)
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition readSequenceItem(DcmItem &item,
+                                 const DcmTagKey &tagKey,
+                                 const size_t flags = 0);
 
     /** write code sequence to dataset
      ** @param  dataset  DICOM dataset to which the code sequence should be written
@@ -267,6 +313,14 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
     OFCondition writeSequence(DcmItem &dataset,
                               const DcmTagKey &tagKey) const;
 
+    /** write code to sequence item
+     ** @param  item    DICOM sequence item to which the code should be written
+     *  @param  tagKey  DICOM tag specifying the sequence in which this item is contained
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition writeSequenceItem(DcmItem &item,
+                                  const DcmTagKey &tagKey);
+
     /** read code from XML document.
      *  Please note that only the "Basic Coded Entry Attributes" are supported by this method.
      ** @param  doc     document containing the XML file content
@@ -681,4 +735,15 @@ class DCMTK_DCMSR_EXPORT DSRCodedEntryValue
 };
 
 
+/** output stream operator for coded entry values.
+ *  Internally, the DSRCodedEntryValue::print() method is used, i.e. the output looks
+ *  like this: (1234,99_OFFIS_DCMTK,"Code Meaning") or (cm,UCUM[1.4],"centimeter")
+ *  @param  stream           output stream to which the coded entry value is printed
+ *  @param  codedEntryValue  coded entry value to be printed
+ *  @return reference to output stream
+ */
+DCMTK_DCMSR_EXPORT STD_NAMESPACE ostream &operator<<(STD_NAMESPACE ostream &stream,
+                                                     const DSRCodedEntryValue& codedEntryValue);
+
+
 #endif
