@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -32,6 +32,15 @@
 #include "dcmtk/dcmsr/dsrrefin.h"
 #include "dcmtk/dcmsr/dsrcsidl.h"
 
+#include "dcmtk/dcmdata/dcvrcs.h"
+#include "dcmtk/dcmdata/dcvrda.h"
+#include "dcmtk/dcmdata/dcvris.h"
+#include "dcmtk/dcmdata/dcvrlo.h"
+#include "dcmtk/dcmdata/dcvrpn.h"
+#include "dcmtk/dcmdata/dcvrsh.h"
+#include "dcmtk/dcmdata/dcvrtm.h"
+#include "dcmtk/dcmdata/dcvrui.h"
+
 #include "dcmtk/ofstd/ofstream.h"
 
 
@@ -212,7 +221,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Replace the currently stored document tree with the given one.  Please note that the
      *  given 'tree' is checked before setting it, i.e. only a valid document tree is accepted.
      *  However, a new SOP instance is never created.  If needed, this has to be done with
-     *  createNewSOPInstance() in addition to or with createNewDocument() before this method.
+     *  createNewSOPInstance() in addition to or with createNewDocument() before this method
+     *  is called.
      ** @param  tree  document tree to be set (content will be copied)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
@@ -220,27 +230,32 @@ class DCMTK_DCMSR_EXPORT DSRDocument
 
     /** set document tree from root template.
      *  Replace the currently stored document tree with the one from the given root template.
-     *  This is just a convenience function, so the additional comments on the above setTree()
-     *  method also apply.
+     *  By default, this method expands the tree, i.e. instances of DSRIncludedTemplateTreeNode
+     *  that were added to the tree with DSRDocumentSubTree::includeTemplate() are replaced by
+     *  their content, i.e. by the internally managed subtree.
+     *  Please note that the additional comments on the above setTree() method also apply.
      ** @param  rootTemplate  template specifying the document tree to be set (content will be
      *                        copied).  This parameter cannot be "const" because of
      *                        DSRRootTemplate::getTree(), which is called internally and which
      *                        modifies the tree.
+     *  @param  expandTree    optional flag that allows for disabling the expanding of the
+     *                        document tree before setting it.  Please note that various
+     *                        output methods like write() or renderHTML() do not yet work on
+     *                        such trees.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    virtual OFCondition setTreeFromRootTemplate(DSRRootTemplate &rootTemplate);
+    virtual OFCondition setTreeFromRootTemplate(DSRRootTemplate &rootTemplate,
+                                                const OFBool expandTree = OFTrue);
 
     /** get specific character set type.
-     *  If the type is unknown the original DICOM defined term can be retrieved
-     *  with the method getSpecificCharacterSet().  Please note that only the
-     *  first of possibly multiple values is used to determine the type from the
-     *  given DICOM code string (multiple character sets are not yet supported).
+     *  If the type is unknown, the original DICOM defined term can be retrieved
+     *  with the method getSpecificCharacterSet().
      ** @return character set (might be CS_invalid/unknown if not supported)
      */
     virtual E_CharacterSet getSpecificCharacterSetType() const;
 
     /** set specific character set type.
-     *  The DICOM defined term (see SpecificCharacterSet) is set accordingly.
+     *  The DICOM defined term (see member variable SpecificCharacterSet) is set accordingly.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition setSpecificCharacterSetType(const E_CharacterSet characterSet);
@@ -661,10 +676,13 @@ class DCMTK_DCMSR_EXPORT DSRDocument
   // --- set DICOM string attributes ---
 
     /** set specific character set.  The internal enumerated value is set accordingly.
-     *  Please note that code extensions techniques are not supported.  Therefore, only
-     *  a single value can be passed.
-     ** @param  value  value to be set (single value only) or "" for no value
-     *  @param  check  check 'value' for conformance with VR (CS) and VM (1) if enabled
+     *  Please note that this method does not return an error if the given 'value' is not
+     *  defined by the DICOM standard or not supported by this class, e.g. when no mapping
+     *  to the character set names needed for HTML/XHTML or XML output is defined.
+     *  If needed, check the return value of the method getSpecificCharacterSetType() for
+     *  DSRTypes::CS_invalid or DSRTypes::CS_unknown after calling this method.
+     ** @param  value  value to be set (single or multiple values) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1-n) if enabled
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition setSpecificCharacterSet(const OFString &value,
@@ -905,7 +923,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  be created (this is the case if the study instance UID or series instance UID has
      *  changed as well as any other attribute within the SR Document General Module or
      *  SR Document Content Module, see DICOM standard for details).
-     *  This method also updates the other DICOM header attributes (calling updateAttributes()).
+     *  This method also updates other DICOM header attributes (by calling updateAttributes()).
+     *  However, instance-level attributes other than the SOP instance UID are usually not
+     *  changed (if already set), e.g. the current instance number or content date/time.
      */
     virtual void createNewSOPInstance();
 
@@ -1158,6 +1178,11 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     OFCondition checkDatasetForReading(DcmItem &dataset,
                                        E_DocumentType &documentType);
 
+    /** get current value of specific character set
+     ** @return pointer to character string (never NULL)
+     */
+    const char *getSpecificCharacterSet() const;
+
     /** update various DICOM attributes.
      *  (e.g. set the modality and SOP class UID, generate a new Study, Series and SOP instance UID
      *  if required, set date/time values, etc.)
@@ -1183,7 +1208,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /// defined term: see class DSRTypes
     E_CharacterSet     SpecificCharacterSetEnum;
 
-    // DICOM attributes are listed ordered by module.
+    // DICOM attributes are listed ordered by Module.
     // The comments for each attribute describe "Name: (VR, VM, Type)".
     // Please note that for particular SR documents (e.g. Key Object Selection)
     // other rules might apply.  See DICOM standard for further reference.
@@ -1203,7 +1228,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmTime             InstanceCreationTime;
     /// Instance Creator UID: (UI, 1, 3)
     DcmUniqueIdentifier InstanceCreatorUID;
-    /// Coding Scheme Identification Sequence: (SQ, 1, 3)
+    /// Coding Scheme Identification Sequence: (SQ, 1-n, 3)
     DSRCodingSchemeIdentificationList CodingSchemeIdentification;
 
     // --- General Study Module (M) ---
@@ -1276,6 +1301,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmLongString       ProtocolName;
     /// Series Description: (LO, 1, 3)
     DcmLongString       SeriesDescription;
+    /// Series Description Code Sequence: (SQ, 1, 3)
+     // - tbd: optional attribute not yet supported
     /// Referenced Performed Procedure Step Sequence: (SQ, 1, 2)
     DcmSequenceOfItems  ReferencedPerformedProcedureStep;
 
@@ -1295,21 +1322,27 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmDate             ContentDate;
     /// Content Time: (TM, 1, 1)
     DcmTime             ContentTime;
-    /// Verifying Observer Sequence: (SQ, 1, 1C)
+    /// Verifying Observer Sequence: (SQ, 1-n, 1C)
     DcmSequenceOfItems  VerifyingObserver;
-    /// Predecessor Documents Sequence: (SQ, 1, 1C)
+    /// Author Observer Sequence: (SQ, 1-n, 3)
+     // - tbd: optional attribute not yet supported
+    /// Participant Sequence: (SQ, 1-n, 3)
+     // - tbd: optional attribute not yet supported
+    /// Custodial Organization Sequence: (SQ, 1, 3)
+     // - tbd: optional attribute not yet supported
+    /// Predecessor Documents Sequence: (SQ, 1-n, 1C)
     DSRSOPInstanceReferenceList PredecessorDocuments;
-    /// Identical Documents Sequence: (SQ, 1, 1C)
+    /// Identical Documents Sequence: (SQ, 1-n, 1C)
     DSRSOPInstanceReferenceList IdenticalDocuments;
-    // Referenced Request Sequence: (SQ, 1, 1C)
-    // - tbd: conditional attribute not yet supported
-    /// Performed Procedure Code Sequence: (SQ, 1, 2)
+    // Referenced Request Sequence: (SQ, 1-n, 1C)
+     // - tbd: conditional attribute not yet supported
+    /// Performed Procedure Code Sequence: (SQ, 1-n, 2)
     DcmSequenceOfItems  PerformedProcedureCode;
-    /// Current Requested Procedure Evidence Sequence: (SQ, 1, 1C)
+    /// Current Requested Procedure Evidence Sequence: (SQ, 1-n, 1C)
     DSRSOPInstanceReferenceList CurrentRequestedProcedureEvidence;
-    /// Pertinent Other Evidence Sequence: (SQ, 1, 1C)
+    /// Pertinent Other Evidence Sequence: (SQ, 1-n, 1C)
     DSRSOPInstanceReferenceList PertinentOtherEvidence;
-    /// Referenced Instance Sequence: (SQ, 1, 1C)
+    /// Referenced Instance Sequence: (SQ, 1-n, 1C)
     DSRReferencedInstanceList ReferencedInstances;
 
  // --- declaration of copy constructor and assignment operator ---
