@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2012, OFFIS e.V.
+ *  Copyright (C) 2002-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -27,13 +27,6 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/ofstd/oflist.h"
-#include "dcmtk/ofstd/ofstring.h"
-#include "dcmtk/ofstd/ofcond.h"
-
-#include "dcmtk/dcmdata/dcitem.h"
-#include "dcmtk/dcmdata/dctagkey.h"
-
 #include "dcmtk/dcmsr/dsrtypes.h"
 #include "dcmtk/dcmsr/dsrcodvl.h"
 
@@ -79,9 +72,11 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      *  i.e. the structure might look different when written back to a dataset.  However,
      *  the content is identical and this way of storing information saves storage space.
      ** @param  dataset  DICOM dataset from which the data should be read
+     *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition read(DcmItem &dataset);
+    OFCondition read(DcmItem &dataset,
+                     const size_t flags);
 
     /** write list of referenced SOP instances.
      *  Does nothing if list is empty.
@@ -97,7 +92,7 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      *  the content is identical and this way of storing information saves storage space.
      ** @param  doc     document containing the XML file content
      *  @param  cursor  cursor pointing to the starting node
-     *  @param  flags   optional flag used to customize the reading process (see DSRTypes::XF_xxx)
+     *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition readXML(const DSRXMLDocument &doc,
@@ -106,11 +101,21 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
     /** write current list of references in XML format
      ** @param  stream  output stream to which the XML data is written
-     *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
+     *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                         const size_t flags = 0) const;
+                         const size_t flags) const;
+
+    /** set specific character set, which is used for checking the affected element values.
+     *  Please note that this method does not return an error if the given 'value' is not
+     *  defined by the DICOM standard or not supported by this implementation.
+     ** @param  value  value to be set (single or multiple values) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (CS) and VM (1-n) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    OFCondition setSpecificCharacterSet(const OFString &value,
+                                        const OFBool check = OFTrue);
 
     /** add the specified item to the list of references.
      *  Before adding the item, the given UID values are usually checked.  If one of the
@@ -232,6 +237,15 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
      */
     const OFString &getSOPClassUID(OFString &stringValue) const;
 
+    /** get name associated with the SOP class UID of the currently selected entry
+     ** @param  stringValue  reference to string variable in which the result is stored
+     *  @param  defaultName  string value that is returned if the SOP class UID is unknown
+     ** @return reference to the resulting string (might be empty even if 'defaultName' is
+     *          non-empty, e.g. in case no entry is currently selected)
+     */
+    const OFString &getSOPClassName(OFString &stringValue,
+                                    const OFString &defaultName = "unknown SOP Class UID") const;
+
     /** get the retrieve application entity title of the currently selected entry (optional).
      *  The resulting string may contain multiple values separated by a backslash ("\").
      ** @param  stringValue  reference to string variable in which the result is stored
@@ -356,9 +370,11 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
         /** read instance level attributes from dataset
          ** @param  dataset  DICOM dataset from which the list should be read
+         *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset);
+        OFCondition read(DcmItem &dataset,
+                         const size_t flags);
 
         /** write series and instance level attributes to dataset
          ** @param  dataset  DICOM dataset to which the list should be written
@@ -369,18 +385,20 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
         /** read series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
          *  @param  cursor  cursor pointing to the starting node
+         *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition readXML(const DSRXMLDocument &doc,
-                            DSRXMLCursor cursor);
+                            DSRXMLCursor cursor,
+                            const size_t flags);
 
         /** write series and instance level attributes in XML format
          ** @param  stream  output stream to which the XML document is written
-         *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
+         *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                             const size_t flags = 0) const;
+                             const size_t flags) const;
 
         /** set cursor to the specified instance (if existent)
          ** @param  instanceUID  SOP instance UID of the entry to be searched for
@@ -456,9 +474,11 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
 
         /** read series and instance level from dataset
          ** @param  dataset  DICOM dataset from which the list should be read
+         *  @param  flags    flag used to customize the reading process (see DSRTypes::RF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset);
+        OFCondition read(DcmItem &dataset,
+                         const size_t flags);
 
         /** write study, series and instance level attributes to dataset
          ** @param  dataset  DICOM dataset to which the list should be written
@@ -469,18 +489,20 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
         /** read study, series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
          *  @param  cursor  cursor pointing to the starting node
+         *  @param  flags   flag used to customize the reading process (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition readXML(const DSRXMLDocument &doc,
-                            DSRXMLCursor cursor);
+                            DSRXMLCursor cursor,
+                            const size_t flags);
 
         /** write study, series and instance level attributes in XML format
          ** @param  stream  output stream to which the XML document is written
-         *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
+         *  @param  flags   flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
         OFCondition writeXML(STD_NAMESPACE ostream &stream,
-                             const size_t flags = 0) const;
+                             const size_t flags) const;
 
         /** set cursor to the specified series entry (if existent)
          ** @param  seriesUID  series instance UID of the entry to be searched for
@@ -602,6 +624,8 @@ class DCMTK_DCMSR_EXPORT DSRSOPInstanceReferenceList
     OFList<StudyStruct *> StudyList;
     /// internal cursor to current (selected) list item
     OFListIterator(StudyStruct *) Iterator;
+    /// specific character set used for checking purposes
+    OFString SpecificCharacterSet;
 
     // default constructor - not implemented!
     DSRSOPInstanceReferenceList();
