@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,12 +26,11 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/ofstd/ofstring.h"
-#include "dcmtk/ofstd/ofstack.h"
-#include "dcmtk/ofstd/oflist.h"
-
-#include "dcmtk/dcmsr/dsdefine.h"
 #include "dcmtk/dcmsr/dsrtypes.h"
+#include "dcmtk/dcmsr/dsrposcn.h"
+#include "dcmtk/dcmsr/dsrtnant.h"
+
+#include "dcmtk/ofstd/ofstack.h"
 
 
 /*-----------------------*
@@ -45,9 +44,13 @@ class DSRTreeNode;
  *  class declaration  *
  *---------------------*/
 
-/** Class implementing a tree node cursor
+/** Class implementing a tree node cursor.
+ ** @tparam  T  template type used for the tree node pointers
+ *  @tparam  B  boolean flag that indicates whether to treat certain tree nodes
+ *              differently (depends on the particular implementation)
  */
-template<typename T = DSRTreeNode> class DSRTreeNodeCursor
+template<typename T = DSRTreeNode, OFBool B = OFFalse>
+class DSRTreeNodeCursor
 {
 
   public:
@@ -59,12 +62,16 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
     /** copy constructor
      ** @param  cursor  object to be copied
      */
-    DSRTreeNodeCursor(const DSRTreeNodeCursor<T> &cursor);
+    DSRTreeNodeCursor(const DSRTreeNodeCursor<T, B> &cursor);
 
-    /** constructor
-     ** @param  node  pointer to tree node used to initialize the cursor (set to this node)
+    /** constructor.
+     *  See comments on setCursor(T*) method.
+     ** @param  node      pointer to tree node used to initialize the cursor
+     *  @param  position  optional pointer to position counter that should be used to
+     *                    initialize the internal counter
      */
-    DSRTreeNodeCursor(T *node);
+    DSRTreeNodeCursor(T *node,
+                      const DSRPositionCounter *position = NULL);
 
     /** destructor
      */
@@ -74,15 +81,17 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
      ** @param  cursor  object to be copied
      ** @return reference to modified cursor (this object)
      */
-    DSRTreeNodeCursor<T> &operator=(const DSRTreeNodeCursor<T> &cursor);
+    DSRTreeNodeCursor<T, B> &operator=(const DSRTreeNodeCursor<T, B> &cursor);
 
-    /** assignment operator
+    /** assignment operator.
+     *  See comments on setCursor(T*) method.
      ** @param  node  node to which the cursor should be set
      ** @return reference to modified cursor (this object)
      */
-    DSRTreeNodeCursor<T> &operator=(T *node);
+    DSRTreeNodeCursor<T, B> &operator=(T *node);
 
-    /** clear all member variables
+    /** clear all member variables.
+     *  The cursor becomes invalid afterwards (same state as after default construction).
      */
     virtual void clear();
 
@@ -103,27 +112,27 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
     /** check whether the current node has a parent
      ** @return OFTrue if the current node has a parent, OFFalse otherwise
      */
-    OFBool hasParentNode() const;
+    inline OFBool hasParentNode() const;
 
     /** check whether the current node has any children
      ** @return OFTrue if the current node has any children, OFFalse otherwise
      */
-    OFBool hasChildNodes() const;
+    inline OFBool hasChildNodes() const;
 
     /** check whether the current node has a preceding sibling
      ** @return OFTrue if the current node has a preceding sibling, OFFalse otherwise
      */
-    OFBool hasPreviousNode() const;
+    inline OFBool hasPreviousNode() const;
 
     /** check whether the current node has a following sibling
      ** @return OFTrue if the current node has a following sibling, OFFalse otherwise
      */
-    OFBool hasNextNode() const;
+    inline OFBool hasNextNode() const;
 
     /** check whether the current node has any siblings
      ** @return OFTrue if the current node has any siblings, OFFalse otherwise
      */
-    OFBool hasSiblingNodes() const;
+    inline OFBool hasSiblingNodes() const;
 
     /** get pointer to current node
      ** @return pointer to current node (might be NULL)
@@ -134,7 +143,7 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
      *  Can be used to have a lookup to the parent node without changing the cursor.
      ** @return pointer to parent node (if any), NULL otherwise
      */
-    virtual const T *getParentNode();
+    virtual const T *getParentNode() const;
 
     /** get pointer to first child node.
      *  Can be used to have a lookup to the first child node without changing the cursor.
@@ -186,6 +195,14 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
      */
     size_t goDown();
 
+    /** @copydoc goUp()
+     */
+    inline size_t gotoParent();
+
+    /** @copydoc goDown()
+     */
+    inline size_t gotoChild();
+
     /** iterate over all nodes. Starts from current position!
      ** @param  searchIntoSub  flag indicating whether to search into sub-trees
      *                         ("deep search") or on the current level only
@@ -209,18 +226,31 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
     size_t gotoNode(const OFString &position,
                     const char separator = '.');
 
+    /** set cursor to specified node. Starts from current position!
+     ** @param  annotation  annotation of the node to set the cursor to
+     ** @return ID of the new current node if successful, 0 otherwise
+     */
+    size_t gotoNode(const DSRTreeNodeAnnotation &annotation);
+
     /** get current node ID.
      *  The node ID uniquely identifies a content item in the document tree.  Most of
      *  the navigation methods above do return this ID too.
      ** @return ID of the current node if valid, 0 otherwise
      */
-    size_t getNodeID() const;
+    inline size_t getNodeID() const;
 
     /** get current level.
      *  The level starts with 1 for the root node, then 2 for its child nodes, etc.
      ** @return number of the current level if valid, 0 otherwise
      */
-    size_t getLevel() const;
+    inline size_t getLevel() const;
+
+    /** get reference to internal position counter.
+     *  Please note that this method allows for manipulating the internal position
+     *  counter, so handle with care!
+     ** @return reference to internal position counter
+     */
+    inline DSRPositionCounter &getPositionCounter();
 
     /** get position string of the current node.
      *  Specifies the position of each node by means of a dot separated string of
@@ -233,8 +263,8 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
      *  @param  separator  character used to separate the figures (default: '.')
      ** @return reference to the resulting position string (empty if invalid)
      */
-    const OFString &getPosition(OFString &position,
-                                const char separator = '.') const;
+    inline const OFString &getPosition(OFString &position,
+                                       const char separator = '.') const;
 
 
   protected:
@@ -243,8 +273,19 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
      */
     void clearNodeCursorStack();
 
+    /** get cursor
+     ** @return reference to cursor (this object)
+     */
+    inline const DSRTreeNodeCursor<T, B> &getCursor() const;
+
+    /** set cursor to specified object
+     ** @param  cursor  object to set this cursor to
+     */
+    inline void setCursor(const DSRTreeNodeCursor<T, B> &cursor);
+
     /** set cursor to specified node.
-     *  Clears the internal position list/stack and sets the position counter to 1.
+     *  Clears the internal position counter and sets the position of the current level
+     *  to 1 (if the passed 'node' is valid) or 0 (if the 'node' is invalid).
      ** @param  node  node to which the cursor should be set
      ** @return ID of the new current node if successful, 0 otherwise
      */
@@ -255,10 +296,8 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
     /// stack of node pointers. Used to store the cursor position of upper levels.
     OFStack<T *> NodeCursorStack;
 
-    /// current position within the current level
-    size_t Position;
-    /// list of position counters in upper levels
-    OFList<size_t> PositionList;
+    /// counter for the current position within the current level and on upper levels
+    DSRPositionCounter Position;
 };
 
 
@@ -266,95 +305,97 @@ template<typename T = DSRTreeNode> class DSRTreeNodeCursor
  *  implementation  *
  *------------------*/
 
-template<typename T>
-DSRTreeNodeCursor<T>::DSRTreeNodeCursor()
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B>::DSRTreeNodeCursor()
   : NodeCursor(NULL),
     NodeCursorStack(),
-    Position(0),
-    PositionList()
+    Position()
 {
 }
 
 
-template<typename T>
-DSRTreeNodeCursor<T>::DSRTreeNodeCursor(const DSRTreeNodeCursor<T> &cursor)
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B>::DSRTreeNodeCursor(const DSRTreeNodeCursor<T, B> &cursor)
   : NodeCursor(cursor.NodeCursor),
     NodeCursorStack(cursor.NodeCursorStack),
-    Position(cursor.Position),
-    PositionList(cursor.PositionList)
+    Position(cursor.Position)
 {
 }
 
 
-template<typename T>
-DSRTreeNodeCursor<T>::DSRTreeNodeCursor(T *node)
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B>::DSRTreeNodeCursor(T *node,
+                                           const DSRPositionCounter *position)
   : NodeCursor(node),
     NodeCursorStack(),
-    Position((node != NULL) ? 1 : 0),
-    PositionList()
+    Position()
+{
+    /* check whether a valid position counter is given */
+    if (position != NULL)
+    {
+        if (position->isValid())
+            Position = *position;
+        else
+            Position.initialize(NodeCursor != NULL, position->getFlags());
+    } else
+        Position.initialize(NodeCursor != NULL);
+}
+
+
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B>::~DSRTreeNodeCursor()
 {
 }
 
 
-template<typename T>
-DSRTreeNodeCursor<T>::~DSRTreeNodeCursor()
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B> &DSRTreeNodeCursor<T, B>::operator=(const DSRTreeNodeCursor<T, B> &cursor)
 {
-}
-
-
-template<typename T>
-DSRTreeNodeCursor<T> &DSRTreeNodeCursor<T>::operator=(const DSRTreeNodeCursor<T> &cursor)
-{
-    NodeCursor = cursor.NodeCursor;
-    NodeCursorStack = cursor.NodeCursorStack;
-    Position = cursor.Position;
-    /* copy position list (operator= is not private anymore in class OFList) */
-    PositionList = cursor.PositionList;
+    setCursor(cursor);
     return *this;
 }
 
 
-template<typename T>
-DSRTreeNodeCursor<T> &DSRTreeNodeCursor<T>::operator=(T *node)
+template<typename T, OFBool B>
+DSRTreeNodeCursor<T, B> &DSRTreeNodeCursor<T, B>::operator=(T *node)
 {
     setCursor(node);
     return *this;
 }
 
 
-template<typename T>
-void DSRTreeNodeCursor<T>::clear()
+template<typename T, OFBool B>
+void DSRTreeNodeCursor<T, B>::clear()
 {
     NodeCursor = NULL;
     clearNodeCursorStack();
-    Position = 0;
-    PositionList.clear();
+    Position.clear();
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::isValid() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::isValid() const
 {
     return (NodeCursor != NULL);
 }
 
 
-template<typename T>
-void DSRTreeNodeCursor<T>::clearNodeCursorStack()
+template<typename T, OFBool B>
+void DSRTreeNodeCursor<T, B>::clearNodeCursorStack()
 {
     while (!NodeCursorStack.empty())
         NodeCursorStack.pop();
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::countChildNodes(const OFBool searchIntoSub) const
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::countChildNodes(const OFBool searchIntoSub) const
 {
     size_t count = 0;
     if (NodeCursor != NULL)
     {
         /* do we have any children at all? */
-        DSRTreeNodeCursor<T> cursor(NodeCursor->getDown());
+        DSRTreeNodeCursor<T, B> cursor(NodeCursor->getDown());
         if (cursor.isValid())
         {
             /* iterate over all child nodes */
@@ -367,63 +408,60 @@ size_t DSRTreeNodeCursor<T>::countChildNodes(const OFBool searchIntoSub) const
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::hasParentNode() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::hasParentNode() const
 {
     return ((NodeCursor != NULL) && !NodeCursorStack.empty());
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::hasChildNodes() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::hasChildNodes() const
 {
     return (getChildNode() != NULL);
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::hasPreviousNode() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::hasPreviousNode() const
 {
     return (getPreviousNode() != NULL);
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::hasNextNode() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::hasNextNode() const
 {
     return (getNextNode() != NULL);
 }
 
 
-template<typename T>
-OFBool DSRTreeNodeCursor<T>::hasSiblingNodes() const
+template<typename T, OFBool B>
+OFBool DSRTreeNodeCursor<T, B>::hasSiblingNodes() const
 {
     return (getPreviousNode() != NULL) || (getNextNode() != NULL);
 }
 
 
-template<typename T>
-T *DSRTreeNodeCursor<T>::getNode() const
+template<typename T, OFBool B>
+T *DSRTreeNodeCursor<T, B>::getNode() const
 {
     return NodeCursor;
 }
 
 
-template<typename T>
-const T *DSRTreeNodeCursor<T>::getParentNode()
+template<typename T, OFBool B>
+const T *DSRTreeNodeCursor<T, B>::getParentNode() const
 {
     T *node = NULL;
     if (hasParentNode())
-    {
-        /* this method is not "const" because of OFStack.top() */
         node = NodeCursorStack.top();
-    }
     return node;
 }
 
 
-template<typename T>
-const T *DSRTreeNodeCursor<T>::getChildNode() const
+template<typename T, OFBool B>
+const T *DSRTreeNodeCursor<T, B>::getChildNode() const
 {
     T *node = NULL;
     if (NodeCursor != NULL)
@@ -432,8 +470,8 @@ const T *DSRTreeNodeCursor<T>::getChildNode() const
 }
 
 
-template<typename T>
-const T *DSRTreeNodeCursor<T>::getPreviousNode() const
+template<typename T, OFBool B>
+const T *DSRTreeNodeCursor<T, B>::getPreviousNode() const
 {
     T *node = NULL;
     if (NodeCursor != NULL)
@@ -442,8 +480,8 @@ const T *DSRTreeNodeCursor<T>::getPreviousNode() const
 }
 
 
-template<typename T>
-const T *DSRTreeNodeCursor<T>::getNextNode() const
+template<typename T, OFBool B>
+const T *DSRTreeNodeCursor<T, B>::getNextNode() const
 {
     T *node = NULL;
     if (NodeCursor != NULL)
@@ -452,25 +490,37 @@ const T *DSRTreeNodeCursor<T>::getNextNode() const
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::setCursor(T *node)
+template<typename T, OFBool B>
+const DSRTreeNodeCursor<T, B> &DSRTreeNodeCursor<T, B>::getCursor() const
+{
+    return *this;
+}
+
+
+template<typename T, OFBool B>
+void DSRTreeNodeCursor<T, B>::setCursor(const DSRTreeNodeCursor<T, B> &cursor)
+{
+    NodeCursor = cursor.NodeCursor;
+    NodeCursorStack = cursor.NodeCursorStack;
+    Position = cursor.Position;
+}
+
+
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::setCursor(T *node)
 {
     size_t nodeID = 0;
     NodeCursor = node;
-    clearNodeCursorStack();
-    PositionList.clear();
     if (NodeCursor != NULL)
-    {
         nodeID = NodeCursor->getIdent();
-        Position = 1;
-    } else
-        Position = 0;
+    clearNodeCursorStack();
+    Position.initialize(NodeCursor != NULL);
     return nodeID;
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoFirst()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoFirst()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -486,8 +536,8 @@ size_t DSRTreeNodeCursor<T>::gotoFirst()
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoLast()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoLast()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -503,8 +553,8 @@ size_t DSRTreeNodeCursor<T>::gotoLast()
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoPrevious()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoPrevious()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -520,8 +570,8 @@ size_t DSRTreeNodeCursor<T>::gotoPrevious()
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoNext()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoNext()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -537,8 +587,8 @@ size_t DSRTreeNodeCursor<T>::gotoNext()
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::goUp()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::goUp()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -551,11 +601,7 @@ size_t DSRTreeNodeCursor<T>::goUp()
             {
                 NodeCursor = cursor;
                 nodeID = NodeCursor->getIdent();
-                if (!PositionList.empty())
-                {
-                    Position = PositionList.back();
-                    PositionList.pop_back();
-                }
+                Position.goUp();
             }
         }
     }
@@ -563,8 +609,8 @@ size_t DSRTreeNodeCursor<T>::goUp()
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::goDown()
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::goDown()
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -574,19 +620,29 @@ size_t DSRTreeNodeCursor<T>::goDown()
             NodeCursorStack.push(NodeCursor);
             NodeCursor = NodeCursor->getDown();
             nodeID = NodeCursor->getIdent();
-            if (Position > 0)
-            {
-                PositionList.push_back(Position);
-                Position = 1;
-            }
+            Position.goDown();
         }
     }
     return nodeID;
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::iterate(const OFBool searchIntoSub)
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoParent()
+{
+    return goUp();
+}
+
+
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoChild()
+{
+    return goDown();
+}
+
+
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::iterate(const OFBool searchIntoSub)
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -597,11 +653,7 @@ size_t DSRTreeNodeCursor<T>::iterate(const OFBool searchIntoSub)
             NodeCursorStack.push(NodeCursor);
             NodeCursor = NodeCursor->getDown();
             nodeID = NodeCursor->getIdent();
-            if (Position > 0)
-            {
-                PositionList.push_back(Position);
-                Position = 1;
-            }
+            Position.goDown();
         }
         else if (NodeCursor->getNext() != NULL)
         {
@@ -616,11 +668,7 @@ size_t DSRTreeNodeCursor<T>::iterate(const OFBool searchIntoSub)
                 {
                     NodeCursor = NodeCursorStack.top();
                     NodeCursorStack.pop();
-                    if (!PositionList.empty())
-                    {
-                        Position = PositionList.back();
-                        PositionList.pop_back();
-                    }
+                    Position.goUp();
                 } else
                     NodeCursor = NULL;
             } while ((NodeCursor != NULL) && (NodeCursor->getNext() == NULL));
@@ -639,8 +687,8 @@ size_t DSRTreeNodeCursor<T>::iterate(const OFBool searchIntoSub)
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoNode(const size_t searchID)
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoNode(const size_t searchID)
 {
     size_t nodeID = 0;
     if (searchID > 0)
@@ -656,9 +704,9 @@ size_t DSRTreeNodeCursor<T>::gotoNode(const size_t searchID)
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::gotoNode(const OFString &position,
-                                      const char separator)
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoNode(const OFString &position,
+                                         const char separator)
 {
     size_t nodeID = 0;
     if (!position.empty())
@@ -703,8 +751,25 @@ size_t DSRTreeNodeCursor<T>::gotoNode(const OFString &position,
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::getNodeID() const
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::gotoNode(const DSRTreeNodeAnnotation &annotation)
+{
+    size_t nodeID = 0;
+    if (!annotation.isEmpty())
+    {
+        if (NodeCursor != NULL)
+        {
+            nodeID = NodeCursor->getIdent();
+            while ((nodeID > 0) && (NodeCursor->getAnnotation() != annotation))
+                nodeID = iterate();
+        }
+    }
+    return nodeID;
+}
+
+
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::getNodeID() const
 {
     size_t nodeID = 0;
     if (NodeCursor != NULL)
@@ -713,8 +778,8 @@ size_t DSRTreeNodeCursor<T>::getNodeID() const
 }
 
 
-template<typename T>
-size_t DSRTreeNodeCursor<T>::getLevel() const
+template<typename T, OFBool B>
+size_t DSRTreeNodeCursor<T, B>::getLevel() const
 {
     size_t level = 0;
     if (NodeCursor != NULL)
@@ -723,28 +788,18 @@ size_t DSRTreeNodeCursor<T>::getLevel() const
 }
 
 
-template<typename T>
-const OFString &DSRTreeNodeCursor<T>::getPosition(OFString &position,
-                                                  const char separator) const
+template<typename T, OFBool B>
+DSRPositionCounter &DSRTreeNodeCursor<T, B>::getPositionCounter()
 {
-    position.clear();
-    if (Position > 0)
-    {
-        char stringBuf[20];
-        const OFListConstIterator(size_t) endPos = PositionList.end();
-        OFListConstIterator(size_t) iterator = PositionList.begin();
-        while (iterator != endPos)
-        {
-            if (!position.empty())
-                position += separator;
-            position += DSRTypes::numberToString(*iterator, stringBuf);
-            iterator++;
-        }
-        if (!position.empty())
-            position += separator;
-        position += DSRTypes::numberToString(Position, stringBuf);
-    }
-    return position;
+    return Position;
+}
+
+
+template<typename T, OFBool B>
+const OFString &DSRTreeNodeCursor<T, B>::getPosition(OFString &position,
+                                                     const char separator) const
+{
+    return Position.getString(position, separator);
 }
 
 
