@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,14 +26,20 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmdata/dctk.h"
+#include "dcmtk/dcmsr/dsdefine.h"
+
+#include "dcmtk/dcmdata/dcelem.h"
+#include "dcmtk/dcmdata/dcitem.h"
+#include "dcmtk/dcmdata/dcsequen.h"
 
 #include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/ofstd/ofstring.h"
 #include "dcmtk/ofstd/oftypes.h"
 #include "dcmtk/ofstd/ofcond.h"
 #include "dcmtk/oflog/oflog.h"
 
-#include "dcmtk/dcmsr/dsdefine.h"
+
+// global definitions for logging mechanism provided by the oflog module
 
 extern DCMTK_DCMSR_EXPORT OFLogger DCM_dcmsrLogger;
 
@@ -86,6 +92,7 @@ extern DCMTK_DCMSR_EXPORT OFLogger DCM_dcmsrLogger;
 #define DCMSR_ANSI_ESCAPE_CODE_CONCEPT_NAME      "\033[22m\033[33m"
 #define DCMSR_ANSI_ESCAPE_CODE_ITEM_VALUE        "\033[1m\033[37m"
 #define DCMSR_ANSI_ESCAPE_CODE_TEMPLATE_ID       "\033[22m\033[35m"
+#define DCMSR_ANSI_ESCAPE_CODE_ANNOTATION        "\033[22m\033[36m"
 #define DCMSR_ANSI_ESCAPE_CODE_DELIMITER         "\033[1m\033[30m"
 
 // helper macro for the conditional usage of ANSI escape codes
@@ -193,6 +200,31 @@ extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_InvalidContentItem;
 
 /// error: template identification cannot be used, i.e. requirements are not fulfilled
 extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_CannotUseTemplateIdentification;
+
+/// error: cannot add content item or insert subtree to non-extensible template
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_NonExtensibleTemplate;
+
+/// error: cannot add coded entry to non-extensible context group
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_NonExtensibleContextGroup;
+
+/// error: a given coded entry in not contained in the context group
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_CodedEntryNotInContextGroup;
+
+/// normal: a given coded entry is contained in the context group (i.e. a standard code)
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_CodedEntryInStandardContextGroup;
+
+/// normal: a given coded entry is known as an extension of the context group
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_CodedEntryIsExtensionOfContextGroup;
+
+/// error: a value violates the value set constraint of a particular template row
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_ValueSetConstraintViolated;
+
+/// error: the internally managed structure of a template class is invalid
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_InvalidTemplateStructure;
+
+/// error: cannot process document tree with included templates
+extern DCMTK_DCMSR_EXPORT const OFConditionConst SR_EC_CannotProcessIncludedTemplates;
+
 //@}
 
 
@@ -361,6 +393,9 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     /// read/write: template identification element encloses content items
     static const size_t XF_templateElementEnclosesItems;
 
+    /// write: add comments with details at beginning/end of included template (might be useful for debugging purposes)
+    static const size_t XF_addCommentsForIncludedTemplate;
+
     /// shortcut: combines all XF_xxxAsAttribute write flags (see above)
     static const size_t XF_encodeEverythingAsAttribute;
     //@}
@@ -402,13 +437,28 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     /// print code triple for invalid codes (instead of the text "invalid code")
     static const size_t PF_printInvalidCodes;
 
-    /// shortcut: print all codes
+    /// print node ID at the beginning of each line (might be useful for debugging purposes)
+    static const size_t PF_printNodeID;
+
+    /// indicate with a "*" that the "enhanced encoding mode" is used for codes
+    static const size_t PF_indicateEnhancedEncodingMode;
+
+    /// print annotation of a content item (optional, e.g. user-defined information)
+    static const size_t PF_printAnnotation;
+
+    /// do not print internal "included template" nodes (position counter is still increased)
+    static const size_t PF_hideIncludedTemplateNodes;
+
+    /// do not count internal "included template" nodes (only with PF_hideIncludedTemplateNodes)
+    static const size_t PF_dontCountIncludedTemplateNodes;
+
+    /// shortcut: print all codes (combines all PF_printXxxCodes flags, see above)
     static const size_t PF_printAllCodes;
     //@}
 
 
     /** @name checkByReferenceRelationships() modes
-     *  These flags can be combined and passed to the checkByReferenceRelationships() method.
+     *  These modes can be combined and passed to the checkByReferenceRelationships() method.
      */
     //@{
 
@@ -423,6 +473,20 @@ class DCMTK_DCMSR_EXPORT DSRTypes
     //@}
 
 
+    /** @name checkByReferenceRelationships() bit masks
+     *  These bit masks are used to "filter" valid flags passed to checkByReferenceRelationships().
+     */
+    //@{
+
+    /// bit mask (filter) for valid print flags (see PF_xxx)
+    static const size_t CB_maskPrintFlags;
+
+    /// bit mask (filter) for valid read flags (see RF_xxx)
+    static const size_t CB_maskReadFlags;
+
+    //@}
+
+
   // --- type definitions ---
 
     /** SR document types
@@ -461,8 +525,12 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         DT_Comprehensive3DSR,
         /// DICOM IOD: Radiopharmaceutical Radiation Dose SR
         DT_RadiopharmaceuticalRadiationDoseSR,
+        /// DICOM IOD: Extensible SR (not yet implemented)
+        DT_ExtensibleSR,
+        /// DICOM IOD: Acquisition Context SR
+        DT_AcquisitionContextSR,
         /// internal type used to mark the last entry
-        DT_last = DT_RadiopharmaceuticalRadiationDoseSR
+        DT_last = DT_AcquisitionContextSR
     };
 
     /** SR relationship types
@@ -531,8 +599,10 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         VT_Container,
         /// internal type used to indicate by-reference relationships
         VT_byReference,
+        /// internal type used to indicate (enclose) included templates
+        VT_includedTemplate,
         /// internal type used to mark the last entry
-        VT_last = VT_byReference
+        VT_last = VT_includedTemplate
     };
 
     /** Softcopy presentation state types.  Used for content item IMAGE.
@@ -553,8 +623,12 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         PT_Blending,
         /// XA/XRF Grayscale Softcopy Presentation State (XGSPS)
         PT_XAXRFGrayscale,
+        /// Grayscale Planar MPR Volumetric Presentation State (GPVPS)
+        PT_GrayscalePlanarMPR,
+        /// Compositing Planar MPR Volumetric Presentation State (CPVPS)
+        PT_CompositingPlanarMPR,
         /// internal type used to mark the last entry
-        PT_last = PT_XAXRFGrayscale
+        PT_last = PT_CompositingPlanarMPR
     };
 
     /** SR graphic types.  Used for content item SCOORD.
@@ -693,6 +767,8 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         CS_unknown = CS_invalid,
         /// ISO 646 (ISO-IR 6): ASCII
         CS_ASCII,
+        /// internal type used to indicate the default character set
+        CS_default = CS_ASCII,
         /// ISO-IR 100: Latin alphabet No. 1
         CS_Latin1,
         /// ISO-IR 101: Latin alphabet No. 2
@@ -711,10 +787,18 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         CS_Hebrew,
         /// ISO-IR 148: Latin alphabet No. 5
         CS_Latin5,
-        /// ISO-IR 13: Japanese (Katakana/Romaji)
-        CS_Japanese,
         /// ISO-IR 166: Thai
         CS_Thai,
+        /// ISO-IR 13/87: Japanese (Katakana/Romaji/Kanji)
+        CS_Japanese,
+        /// ISO-IR 6/149: Korean (Hangul/Hanja)
+        CS_Korean,
+        /// ISO-IR 6/58: Chinese
+        CS_ChineseISO,
+        /// GB18030: Chinese
+        CS_ChineseGB18030,
+        /// GBK: Chinese
+        CS_ChineseGBK,
         /// UTF-8: Unicode in UTF-8
         CS_UTF8,
         /// internal type used to mark the last entry
@@ -744,7 +828,9 @@ class DCMTK_DCMSR_EXPORT DSRTypes
         /// add new node before current one (sibling)
         AM_beforeCurrent,
         /// add new node below current one (after last child)
-        AM_belowCurrent
+        AM_belowCurrent,
+        /// add new node below current one (before first child)
+        AM_belowCurrentBeforeFirstChild
     };
 
 
@@ -985,7 +1071,8 @@ class DCMTK_DCMSR_EXPORT DSRTypes
      */
     static E_VerificationFlag enumeratedValueToVerificationFlag(const OFString &enumeratedValue);
 
-    /** convert DICOM defined term to character set
+    /** convert DICOM defined term to character set.
+     *  An empty defined term is mapped to DSRTypes::CS_default (which is ASCII).
      ** @param  definedTerm  defined term to be converted
      ** @return character set if successful, DSRTypes::CS_invalid otherwise
      */
@@ -1218,7 +1305,7 @@ class DCMTK_DCMSR_EXPORT DSRTypes
 
     /** get string value from element
      ** @param  delem        DICOM element from which the string value should be retrieved
-     *  @param  stringValue  reference to variable in which the result should be stored.
+     *  @param  stringValue  reference to variable in which the result should be stored
      *                       (This parameter is automatically cleared if an error occurs.)
      *  @param  pos          index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -1247,18 +1334,19 @@ class DCMTK_DCMSR_EXPORT DSRTypes
                                                       OFString &stringValue,
                                                       const OFBool convertNonASCII = OFFalse);
 
-    /** get string value from dataset.
-     *  Please note that only the first element value is retrieved (in case of multiple values).
+    /** get string value from dataset
      ** @param  dataset      DICOM dataset from which the string should be retrieved.
      *                       (Would be 'const' if the methods from 'dcmdata' would also be 'const'.)
      *  @param  tagKey       DICOM tag specifying the attribute from which the string should be retrieved
-     *  @param  stringValue  reference to variable in which the result should be stored.
+     *  @param  stringValue  reference to variable in which the result should be stored
      *                       (This parameter is automatically cleared if the tag could not be found.)
+     *  @param  pos          index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     static OFCondition getStringValueFromDataset(DcmItem &dataset,
                                                  const DcmTagKey &tagKey,
-                                                 OFString &stringValue);
+                                                 OFString &stringValue,
+                                                 const signed long pos = 0);
 
     /** put string value to dataset
      ** @param  dataset      reference to DICOM dataset to which the string should be put.
