@@ -47,7 +47,7 @@ DSRDocumentSubTree::DSRDocumentSubTree(const DSRDocumentSubTree &tree)
 {
     /* the real work is done in the base class DSRTree,
      * so just update the by-reference relationships (if any) */
-    checkByReferenceRelationships(CM_updateNodeID);
+    checkByReferenceRelationships<DSRDocumentTreeNodeCursor>(CM_updateNodeID);
 }
 
 
@@ -174,15 +174,15 @@ OFBool DSRDocumentSubTree::canUseTemplateIdentification() const
 
 OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
                                       const size_t flags,
-                                      DSRPositionCounter *posCounter)
+                                      const DSRPositionCounter *posCounter)
 {
     OFCondition result = EC_Normal;
     /* initialize cursor with root node (and optional position counter) */
-    DSRDocumentTreeNodeCursor cursor(getRoot(), posCounter);
+    DSRIncludedTemplateNodeCursor cursor(getRoot(), posCounter);
     if (cursor.isValid())
     {
-        /* check and update by-reference relationships (if applicable) */
-        checkByReferenceRelationships(CM_updatePositionString);
+        /* check and update by-reference relationships */
+        checkByReferenceRelationships<DSRIncludedTemplateNodeCursor>(CM_updatePositionString, flags & CB_maskPrintFlags);
         /* update the document tree for output (if needed) */
         updateTreeForOutput();
         OFString tmpString;
@@ -220,22 +220,10 @@ OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
                     DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_RESET)
                     stream << OFendl;
                 }
-                /* print content of included template (subtree) */
-                if (node->hasValidValue())
+                else if ((flags & PF_dontCountIncludedTemplateNodes) && !(cursor.getPositionCounter().getFlags() & PF_dontCountIncludedTemplateNodes))
                 {
-                    DSRSubTemplate *subTempl = OFstatic_cast(DSRIncludedTemplateTreeNode *, node)->getValue().get();
-                    /* further indent included subtree */
-                    if (!(flags & PF_hideIncludedTemplateNodes))
-                        cursor.getPositionCounter().goDown();
-                    /* only print non-empty template (subtree) */
-                    if (!subTempl->isEmpty())
-                        result = subTempl->print(stream, flags, &cursor.getPositionCounter());
-                    /* make sure that empty templates are not counted */
-                    else if (flags & PF_hideIncludedTemplateNodes)
-                        --cursor.getPositionCounter();
-                    /* reset indentation of included subtree */
-                    if (!(flags & PF_hideIncludedTemplateNodes))
-                        cursor.getPositionCounter().goUp();
+                    /* do not count internal "included template" nodes */
+                    --cursor.getPositionCounter();
                 }
             } else {
                 /* print node content */
@@ -252,9 +240,6 @@ OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
             }
         } while (result.good() && cursor.iterate());
     }
-    /* store and return current value of position counter (if needed) */
-    if (posCounter != NULL)
-        *posCounter = cursor.getPositionCounter();
     return result;
 }
 
@@ -271,7 +256,7 @@ OFCondition DSRDocumentSubTree::writeXML(STD_NAMESPACE ostream &stream,
         if (cursor.isValid())
         {
             /* check by-reference relationships (if applicable) */
-            checkByReferenceRelationships(CM_resetReferenceTargetFlag);
+            checkByReferenceRelationships<DSRDocumentTreeNodeCursor>(CM_resetReferenceTargetFlag);
             /* update the document tree for output (if needed) */
             updateTreeForOutput();
             /* write current node (and its siblings) */
@@ -291,6 +276,26 @@ DSRContentItem &DSRDocumentSubTree::getCurrentContentItem()
 }
 
 
+const DSRDocumentTreeNode *DSRDocumentSubTree::getCurrentNode() const
+{
+    return getNode();
+}
+
+
+OFBool DSRDocumentSubTree::getCursorToRootNode(DSRDocumentTreeNodeCursor &cursor) const
+{
+    cursor = DSRDocumentTreeNodeCursor(getRoot());
+    return cursor.isValid();
+}
+
+
+OFBool DSRDocumentSubTree::getCursorToRootNode(DSRIncludedTemplateNodeCursor &cursor) const
+{
+    cursor = DSRIncludedTemplateNodeCursor(getRoot());
+    return cursor.isValid();
+}
+
+
 size_t DSRDocumentSubTree::countNodes(const OFBool searchIntoSubTemplates,
                                       const OFBool countIncludedTemplateNodes) const
 {
@@ -603,10 +608,15 @@ size_t DSRDocumentSubTree::addByReferenceRelationship(const E_RelationshipType r
 }
 
 
-OFCondition DSRDocumentSubTree::updateByReferenceRelationships()
+OFCondition DSRDocumentSubTree::updateByReferenceRelationships(const OFBool updateIncludedTemplates)
 {
+    OFCondition result = EC_Normal;
     /* update the position strings of by-reference relationships */
-    return checkByReferenceRelationships(CM_updatePositionString);
+    if (updateIncludedTemplates)
+        result = checkByReferenceRelationships<DSRIncludedTemplateNodeCursor>(CM_updatePositionString);
+    else
+        result = checkByReferenceRelationships<DSRDocumentTreeNodeCursor>(CM_updatePositionString);
+    return result;
 }
 
 
@@ -858,6 +868,13 @@ void DSRDocumentSubTree::swap(DSRDocumentSubTree &tree)
 }
 
 
+DSRDocumentTreeNode *DSRDocumentSubTree::getNode() const
+{
+    /* just call the inherited method */
+    return DSRTree<DSRDocumentTreeNode>::getNode();
+}
+
+
 size_t DSRDocumentSubTree::addNode(DSRDocumentTreeNode *node,
                                    const E_AddMode addMode)
 {
@@ -928,7 +945,7 @@ OFCondition DSRDocumentSubTree::expandIncludedTemplates(DSRDocumentSubTree *tree
     if ((tree != NULL) && (tree->gotoRoot() > 0))
     {
         OFBool nodeDeleted;
-        const DSRDocumentTreeNode *node;
+        DSRDocumentTreeNode *node;
         /* iterate over all nodes */
         do {
             node = tree->getNode();
@@ -938,7 +955,7 @@ OFCondition DSRDocumentSubTree::expandIncludedTemplates(DSRDocumentSubTree *tree
                 /* and expand the included templates (if any) */
                 if (node->getValueType() == VT_includedTemplate)
                 {
-                    const DSRSubTemplate *subTempl = OFstatic_cast(const DSRIncludedTemplateTreeNode *, node)->getValue().get();
+                    DSRSubTemplate *subTempl = OFstatic_cast(DSRIncludedTemplateTreeNode *, node)->getValue().get();
                     if (subTempl != NULL)
                     {
                         /* template has no content items */
@@ -947,6 +964,8 @@ OFCondition DSRDocumentSubTree::expandIncludedTemplates(DSRDocumentSubTree *tree
                             /* just remove current node (included template) */
                             nodeDeleted = (tree->removeNode() > 0);
                         } else {
+                            /* make sure that by-reference relationships are "up to date" */
+                            subTempl->updateByReferenceRelationships(OFTrue /*updateIncludedTemplates*/);
                             /* clone the subtree managed by the template */
                             DSRDocumentSubTree *subTree = subTempl->cloneTree();
                             if (subTree != NULL)
@@ -986,6 +1005,7 @@ OFCondition DSRDocumentSubTree::expandIncludedTemplates(DSRDocumentSubTree *tree
 }
 
 
+template <typename T_Cursor>
 OFCondition DSRDocumentSubTree::checkByReferenceRelationships(const size_t mode,
                                                               const size_t flags)
 {
@@ -999,8 +1019,10 @@ OFCondition DSRDocumentSubTree::checkByReferenceRelationships(const size_t mode,
             /* specify for all content items not to be the target of a by-reference relationship */
             if (mode & CM_resetReferenceTargetFlag)
                 resetReferenceTargetFlag();
+            /* pass flags to reference cursor (see below) */
+            const DSRPositionCounter posCounter(flags);
             /* start at the root of the document tree */
-            DSRDocumentTreeNodeCursor cursor(getRoot());
+            T_Cursor cursor(getRoot());
             if (cursor.isValid())
             {
                 /* for all content items */
@@ -1012,14 +1034,14 @@ OFCondition DSRDocumentSubTree::checkByReferenceRelationships(const size_t mode,
                         OFString nodePosString;
                         cursor.getPosition(nodePosString);
                         /* type cast to access members of by-reference class */
-                        DSRByReferenceTreeNode *byRefNode = OFconst_cast(DSRByReferenceTreeNode *, OFstatic_cast(const DSRByReferenceTreeNode *, cursor.getNode()));
+                        DSRByReferenceTreeNode *byRefNode = OFstatic_cast(DSRByReferenceTreeNode *, cursor.getNode());
                         if (flags & RF_showCurrentlyProcessedItem)
                             DCMSR_INFO("Updating by-reference relationship in content item " << nodePosString);
                         /* start searching from root node, be careful with large trees! (tbd: might be improved later on) */
-                        DSRDocumentTreeNodeCursor refCursor(getRoot());
+                        T_Cursor refCursor(getRoot(), &posCounter);
                         if (mode & CM_updateNodeID)
                         {
-                            /* update node ID (based on position string; tbc: what about included templates?) */
+                            /* update node ID (based on position string) */
                             refNodeID = refCursor.gotoNode(byRefNode->getReferencedContentItem());
                             const DSRDocumentTreeNode *targetNode = (refNodeID > 0) ? refCursor.getNode() : NULL;
                             const E_ValueType targetValueType = (targetNode != NULL) ? targetNode->getValueType() : VT_invalid;
@@ -1030,7 +1052,7 @@ OFCondition DSRDocumentSubTree::checkByReferenceRelationships(const size_t mode,
                             if (mode & CM_updatePositionString)
                             {
                                 OFString refPosString;
-                                /* update position string (tbd: does not yet work correctly with "included templates" */
+                                /* update position string */
                                 if (refNodeID > 0)
                                     refCursor.getPosition(refPosString);
                                 byRefNode->updateReference(refPosString);
@@ -1097,7 +1119,7 @@ OFCondition DSRDocumentSubTree::checkByReferenceRelationships(const size_t mode,
 
 void DSRDocumentSubTree::resetReferenceTargetFlag()
 {
-    DSRDocumentTreeNodeCursor cursor(getRoot());
+    DSRIncludedTemplateNodeCursor cursor(getRoot());
     if (cursor.isValid())
     {
         /* iterate over all nodes */
