@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,17 +25,15 @@
 
 #include "dcmtk/dcmsr/dsrimgfr.h"
 
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvris.h"
+
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
-#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
-#define EXPLICIT_SPECIALIZATION template<>
-#else
-#define EXPLICIT_SPECIALIZATION
-#endif
-
 /* declared in class DSRListOfItems<T> */
-EXPLICIT_SPECIALIZATION const Sint32 DSRListOfItems<Sint32>::EmptyItem = 0;
+DCMTK_EXPLICIT_SPECIALIZATION
+const Sint32 DSRListOfItems<Sint32>::EmptyItem = 0;
 
 
 DSRImageFrameList::DSRImageFrameList()
@@ -87,7 +85,8 @@ OFCondition DSRImageFrameList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRImageFrameList::read(DcmItem &dataset)
+OFCondition DSRImageFrameList::read(DcmItem &dataset,
+                                    const size_t /*flags*/)
 {
     /* get integer string from dataset */
     DcmIntegerString delem(DCM_ReferencedFrameNumber);
