@@ -1,9 +1,9 @@
 /*
  *
- *  Copyright (C) 2013-2015, OFFIS e.V.
+ *  Copyright (C) 2013-2016, J. Riesmeier, Oldenburg, Germany
  *  All rights reserved.  See COPYRIGHT file for details.
  *
- *  This software and supporting documentation were developed by
+ *  This software and supporting documentation are maintained by
  *
  *    OFFIS e.V.
  *    R&D Division Health
@@ -25,17 +25,15 @@
 
 #include "dcmtk/dcmsr/dsrimgse.h"
 
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvrus.h"
+
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
-#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
-#define EXPLICIT_SPECIALIZATION template<>
-#else
-#define EXPLICIT_SPECIALIZATION
-#endif
-
 /* declared in class DSRListOfItems<T> */
-EXPLICIT_SPECIALIZATION const Uint16 DSRListOfItems<Uint16>::EmptyItem = 0;
+DCMTK_EXPLICIT_SPECIALIZATION
+const Uint16 DSRListOfItems<Uint16>::EmptyItem = 0;
 
 
 DSRImageSegmentList::DSRImageSegmentList()
@@ -63,8 +61,8 @@ DSRImageSegmentList &DSRImageSegmentList::operator=(const DSRImageSegmentList &l
 
 
 OFCondition DSRImageSegmentList::print(STD_NAMESPACE ostream &stream,
-                                     const size_t flags,
-                                     const char separator) const
+                                       const size_t flags,
+                                       const char separator) const
 {
     const OFListConstIterator(Uint16) endPos = ItemList.end();
     OFListConstIterator(Uint16) iterator = ItemList.begin();
