@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,14 +25,12 @@
 
 #include "dcmtk/dcmsr/dsrtcodt.h"
 
-#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
-#define EXPLICIT_SPECIALIZATION template<>
-#else
-#define EXPLICIT_SPECIALIZATION
-#endif
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvrdt.h"
 
 /* declared in class DSRListOfItems<T> */
-EXPLICIT_SPECIALIZATION const OFString DSRListOfItems<OFString>::EmptyItem;
+DCMTK_EXPLICIT_SPECIALIZATION
+const OFString DSRListOfItems<OFString>::EmptyItem;
 
 
 DSRReferencedDateTimeList::DSRReferencedDateTimeList()
@@ -84,7 +82,8 @@ OFCondition DSRReferencedDateTimeList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRReferencedDateTimeList::read(DcmItem &dataset)
+OFCondition DSRReferencedDateTimeList::read(DcmItem &dataset,
+                                            const size_t /*flags*/)
 {
     /* get string array from dataset */
     DcmDateTime delem(DCM_ReferencedDateTime);
