@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -25,17 +25,15 @@
 
 #include "dcmtk/dcmsr/dsrtcosp.h"
 
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvrul.h"
+
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
-#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
-#define EXPLICIT_SPECIALIZATION template<>
-#else
-#define EXPLICIT_SPECIALIZATION
-#endif
-
 /* declared in class DSRListOfItems<T> */
-EXPLICIT_SPECIALIZATION const Uint32 DSRListOfItems<Uint32>::EmptyItem = 0;
+DCMTK_EXPLICIT_SPECIALIZATION
+const Uint32 DSRListOfItems<Uint32>::EmptyItem = 0;
 
 
 DSRReferencedSamplePositionList::DSRReferencedSamplePositionList()
@@ -87,7 +85,8 @@ OFCondition DSRReferencedSamplePositionList::print(STD_NAMESPACE ostream &stream
 }
 
 
-OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset)
+OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset,
+                                                  const size_t /*flags*/)
 {
     /* get element from dataset */
     DcmUnsignedLong delem(DCM_ReferencedSamplePositions);
