@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -53,6 +53,14 @@
 #include "dcmtk/dcmsr/dsrmaccc.h"
 #include "dcmtk/dcmsr/dsrimpcc.h"
 #include "dcmtk/dcmsr/dsrc3dcc.h"
+#include "dcmtk/dcmsr/dsrrrdcc.h"
+#include "dcmtk/dcmsr/dsracqcc.h"
+
+#include "dcmtk/dcmdata/dcuid.h"
+#include "dcmtk/dcmdata/dcvrda.h"
+#include "dcmtk/dcmdata/dcvrdt.h"
+#include "dcmtk/dcmdata/dcvrpn.h"
+#include "dcmtk/dcmdata/dcvrtm.h"
 
 #include "dcmtk/ofstd/ofstd.h"
 
@@ -120,6 +128,7 @@ const size_t DSRTypes::XF_useDcmsrNamespace              = 1 << 7;
 const size_t DSRTypes::XF_addSchemaReference             = 1 << 8;
 const size_t DSRTypes::XF_validateSchema                 = 1 << 9;
 const size_t DSRTypes::XF_templateElementEnclosesItems   = 1 << 10;
+const size_t DSRTypes::XF_addCommentsForIncludedTemplate = 1 << 11;
 /* shortcuts */
 const size_t DSRTypes::XF_encodeEverythingAsAttribute    = DSRTypes::XF_codeComponentsAsAttribute |
                                                            DSRTypes::XF_relationshipTypeAsAttribute |
@@ -137,6 +146,11 @@ const size_t DSRTypes::PF_useANSIEscapeCodes             = 1 << 6;
 const size_t DSRTypes::PF_printLongSOPClassName          = 1 << 7;
 const size_t DSRTypes::PF_printSOPClassUID               = 1 << 8;
 const size_t DSRTypes::PF_printInvalidCodes              = 1 << 9;
+const size_t DSRTypes::PF_printNodeID                    = 1 << 10;
+const size_t DSRTypes::PF_indicateEnhancedEncodingMode   = 1 << 11;
+const size_t DSRTypes::PF_printAnnotation                = 1 << 12;
+const size_t DSRTypes::PF_hideIncludedTemplateNodes      = 1 << 13;
+const size_t DSRTypes::PF_dontCountIncludedTemplateNodes = 1 << 14;
 /* shortcuts */
 const size_t DSRTypes::PF_printAllCodes                  = DSRTypes::PF_printConceptNameCodes;
 
@@ -145,6 +159,12 @@ const size_t DSRTypes::CM_updatePositionString           = 1 << 0;
 const size_t DSRTypes::CM_updateNodeID                   = 1 << 1;
 const size_t DSRTypes::CM_resetReferenceTargetFlag       = 1 << 2;
 
+/* checkByReferenceRelationships bit masks (avoid conflicts!) */
+const size_t DSRTypes::CB_maskPrintFlags                 = DSRTypes::PF_dontCountIncludedTemplateNodes;
+const size_t DSRTypes::CB_maskReadFlags                  = DSRTypes::RF_acceptUnknownRelationshipType |
+                                                           DSRTypes::RF_ignoreRelationshipConstraints |
+                                                           DSRTypes::RF_showCurrentlyProcessedItem;
+
 
 /*---------------------*
  *  type declarations  *
@@ -251,32 +271,44 @@ struct S_CharacterSetNameMap
  *---------------------------------*/
 
 // conditions
-makeOFConditionConst(SR_EC_UnknownDocumentType,              OFM_dcmsr,  1, OF_error, "Unknown Document Type");
-makeOFConditionConst(SR_EC_InvalidDocument,                  OFM_dcmsr,  2, OF_error, "Invalid Document");
-makeOFConditionConst(SR_EC_InvalidDocumentTree,              OFM_dcmsr,  3, OF_error, "Invalid Document Tree");
-makeOFConditionConst(SR_EC_MandatoryAttributeMissing,        OFM_dcmsr,  4, OF_error, "Mandatory Attribute missing");
-makeOFConditionConst(SR_EC_InvalidValue,                     OFM_dcmsr,  5, OF_error, "Invalid Value");
-makeOFConditionConst(SR_EC_UnsupportedValue,                 OFM_dcmsr,  6, OF_error, "Unsupported Value");
-makeOFConditionConst(SR_EC_UnknownValueType,                 OFM_dcmsr,  7, OF_error, "Unknown Value Type");
-makeOFConditionConst(SR_EC_UnknownRelationshipType,          OFM_dcmsr,  8, OF_error, "Unknown Relationship Type");
-makeOFConditionConst(SR_EC_InvalidByValueRelationship,       OFM_dcmsr,  9, OF_error, "Invalid by-value Relationship");
-makeOFConditionConst(SR_EC_InvalidByReferenceRelationship,   OFM_dcmsr, 10, OF_error, "Invalid by-reference Relationship");
-makeOFConditionConst(SR_EC_SOPInstanceNotFound,              OFM_dcmsr, 11, OF_error, "SOP Instance not found");
-makeOFConditionConst(SR_EC_DifferentSOPClassesForAnInstance, OFM_dcmsr, 12, OF_error, "Different SOP Classes for an Instance");
-makeOFConditionConst(SR_EC_CodingSchemeNotFound,             OFM_dcmsr, 13, OF_error, "Coding Scheme Designator not found");
-makeOFConditionConst(SR_EC_CorruptedXMLStructure,            OFM_dcmsr, 14, OF_error, "Corrupted XML structure");
-makeOFConditionConst(SR_EC_RepresentationNotAvailable,       OFM_dcmsr, 15, OF_error, "Representation not available");
-makeOFConditionConst(SR_EC_CannotCreateIconImage,            OFM_dcmsr, 16, OF_error, "Cannot create Icon Image");
-makeOFConditionConst(SR_EC_CannotAddContentItem,             OFM_dcmsr, 17, OF_error, "Cannot add Content Item");
-makeOFConditionConst(SR_EC_InvalidConceptName,               OFM_dcmsr, 18, OF_error, "Invalid Concept Name");
-makeOFConditionConst(SR_EC_CannotInsertSubTree,              OFM_dcmsr, 19, OF_error, "Cannot insert Subtree");
-makeOFConditionConst(SR_EC_CannotChangeRelationshipType,     OFM_dcmsr, 20, OF_error, "Cannot change Relationship Type");
-makeOFConditionConst(SR_EC_IncompatibleDocumentTree,         OFM_dcmsr, 21, OF_error, "Incompatible Document Tree");
-makeOFConditionConst(SR_EC_ContentItemNotFound,              OFM_dcmsr, 22, OF_error, "Content Item not found");
-makeOFConditionConst(SR_EC_CannotRemoveSubTree,              OFM_dcmsr, 23, OF_error, "Cannot remove Subtree");
-makeOFConditionConst(SR_EC_EmptyDocumentTree,                OFM_dcmsr, 24, OF_error, "Empty Document Tree");
-makeOFConditionConst(SR_EC_InvalidContentItem,               OFM_dcmsr, 25, OF_error, "Invalid Content Item");
-makeOFConditionConst(SR_EC_CannotUseTemplateIdentification,  OFM_dcmsr, 26, OF_error, "Cannot use Template Identification");
+makeOFConditionConst(SR_EC_UnknownDocumentType,                 OFM_dcmsr,  1, OF_error, "Unknown Document Type");
+makeOFConditionConst(SR_EC_InvalidDocument,                     OFM_dcmsr,  2, OF_error, "Invalid Document");
+makeOFConditionConst(SR_EC_InvalidDocumentTree,                 OFM_dcmsr,  3, OF_error, "Invalid Document Tree");
+makeOFConditionConst(SR_EC_MandatoryAttributeMissing,           OFM_dcmsr,  4, OF_error, "Mandatory Attribute missing");
+makeOFConditionConst(SR_EC_InvalidValue,                        OFM_dcmsr,  5, OF_error, "Invalid Value");
+makeOFConditionConst(SR_EC_UnsupportedValue,                    OFM_dcmsr,  6, OF_error, "Unsupported Value");
+makeOFConditionConst(SR_EC_UnknownValueType,                    OFM_dcmsr,  7, OF_error, "Unknown Value Type");
+makeOFConditionConst(SR_EC_UnknownRelationshipType,             OFM_dcmsr,  8, OF_error, "Unknown Relationship Type");
+makeOFConditionConst(SR_EC_InvalidByValueRelationship,          OFM_dcmsr,  9, OF_error, "Invalid by-value Relationship");
+makeOFConditionConst(SR_EC_InvalidByReferenceRelationship,      OFM_dcmsr, 10, OF_error, "Invalid by-reference Relationship");
+makeOFConditionConst(SR_EC_SOPInstanceNotFound,                 OFM_dcmsr, 11, OF_error, "SOP Instance not found");
+makeOFConditionConst(SR_EC_DifferentSOPClassesForAnInstance,    OFM_dcmsr, 12, OF_error, "Different SOP Classes for an Instance");
+makeOFConditionConst(SR_EC_CodingSchemeNotFound,                OFM_dcmsr, 13, OF_error, "Coding Scheme Designator not found");
+makeOFConditionConst(SR_EC_CorruptedXMLStructure,               OFM_dcmsr, 14, OF_error, "Corrupted XML structure");
+makeOFConditionConst(SR_EC_RepresentationNotAvailable,          OFM_dcmsr, 15, OF_error, "Representation not available");
+makeOFConditionConst(SR_EC_CannotCreateIconImage,               OFM_dcmsr, 16, OF_error, "Cannot create Icon Image");
+makeOFConditionConst(SR_EC_CannotAddContentItem,                OFM_dcmsr, 17, OF_error, "Cannot add Content Item");
+makeOFConditionConst(SR_EC_InvalidConceptName,                  OFM_dcmsr, 18, OF_error, "Invalid Concept Name");
+makeOFConditionConst(SR_EC_CannotInsertSubTree,                 OFM_dcmsr, 19, OF_error, "Cannot insert Subtree");
+makeOFConditionConst(SR_EC_CannotChangeRelationshipType,        OFM_dcmsr, 20, OF_error, "Cannot change Relationship Type");
+makeOFConditionConst(SR_EC_IncompatibleDocumentTree,            OFM_dcmsr, 21, OF_error, "Incompatible Document Tree");
+makeOFConditionConst(SR_EC_ContentItemNotFound,                 OFM_dcmsr, 22, OF_error, "Content Item not found");
+makeOFConditionConst(SR_EC_CannotRemoveSubTree,                 OFM_dcmsr, 23, OF_error, "Cannot remove Subtree");
+makeOFConditionConst(SR_EC_EmptyDocumentTree,                   OFM_dcmsr, 24, OF_error, "Empty Document Tree");
+makeOFConditionConst(SR_EC_InvalidContentItem,                  OFM_dcmsr, 25, OF_error, "Invalid Content Item");
+makeOFConditionConst(SR_EC_CannotUseTemplateIdentification,     OFM_dcmsr, 26, OF_error, "Cannot use Template Identification");
+makeOFConditionConst(SR_EC_NonExtensibleTemplate,               OFM_dcmsr, 27, OF_error, "Non-extensible Template");
+makeOFConditionConst(SR_EC_NonExtensibleContextGroup,           OFM_dcmsr, 28, OF_error, "Non-extensible Context Group");
+makeOFConditionConst(SR_EC_CodedEntryNotInContextGroup,         OFM_dcmsr, 29, OF_error, "Coded Entry not in Context Group");
+makeOFConditionConst(SR_EC_CodedEntryInStandardContextGroup,    OFM_dcmsr, 30, OF_ok,    "Coded Entry in Context Group (Standard)");
+makeOFConditionConst(SR_EC_CodedEntryIsExtensionOfContextGroup, OFM_dcmsr, 31, OF_ok,    "Coded Entry in Context Group (Extension)");
+makeOFConditionConst(SR_EC_ValueSetConstraintViolated,          OFM_dcmsr, 32, OF_error, "Value Set Constraint violated");
+makeOFConditionConst(SR_EC_InvalidTemplateStructure,            OFM_dcmsr, 33, OF_error, "Invalid Template Structure");
+makeOFConditionConst(SR_EC_CannotProcessIncludedTemplates,      OFM_dcmsr, 34, OF_error, "Cannot process Document Tree with included Templates");
+
+
+// NOTE:
+// error codes 1000 and above are reserved for the submodule "cmr"
 
 
 static const S_DocumentTypeNameMap DocumentTypeNameMap[] =
@@ -295,7 +327,9 @@ static const S_DocumentTypeNameMap DocumentTypeNameMap[] =
     {DSRTypes::DT_MacularGridThicknessAndVolumeReport, UID_MacularGridThicknessAndVolumeReportStorage, OFTrue,  "SR", "Macular Grid Thickness and Volume Report"},
     {DSRTypes::DT_ImplantationPlanSRDocument,          UID_ImplantationPlanSRDocumentStorage,          OFTrue,  "SR", "Implantation Plan SR Document"},
     {DSRTypes::DT_Comprehensive3DSR,                   UID_Comprehensive3DSRStorage,                   OFFalse, "SR", "Comprehensive 3D SR"},
-    {DSRTypes::DT_RadiopharmaceuticalRadiationDoseSR,  UID_RadiopharmaceuticalRadiationDoseSRStorage,  OFTrue,  "SR", "Radiopharmaceutical Radiation Dose SR"}
+    {DSRTypes::DT_RadiopharmaceuticalRadiationDoseSR,  UID_RadiopharmaceuticalRadiationDoseSRStorage,  OFTrue,  "SR", "Radiopharmaceutical Radiation Dose SR"},
+    {DSRTypes::DT_ExtensibleSR,                        UID_ExtensibleSRStorage,                        OFTrue,  "SR", "Extensible SR"},
+    {DSRTypes::DT_AcquisitionContextSR,                UID_AcquisitionContextSRStorage,                OFTrue,  "SR", "Acquisition Context SR"}
 };
 
 
@@ -303,7 +337,7 @@ static const S_RelationshipTypeNameMap RelationshipTypeNameMap[] =
 {
     {DSRTypes::RT_invalid,       "",                "invalid relationship type"},
     {DSRTypes::RT_unknown,       "",                "unknown relationship type"},
-    {DSRTypes::RT_isRoot,        "",                ""},
+    {DSRTypes::RT_isRoot,        "",                "(is root)"},
     {DSRTypes::RT_contains,      "CONTAINS",        "contains"},
     {DSRTypes::RT_hasObsContext, "HAS OBS CONTEXT", "has obs context"},
     {DSRTypes::RT_hasAcqContext, "HAS ACQ CONTEXT", "has acq context"},
@@ -316,34 +350,37 @@ static const S_RelationshipTypeNameMap RelationshipTypeNameMap[] =
 
 static const S_ValueTypeNameMap ValueTypeNameMap[] =
 {
-    {DSRTypes::VT_invalid,     "",               "item",      "invalid/unknown value type"},
-    {DSRTypes::VT_Text,        "TEXT",           "text",      "Text"},
-    {DSRTypes::VT_Code,        "CODE",           "code",      "Code"},
-    {DSRTypes::VT_Num,         "NUM",            "num",       "Number"},
-    {DSRTypes::VT_DateTime,    "DATETIME",       "datetime",  "Date/Time"},
-    {DSRTypes::VT_Date,        "DATE",           "date",      "Date"},
-    {DSRTypes::VT_Time,        "TIME",           "time",      "Time"},
-    {DSRTypes::VT_UIDRef,      "UIDREF",         "uidref",    "UID Reference"},
-    {DSRTypes::VT_PName,       "PNAME",          "pname",     "Person Name"},
-    {DSRTypes::VT_SCoord,      "SCOORD",         "scoord",    "Spatial Coordinates"},
-    {DSRTypes::VT_SCoord3D,    "SCOORD3D",       "scoord3d",  "Spatial Coordinates (3D)"},
-    {DSRTypes::VT_TCoord,      "TCOORD",         "tcoord",    "Temporal Coordinates"},
-    {DSRTypes::VT_Composite,   "COMPOSITE",      "composite", "Composite Object"},
-    {DSRTypes::VT_Image,       "IMAGE",          "image",     "Image"},
-    {DSRTypes::VT_Waveform,    "WAVEFORM",       "waveform",  "Waveform"},
-    {DSRTypes::VT_Container,   "CONTAINER",      "container", "Container"},
-    {DSRTypes::VT_byReference, "(by-reference)", "reference", "(by-reference)"}
+    {DSRTypes::VT_invalid,          "",                "item",      "invalid/unknown value type"},
+    {DSRTypes::VT_Text,             "TEXT",            "text",      "Text"},
+    {DSRTypes::VT_Code,             "CODE",            "code",      "Code"},
+    {DSRTypes::VT_Num,              "NUM",             "num",       "Number"},
+    {DSRTypes::VT_DateTime,         "DATETIME",        "datetime",  "Date/Time"},
+    {DSRTypes::VT_Date,             "DATE",            "date",      "Date"},
+    {DSRTypes::VT_Time,             "TIME",            "time",      "Time"},
+    {DSRTypes::VT_UIDRef,           "UIDREF",          "uidref",    "UID Reference"},
+    {DSRTypes::VT_PName,            "PNAME",           "pname",     "Person Name"},
+    {DSRTypes::VT_SCoord,           "SCOORD",          "scoord",    "Spatial Coordinates"},
+    {DSRTypes::VT_SCoord3D,         "SCOORD3D",        "scoord3d",  "Spatial Coordinates (3D)"},
+    {DSRTypes::VT_TCoord,           "TCOORD",          "tcoord",    "Temporal Coordinates"},
+    {DSRTypes::VT_Composite,        "COMPOSITE",       "composite", "Composite Object"},
+    {DSRTypes::VT_Image,            "IMAGE",           "image",     "Image"},
+    {DSRTypes::VT_Waveform,         "WAVEFORM",        "waveform",  "Waveform"},
+    {DSRTypes::VT_Container,        "CONTAINER",       "container", "Container"},
+    {DSRTypes::VT_byReference,      "(by-reference)",  "reference", "(by-reference)"},
+    {DSRTypes::VT_includedTemplate, "(incl-template)", "template",  "(included template)"}
 };
 
 
 static const S_PresentationStateTypeNameMap PresentationStateTypeNameMap[] =
 {
-    {DSRTypes::PT_invalid,        "",                                                 "invalid/unknown presentation state type"},
-    {DSRTypes::PT_Grayscale,      UID_GrayscaleSoftcopyPresentationStateStorage,      "GSPS"},
-    {DSRTypes::PT_Color,          UID_ColorSoftcopyPresentationStateStorage,          "CSPS"},
-    {DSRTypes::PT_PseudoColor,    UID_PseudoColorSoftcopyPresentationStateStorage,    "PCSPS"},
-    {DSRTypes::PT_Blending,       UID_BlendingSoftcopyPresentationStateStorage,       "BSPS"},
-    {DSRTypes::PT_XAXRFGrayscale, UID_XAXRFGrayscaleSoftcopyPresentationStateStorage, "XGSPS"}
+    {DSRTypes::PT_invalid,              "",                                                         "invalid/unknown presentation state type"},
+    {DSRTypes::PT_Grayscale,            UID_GrayscaleSoftcopyPresentationStateStorage,              "GSPS"},
+    {DSRTypes::PT_Color,                UID_ColorSoftcopyPresentationStateStorage,                  "CSPS"},
+    {DSRTypes::PT_PseudoColor,          UID_PseudoColorSoftcopyPresentationStateStorage,            "PCSPS"},
+    {DSRTypes::PT_Blending,             UID_BlendingSoftcopyPresentationStateStorage,               "BSPS"},
+    {DSRTypes::PT_XAXRFGrayscale,       UID_XAXRFGrayscaleSoftcopyPresentationStateStorage,         "XGSPS"},
+    {DSRTypes::PT_GrayscalePlanarMPR,   UID_GrayscalePlanarMPRVolumetricPresentationStateStorage,   "GPVPS"},
+    {DSRTypes::PT_CompositingPlanarMPR, UID_CompositingPlanarMPRVolumetricPresentationStateStorage, "CPVPS"}
 };
 
 
@@ -416,21 +453,26 @@ static const S_VerificationFlagNameMap VerificationFlagNameMap[] =
 
 static const S_CharacterSetNameMap CharacterSetNameMap[] =
 {
-    // columns: enum, DICOM, HTML, XML (if "?" a warning is reported)
-    {DSRTypes::CS_invalid,  "",           "",           ""},
-    {DSRTypes::CS_ASCII,    "ISO_IR 6",   "",           "UTF-8"},   /* "ISO_IR 6" is only used for reading */
-    {DSRTypes::CS_Latin1,   "ISO_IR 100", "ISO-8859-1", "ISO-8859-1"},
-    {DSRTypes::CS_Latin2,   "ISO_IR 101", "ISO-8859-2", "ISO-8859-2"},
-    {DSRTypes::CS_Latin3,   "ISO_IR 109", "ISO-8859-3", "ISO-8859-3"},
-    {DSRTypes::CS_Latin4,   "ISO_IR 110", "ISO-8859-4", "ISO-8859-4"},
-    {DSRTypes::CS_Cyrillic, "ISO_IR 144", "ISO-8859-5", "ISO-8859-5"},
-    {DSRTypes::CS_Arabic,   "ISO_IR 127", "ISO-8859-6", "ISO-8859-6"},
-    {DSRTypes::CS_Greek,    "ISO_IR 126", "ISO-8859-7", "ISO-8859-7"},
-    {DSRTypes::CS_Hebrew,   "ISO_IR 138", "ISO-8859-8", "ISO-8859-8"},
-    {DSRTypes::CS_Latin5,   "ISO_IR 148", "ISO-8859-9", "ISO-8859-9"},
-    {DSRTypes::CS_Japanese, "ISO_IR 13",  "?",          "?"},  /* JIS_X0201 ? */
-    {DSRTypes::CS_Thai,     "ISO_IR 166", "?",          "?"},  /* TIS-620 ? */
-    {DSRTypes::CS_UTF8,     "ISO_IR 192", "UTF-8",      "UTF-8"}
+    // columns: enum, DICOM, HTML, XML (if "?" a warning is reported).
+    // This mapping is based on Table D-1 in DICOM PS 3.18 Annex D.
+    {DSRTypes::CS_invalid,        "",                               "",            ""},
+    {DSRTypes::CS_ASCII,          "ISO_IR 6",                       "",            "UTF-8"},   /* "ISO_IR 6" is only used for reading */
+    {DSRTypes::CS_Latin1,         "ISO_IR 100",                     "ISO-8859-1",  "ISO-8859-1"},
+    {DSRTypes::CS_Latin2,         "ISO_IR 101",                     "ISO-8859-2",  "ISO-8859-2"},
+    {DSRTypes::CS_Latin3,         "ISO_IR 109",                     "ISO-8859-3",  "ISO-8859-3"},
+    {DSRTypes::CS_Latin4,         "ISO_IR 110",                     "ISO-8859-4",  "ISO-8859-4"},
+    {DSRTypes::CS_Cyrillic,       "ISO_IR 144",                     "ISO-8859-5",  "ISO-8859-5"},
+    {DSRTypes::CS_Arabic,         "ISO_IR 127",                     "ISO-8859-6",  "ISO-8859-6"},
+    {DSRTypes::CS_Greek,          "ISO_IR 126",                     "ISO-8859-7",  "ISO-8859-7"},
+    {DSRTypes::CS_Hebrew,         "ISO_IR 138",                     "ISO-8859-8",  "ISO-8859-8"},
+    {DSRTypes::CS_Latin5,         "ISO_IR 148",                     "ISO-8859-9",  "ISO-8859-9"},
+    {DSRTypes::CS_Thai,           "ISO_IR 166",                     "TIS-620",     "TIS-620"},
+    {DSRTypes::CS_Japanese,       "ISO 2022 IR 13\\ISO 2022 IR 87", "ISO-2022-JP", "ISO-2022-JP"},
+    {DSRTypes::CS_Korean,         "ISO 2022 IR 6\\ISO 2022 IR 149", "ISO-2022-KR", "ISO-2022-KR"},
+    {DSRTypes::CS_ChineseISO,     "ISO 2022 IR 6\\ISO 2022 IR 58",  "ISO-2022-CN", "ISO-2022-CN"},
+    {DSRTypes::CS_ChineseGB18030, "GB18030",                        "GB18030",     "GB18030"},
+    {DSRTypes::CS_ChineseGBK,     "GBK",                            "GBK",         "GBK"},
+    {DSRTypes::CS_UTF8,           "ISO_IR 192",                     "UTF-8",       "UTF-8"}
 };
 
 
@@ -827,19 +869,25 @@ DSRTypes::E_VerificationFlag DSRTypes::enumeratedValueToVerificationFlag(const O
 
 DSRTypes::E_CharacterSet DSRTypes::definedTermToCharacterSet(const OFString &definedTerm)
 {
-    E_CharacterSet type = CS_invalid;
-    const S_CharacterSetNameMap *iterator = CharacterSetNameMap;
-    while ((iterator->Type != CS_last) && (definedTerm != iterator->DefinedTerm))
-        iterator++;
-    if (definedTerm == iterator->DefinedTerm)
-        type = iterator->Type;
+    E_CharacterSet type = CS_default;
+    /* empty defined term means default */
+    if (!definedTerm.empty())
+    {
+        const S_CharacterSetNameMap *iterator = CharacterSetNameMap;
+        while ((iterator->Type != CS_last) && (definedTerm != iterator->DefinedTerm))
+            iterator++;
+        if (definedTerm == iterator->DefinedTerm)
+            type = iterator->Type;
+        else
+            type = CS_invalid;
+    }
     return type;
 }
 
 
 OFBool DSRTypes::isDocumentTypeSupported(const E_DocumentType documentType)
 {
-    return (documentType != DT_invalid);
+    return (documentType != DT_invalid) && (documentType != DT_ExtensibleSR);
 }
 
 
@@ -960,9 +1008,15 @@ const OFString &DSRTypes::getMarkupStringFromElement(const DcmElement &delem,
 
 OFCondition DSRTypes::getStringValueFromDataset(DcmItem &dataset,
                                                 const DcmTagKey &tagKey,
-                                                OFString &stringValue)
+                                                OFString &stringValue,
+                                                const signed long pos)
 {
-    return dataset.findAndGetOFString(tagKey, stringValue, 0, OFFalse /*searchIntoSub*/);
+    OFCondition result = EC_Normal;
+    if (pos < 0)
+        result = dataset.findAndGetOFStringArray(tagKey, stringValue, OFFalse /*searchIntoSub*/);
+    else
+        result = dataset.findAndGetOFString(tagKey, stringValue, OFstatic_cast(unsigned long, pos), OFFalse /*searchIntoSub*/);
+    return result;
 }
 
 
@@ -1005,7 +1059,12 @@ OFBool DSRTypes::checkElementValue(DcmElement *delem,
         }
     } else {
         const OFCondition checkResult = delem->checkValue(vm, OFTrue /*oldFormat*/);
-        if (checkResult == EC_ValueRepresentationViolated)
+        if (checkResult == EC_InvalidCharacter)
+        {
+            DCMSR_WARN(tagName << " " << tagKey << " contains invalid character(s) in " << module);
+            result = acceptViolation;
+        }
+        else if (checkResult == EC_ValueRepresentationViolated)
         {
             DCMSR_WARN(tagName << " " << tagKey << " violates VR definition in " << module);
             result = acceptViolation;
@@ -1394,7 +1453,17 @@ DSRIODConstraintChecker *DSRTypes::createIODConstraintChecker(const E_DocumentTy
         case DT_Comprehensive3DSR:
             checker = new DSRComprehensive3DSRConstraintChecker();
             break;
-        default:
+        case DT_RadiopharmaceuticalRadiationDoseSR:
+            checker = new DSRRadiopharmaceuticalRadiationDoseConstraintChecker();
+            break;
+        case DT_ExtensibleSR:
+            /* not yet supported */
+            break;
+        case DT_AcquisitionContextSR:
+            checker = new DSRAcquisitionContextConstraintChecker();
+            break;
+        case DT_invalid:
+            /* nothing to do */
             break;
     }
     return checker;
@@ -1570,12 +1639,17 @@ OFBool DSRTypes::writeStringFromElementToXML(STD_NAMESPACE ostream &stream,
     {
         OFString tempString;
         stream << "<" << tagName << ">";
-        if (delem.getVR() == EVR_PN)        // special formatting for person names
+        /* special formatting for person names */
+        if (delem.getVR() == EVR_PN)
         {
             OFString xmlString;
+            /* use first element value only */
             stream << OFendl << dicomToXMLPersonName(getStringValueFromElement(delem, tempString), xmlString, writeEmptyValue) << OFendl;
-        } else
-            OFStandard::convertToMarkupStream(stream, getStringValueFromElement(delem, tempString), OFFalse /*convertNonASCII*/);
+        } else {
+            /* use all element values (1-n) */
+            getStringValueFromElement(delem, tempString, -1 /* all components */);
+            OFStandard::convertToMarkupStream(stream, tempString, OFFalse /*convertNonASCII*/);
+        }
         stream << "</" << tagName << ">" << OFendl;
         result = OFTrue;
     }
