@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2014, OFFIS e.V.
+ *  Copyright (C) 2000-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,17 +26,15 @@
 #include "dcmtk/dcmsr/dsrwavch.h"
 #include "dcmtk/dcmsr/dsrxmld.h"
 
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcvrus.h"
+
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
-#ifdef HAVE_EXPLICIT_TEMPLATE_SPECIALIZATION
-#define EXPLICIT_SPECIALIZATION template<>
-#else
-#define EXPLICIT_SPECIALIZATION
-#endif
-
 /* declared in class DSRListOfItems<T> */
-EXPLICIT_SPECIALIZATION const DSRWaveformChannelItem DSRListOfItems<DSRWaveformChannelItem>::EmptyItem(0, 0);
+DCMTK_EXPLICIT_SPECIALIZATION
+const DSRWaveformChannelItem DSRListOfItems<DSRWaveformChannelItem>::EmptyItem(0, 0);
 
 
 DSRWaveformChannelList::DSRWaveformChannelList()
@@ -88,7 +86,8 @@ OFCondition DSRWaveformChannelList::print(STD_NAMESPACE ostream &stream,
 }
 
 
-OFCondition DSRWaveformChannelList::read(DcmItem &dataset)
+OFCondition DSRWaveformChannelList::read(DcmItem &dataset,
+                                         const size_t /*flags*/)
 {
     /* get integer array from dataset */
     DcmUnsignedShort delem(DCM_ReferencedWaveformChannels);
