@@ -25,6 +25,7 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/ofstd/oftest.h"
+
 #include "dcmtk/dcmsr/dsrdoc.h"
 #include "dcmtk/dcmsr/dsrtpltn.h"
 #include "dcmtk/dcmsr/dsrnumtn.h"
@@ -107,6 +108,26 @@ OFTEST(dcmsr_copyContentItem)
 }
 
 
+OFTEST(dcmsr_getCurrentNode)
+{
+    /* first, create a new SR document */
+    DSRDocument doc(DSRTypes::DT_ComprehensiveSR);
+    DSRDocumentTree &tree = doc.getTree();
+    /* then add some content items */
+    OFCHECK(tree.addContentItem(DSRTypes::RT_isRoot, DSRTypes::VT_Container, DSRCodedEntryValue("121111", "DCM", "Summary")).good());
+    OFCHECK(tree.addChildContentItem(DSRTypes::RT_contains, DSRTypes::VT_Num, DSRCodedEntryValue("121206", "DCM", "Distance")).good());
+    /* and check the current node */
+    const DSRDocumentTreeNode *treeNode = tree.getCurrentNode();
+    if (treeNode != NULL)
+    {
+        OFCHECK_EQUAL(treeNode->getRelationshipType(), DSRTypes::RT_contains);
+        OFCHECK_EQUAL(treeNode->getValueType(), DSRTypes::VT_Num);
+        OFCHECK_EQUAL(treeNode->getConceptName().getCodeMeaning(), "Distance");
+    } else
+        OFCHECK_FAIL("could not get read-only access to current node");
+}
+
+
 OFTEST(dcmsr_gotoNamedNode)
 {
     /* first, create a new SR document */
