@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2015, OFFIS e.V.
+ *  Copyright (C) 2001-2016, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -183,9 +183,9 @@ const unsigned int OFStandard::ftoa_zeropad   = 0x20;
  */
 size_t OFStandard::my_strlcpy(char *dst, const char *src, size_t siz)
 {
-  register char *d = dst;
-  register const char *s = src;
-  register size_t n = siz;
+  char *d = dst;
+  const char *s = src;
+  size_t n = siz;
 
   /* Copy as many bytes as will fit */
   if (n != 0 && --n != 0)
@@ -220,9 +220,9 @@ size_t OFStandard::my_strlcpy(char *dst, const char *src, size_t siz)
  */
 size_t OFStandard::my_strlcat(char *dst, const char *src, size_t siz)
 {
-  register char *d = dst;
-  register const char *s = src;
-  register size_t n = siz;
+  char *d = dst;
+  const char *s = src;
+  size_t n = siz;
   size_t dlen;
 
   /* Find the end of dst and adjust bytes left but don't go past end */
@@ -825,6 +825,12 @@ OFCondition OFStandard::removeRootDirFromPathname(OFFilename &result,
             result.set("", OFTrue /*convert*/);
             status = EC_Normal;
         }
+        /* check for empty root dir */
+        else if (rootLength == 0)
+        {
+            result.set(pathValue, OFTrue /*convert*/);
+            status = EC_Normal;
+        }
         /* check for "compatible" length */
         else if (rootLength <= pathLength)
         {
@@ -858,6 +864,12 @@ OFCondition OFStandard::removeRootDirFromPathname(OFFilename &result,
             result.set("");
             status = EC_Normal;
         }
+        /* check for empty root dir */
+        else if (rootLength == 0)
+        {
+            result.set(pathValue);
+            status = EC_Normal;
+        }
         /* check for "compatible" length */
         else if (rootLength <= pathLength)
         {
@@ -1773,8 +1785,8 @@ static const double atof_powersOf10[] =
 double OFStandard::atof(const char *s, OFBool *success)
 {
     if (success) *success = OFFalse;
-    register const char *p = s;
-    register char c;
+    const char *p = s;
+    char c;
     int sign = 0;
     int expSign = 0;
     double fraction;
@@ -2099,7 +2111,7 @@ static char *ftoa_exponent(char *p, int exponent, char fmtch)
     *p++ = '-';
   }
   else *p++ = '+';
-  register char *t = expbuf + FTOA_MAXEXP;
+  char *t = expbuf + FTOA_MAXEXP;
   if (exponent > 9)
   {
     do
@@ -2186,8 +2198,8 @@ static char *ftoa_round(double fract, int *expon, char *start, char *end, char c
  */
 static int ftoa_convert(double val, int prec, int flags, char *signp, char fmtch, char *startp, char *endp)
 {
-  register char *p;
-  register double fract;
+  char *p;
+  double fract;
   int dotrim = 0;
   int expcnt = 0;
   int gformat = 0;
@@ -2196,7 +2208,7 @@ static int ftoa_convert(double val, int prec, int flags, char *signp, char fmtch
   fract = modf(val, &integer);
 
   /* get an extra slot for rounding. */
-  register char *t = ++startp;
+  char *t = ++startp;
 
   /*
    * get integer portion of val; put into the end of the buffer; the
@@ -2418,7 +2430,7 @@ void OFStandard::ftoa(
   char softsign = 0;  /* temporary negative sign for floats */
   char buf[FTOA_BUFSIZE];      /* space for %c, %[diouxX], %[eEfgG] */
   char sign = '\0';   /* sign prefix (' ', '+', '-', or \0) */
-  register int n;
+  int n;
   unsigned char fmtch = 'G';
   FTOAStringBuffer sb(FTOA_BUFSIZE+1);
 
@@ -2464,7 +2476,7 @@ void OFStandard::ftoa(
   *buf = 0;
   int size = ftoa_convert(val, prec, flags, &softsign, fmtch, buf, buf + sizeof(buf));
   if (softsign) sign = '-';
-  register char *t = *buf ? buf : buf + 1;
+  char *t = *buf ? buf : buf + 1;
 
   /* At this point, `t' points to a string which (if not flags&FTOA_LEFT_ADJUSTMENT)
    * should be padded out to `width' places.  If flags&FTOA_ZEROPAD, it should
